@@ -36,7 +36,7 @@
 #include "config-keys.h"
 #include "sat-cfg.h"
 #include "mod-cfg-get-param.h"
-#include "time-tools.h"
+//#include "time-tools.h"
 #include "sat-popup-menu.h"
 #include "gtk-sat-data.h"
 #include "gpredict-utils.h"
@@ -191,7 +191,10 @@ gtk_polar_view_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 	GTK_POLAR_VIEW (polv)->qth  = qth;
 
 	/* FIXME: use g_has_table_new_full */
-	GTK_POLAR_VIEW (polv)->obj  = g_hash_table_new (g_int_hash, g_int_equal);
+	GTK_POLAR_VIEW (polv)->obj  = g_hash_table_new_full (g_int_hash,
+														 g_int_equal,
+														 g_free,
+														 NULL);
 
 	/* get settings */
 	GTK_POLAR_VIEW (polv)->refresh = mod_cfg_get_int (cfgdata,
@@ -682,7 +685,7 @@ gtk_polar_view_update          (GtkWidget  *widget)
 				/* last desperate sanity check */
 				if (sat != NULL) {
 
-					now = get_current_daynum ();
+					now = polv->tstamp; //get_current_daynum ();
 					number = polv->naos - now;
 
 					/* convert julian date to seconds */
@@ -767,7 +770,7 @@ update_sat    (gpointer key, gpointer value, gpointer data)
 	GooCanvasModel *model;
 	GooCanvasItem  *root;
 	gint            idx,i;
-	gdouble         now = get_current_daynum ();
+	gdouble         now;// = get_current_daynum ();
 	gchar          *text;
 	guint32         colour;
 
@@ -775,6 +778,8 @@ update_sat    (gpointer key, gpointer value, gpointer data)
 	catnum = g_new0 (gint, 1);
 	*catnum = sat->tle.catnr;
 
+	now = polv->tstamp;
+
 	/* update next AOS */
 	if ((sat->aos > now) && (sat->aos < polv->naos)) {
 		polv->naos = sat->aos;
@@ -865,7 +870,7 @@ update_sat    (gpointer key, gpointer value, gpointer data)
 				gdouble       number, now;
 
 
-				now = get_current_daynum ();
+				now = polv->tstamp;//get_current_daynum ();
 				number = sat->los - now;
 
 				/* convert julian date to seconds */
@@ -1395,3 +1400,14 @@ get_canvas_bg_color (GtkPolarView *polv, GdkColor *color)
 }
 
 
+/** \brief Reload reference to satellites (e.g. after TLE update). */
+void
+gtk_polar_view_reload_sats (GtkWidget *polv, GHashTable *sats)
+{
+
+	GTK_POLAR_VIEW (polv)->sats = sats;
+
+	GTK_POLAR_VIEW (polv)->naos = 0.0;
+	GTK_POLAR_VIEW (polv)->ncat = 0;
+}
+
