@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 
 #include <glib.h>
@@ -41,7 +41,7 @@
 
 
 /** \brief Read QTH data from file.
- *  \param filename The file to read from
+ *  \param filename The file to read from.
  *  \param qth Pointer to a qth_t data structure where the data will be stored.
  *  \return FALSE if an error occurred, TRUE otherwise.
  *
@@ -59,21 +59,21 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	/* bail out with error message if data can not be read */
 	if (!g_key_file_load_from_file (qth->data, filename,
-					G_KEY_FILE_KEEP_COMMENTS, &error)) {
+									G_KEY_FILE_KEEP_COMMENTS, &error)) {
 
 		g_key_file_free (qth->data);
 
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Could not load data from %s (%s)"),
-			     __FUNCTION__, filename, error->message);
+					 _("%s: Could not load data from %s (%s)"),
+					 __FUNCTION__, filename, error->message);
 
 		return FALSE;
 	}
 
 	/* send a debug message, then read data */
 	sat_log_log (SAT_LOG_LEVEL_DEBUG,
-		     _("%s: QTH data: %s"),
-		     __FUNCTION__, filename);
+				 _("%s: QTH data: %s"),
+				 __FUNCTION__, filename);
 
 	/*** FIXME: should check that strings are UTF-8? */
 	/* QTH Name */
@@ -83,14 +83,14 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	g_free (buff);
 	g_strfreev (buffv);
-/* g_key_file_get_string (qth->data, */
-/* 					   QTH_CFG_MAIN_SECTION, */
-/* 					   QTH_CFG_NAME_KEY, */
-/* 					   &error); */
+	/* g_key_file_get_string (qth->data, */
+	/* 					   QTH_CFG_MAIN_SECTION, */
+	/* 					   QTH_CFG_NAME_KEY, */
+	/* 					   &error); */
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR, 
-			     _("%s: Error reading QTH name (%s)."),
-			     __FUNCTION__, error->message);
+					 _("%s: Error reading QTH name (%s)."),
+					 __FUNCTION__, error->message);
 
 		qth->name = g_strdup (_("ERROR"));
 		g_clear_error (&error);
@@ -98,13 +98,13 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	/* QTH location */
 	qth->loc = g_key_file_get_string (qth->data,
-					  QTH_CFG_MAIN_SECTION,
-					  QTH_CFG_LOC_KEY,
-					  &error);
+									  QTH_CFG_MAIN_SECTION,
+									  QTH_CFG_LOC_KEY,
+									  &error);
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s: QTH has no location (%s)."),
-			     __FUNCTION__, error->message);
+					 _("%s: QTH has no location (%s)."),
+					 __FUNCTION__, error->message);
 
 		qth->loc = g_strdup ("");
 		g_clear_error (&error);
@@ -112,13 +112,13 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	/* QTH description */
 	qth->desc = g_key_file_get_string (qth->data,
-					   QTH_CFG_MAIN_SECTION,
-					   QTH_CFG_DESC_KEY,
-					   &error);
+									   QTH_CFG_MAIN_SECTION,
+									   QTH_CFG_DESC_KEY,
+									   &error);
 	if ((qth->desc == NULL) || (error != NULL)) {
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s: QTH has no description."),
-			     __FUNCTION__);
+					 _("%s: QTH has no description."),
+					 __FUNCTION__);
 
 		qth->desc = g_strdup ("");
 		g_clear_error (&error);
@@ -126,13 +126,13 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	/* Weather station */
 	qth->wx = g_key_file_get_string (qth->data,
-					 QTH_CFG_MAIN_SECTION,
-					 QTH_CFG_WX_KEY,
-					 &error);
+									 QTH_CFG_MAIN_SECTION,
+									 QTH_CFG_WX_KEY,
+									 &error);
 	if ((qth->wx == NULL) || (error != NULL)) {
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s: QTH has no weather station."),
-			     __FUNCTION__);
+					 _("%s: QTH has no weather station."),
+					 __FUNCTION__);
 
 		qth->wx = g_strdup ("");
 		g_clear_error (&error);
@@ -140,13 +140,13 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	/* QTH Latitude */
 	buff = g_key_file_get_string (qth->data,
-				      QTH_CFG_MAIN_SECTION,
-				      QTH_CFG_LAT_KEY,
-				      &error);
+								  QTH_CFG_MAIN_SECTION,
+								  QTH_CFG_LAT_KEY,
+								  &error);
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Error reading QTH latitude (%s)."),
-			     __FUNCTION__, error->message);
+					 _("%s: Error reading QTH latitude (%s)."),
+					 __FUNCTION__, error->message);
 
 		g_clear_error (&error);
 
@@ -162,13 +162,13 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	/* QTH Longitude */
 	buff = g_key_file_get_string (qth->data,
-				      QTH_CFG_MAIN_SECTION,
-				      QTH_CFG_LON_KEY,
-				      &error);
+								  QTH_CFG_MAIN_SECTION,
+								  QTH_CFG_LON_KEY,
+								  &error);
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Error reading QTH longitude (%s)."),
-			     __FUNCTION__, error->message);
+					 _("%s: Error reading QTH longitude (%s)."),
+					 __FUNCTION__, error->message);
 
 		g_clear_error (&error);
 
@@ -184,13 +184,13 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	/* QTH Altitude */
 	qth->alt = g_key_file_get_integer (qth->data,
-					   QTH_CFG_MAIN_SECTION,
-					   QTH_CFG_ALT_KEY,
-					   &error);
+									   QTH_CFG_MAIN_SECTION,
+									   QTH_CFG_ALT_KEY,
+									   &error);
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Error reading QTH altitude (%s)."),
-			     __FUNCTION__, error->message);
+					 _("%s: Error reading QTH altitude (%s)."),
+					 __FUNCTION__, error->message);
 
 		g_clear_error (&error);
 
@@ -204,17 +204,21 @@ gtk_sat_data_read_qth (const gchar *filename, qth_t *qth)
 
 	/* Now, send debug message and return */
 	sat_log_log (SAT_LOG_LEVEL_MSG,
-		     _("%s: QTH data: %s, %.2f, %.2f, %d"),
-		     __FUNCTION__,
-		     qth->name,
-		     qth->lat,
-		     qth->lon,
-		     qth->alt);
+				 _("%s: QTH data: %s, %.4f, %.4f, %d"),
+				 __FUNCTION__,
+				 qth->name,
+				 qth->lat,
+				 qth->lon,
+				 qth->alt);
 
 	return TRUE;
 }
 
 
+/** \brief Save the QTH data to a file.
+ * \param filename The file to save to.
+ * \param qth Pointer to a qth_t data structure from which the data will be read.
+ */
 gint
 gtk_sat_data_save_qth (const gchar *filename, qth_t *qth)
 {
@@ -226,32 +230,31 @@ gtk_sat_data_save_qth (const gchar *filename, qth_t *qth)
 	gchar      *cfgstr;
 	gint        ok = 1;
 
-
 	qth->data = g_key_file_new ();
 	g_key_file_set_list_separator (qth->data, ';');
 
 	/* name */
-/* 	if (qth->name) { */
-/* 		g_key_file_set_string (qth->data, */
-/* 				       QTH_CFG_MAIN_SECTION, */
-/* 				       QTH_CFG_NAME_KEY, */
-/* 				       qth->name); */
-/* 	} */
+	/* 	if (qth->name) { */
+	/* 		g_key_file_set_string (qth->data, */
+	/* 				       QTH_CFG_MAIN_SECTION, */
+	/* 				       QTH_CFG_NAME_KEY, */
+	/* 				       qth->name); */
+	/* 	} */
 
 	/* description */
 	if (qth->desc && (g_utf8_strlen (qth->desc, -1) > 0)) {
 		g_key_file_set_string (qth->data,
-				       QTH_CFG_MAIN_SECTION,
-				       QTH_CFG_DESC_KEY,
-				       qth->desc);
+							   QTH_CFG_MAIN_SECTION,
+							   QTH_CFG_DESC_KEY,
+							   qth->desc);
 	}
 	
 	/* location */
 	if (qth->loc && (g_utf8_strlen (qth->loc, -1) > 0)) {
 		g_key_file_set_string (qth->data,
-				       QTH_CFG_MAIN_SECTION,
-				       QTH_CFG_LOC_KEY,
-				       qth->loc);
+							   QTH_CFG_MAIN_SECTION,
+							   QTH_CFG_LOC_KEY,
+							   qth->loc);
 	}
 
 	/* latitude */
@@ -259,33 +262,33 @@ gtk_sat_data_save_qth (const gchar *filename, qth_t *qth)
 	buff = g_malloc (10);
 	buff = g_ascii_dtostr (buff, 9, qth->lat);
 	g_key_file_set_string (qth->data,
-			       QTH_CFG_MAIN_SECTION,
-			       QTH_CFG_LAT_KEY,
-			       buff);
+						   QTH_CFG_MAIN_SECTION,
+						   QTH_CFG_LAT_KEY,
+						   buff);
 	g_free (buff);
 
 	/* longitude */
-/* 	buff = g_strdup_printf ("%.4f", qth->lon); */
+	/* 	buff = g_strdup_printf ("%.4f", qth->lon); */
 	buff = g_malloc (10);
 	buff = g_ascii_dtostr (buff, 9, qth->lon);
 	g_key_file_set_string (qth->data,
-			       QTH_CFG_MAIN_SECTION,
-			       QTH_CFG_LON_KEY,
-			       buff);
+						   QTH_CFG_MAIN_SECTION,
+						   QTH_CFG_LON_KEY,
+						   buff);
 	g_free (buff);
 
 	/* altitude */
 	g_key_file_set_integer (qth->data,
-				QTH_CFG_MAIN_SECTION,
-				QTH_CFG_ALT_KEY,
-				qth->alt);
+							QTH_CFG_MAIN_SECTION,
+							QTH_CFG_ALT_KEY,
+							qth->alt);
 
 	/* weather station */
 	if (qth->wx && (g_utf8_strlen (qth->wx, -1) > 0)) {
 		g_key_file_set_string (qth->data,
-				       QTH_CFG_MAIN_SECTION,
-				       QTH_CFG_WX_KEY,
-				       qth->wx);
+							   QTH_CFG_MAIN_SECTION,
+							   QTH_CFG_WX_KEY,
+							   qth->wx);
 	}
 
 	/* saving code */
@@ -295,8 +298,8 @@ gtk_sat_data_save_qth (const gchar *filename, qth_t *qth)
 
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Could not create QTH data (%s)."),
-			     __FUNCTION__, error->message);
+					 _("%s: Could not create QTH data (%s)."),
+					 __FUNCTION__, error->message);
 
 		g_clear_error (&error);
 
@@ -308,8 +311,8 @@ gtk_sat_data_save_qth (const gchar *filename, qth_t *qth)
 
 		if (error != NULL) {
 			sat_log_log (SAT_LOG_LEVEL_ERROR,
-				     _("%s: Could not create QTH file %s\n%s."),
-				     __FUNCTION__, filename, error->message);
+						 _("%s: Could not create QTH file %s\n%s."),
+						 __FUNCTION__, filename, error->message);
 
 			g_clear_error (&error);
 
@@ -317,18 +320,18 @@ gtk_sat_data_save_qth (const gchar *filename, qth_t *qth)
 		}
 		else {
 			g_io_channel_write_chars (cfgfile,
-						  cfgstr,
-						  length,
-						  &written,
-						  &error);
+									  cfgstr,
+									  length,
+									  &written,
+									  &error);
 
 			g_io_channel_shutdown (cfgfile, TRUE, NULL);
 			g_io_channel_unref (cfgfile);
 
 			if (error != NULL) {
 				sat_log_log (SAT_LOG_LEVEL_ERROR,
-					     _("%s: Error writing QTH data (%s)."),
-					     __FUNCTION__, error->message);
+							 _("%s: Error writing QTH data (%s)."),
+							 __FUNCTION__, error->message);
 
 				g_clear_error (&error);
 
@@ -336,15 +339,15 @@ gtk_sat_data_save_qth (const gchar *filename, qth_t *qth)
 			}
 			else if (length != written) {
 				sat_log_log (SAT_LOG_LEVEL_WARN,
-					     _("%s: Wrote only %d out of %d chars."),
-					     __FUNCTION__, written, length);
+							 _("%s: Wrote only %d out of %d chars."),
+							 __FUNCTION__, written, length);
 
 				ok = 0;
 			}
 			else {
 				sat_log_log (SAT_LOG_LEVEL_MSG,
-					     _("%s: QTH data saved."),
-					     __FUNCTION__);
+							 _("%s: QTH data saved."),
+							 __FUNCTION__);
 
 				ok = 1;
 			}
@@ -353,40 +356,51 @@ gtk_sat_data_save_qth (const gchar *filename, qth_t *qth)
 		g_free (cfgstr);
 	}
 
-        return ok;
-
+	return ok;
 }
 
 
-
 /** \brief Free QTH resources.
  *  \param qth The qth data structure to free.
  */
 void
 gtk_sat_data_free_qth (qth_t *qth)
 {
-	if (qth->name)
+	if (qth->name) {
 		g_free (qth->name);
+		qth->name = NULL;
+	}
 
-	if (qth->loc)
+	if (qth->loc) {
 		g_free (qth->loc);
+		qth->loc = NULL;
+	}
 
-	if (qth->desc)
+	if (qth->desc) {
 		g_free (qth->desc);
+		qth->desc = NULL;
+	}
 
-	if (qth->qra)
+	if (qth->qra) {
 		g_free (qth->qra);
+		qth->qra = NULL;
+	}
 
-	if (qth->wx)
+	if (qth->wx) {
 		g_free (qth->wx);
+		qth->wx = NULL;
+	}
 
-	g_key_file_free (qth->data);
+	if (qth->data) {
+		g_key_file_free (qth->data);
+		qth->data = NULL;
+	}
 
 	g_free (qth);
 }
 
 
-/** \brief Read TLE data for a gien atellite into memory.
+/** \brief Read TLE data for a given satellite into memory.
  *  \param catnum The catalog number of the satellite.
  *  \param sat Pointerto a valid sat_t structure.
  *  \return 0 if successfull, 1 if the satellite could not
@@ -407,25 +421,24 @@ gtk_sat_data_read_sat (gint catnum, sat_t *sat)
 	guint    catnr;
 	gboolean found = FALSE;
 	guint    errorcode = 0;
-	
 
 	filename = tle_lookup (catnum);
 
 	if (!filename) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Can not find #%d in any .tle file."),
-			     __FUNCTION__, catnum);
+					 _("%s: Can not find #%d in any .tle file."),
+					 __FUNCTION__, catnum);
 
 		return 1;
 	}
 
 	/* create full file path */
 	path = g_strdup_printf ("%s%s.gpredict2%stle%s%s",
-				g_get_home_dir (),
-				G_DIR_SEPARATOR_S,
-				G_DIR_SEPARATOR_S,
-				G_DIR_SEPARATOR_S,
-				filename);
+							g_get_home_dir (),
+							G_DIR_SEPARATOR_S,
+							G_DIR_SEPARATOR_S,
+							G_DIR_SEPARATOR_S,
+							filename);
 
 	fp = fopen (path, "r");
 
@@ -447,28 +460,28 @@ gtk_sat_data_read_sat (gint catnum, sat_t *sat)
 			if (catnr == catnum) {
 
 				sat_log_log (SAT_LOG_LEVEL_DEBUG,
-					     _("%s: Found #%d in %s"),
-					     __FUNCTION__,
-					     catnum,
-					     path);
+							 _("%s: Found #%d in %s"),
+							 __FUNCTION__,
+							 catnum,
+							 path);
 
 				found = TRUE;
 
 				if (Get_Next_Tle_Set (tle_str, &sat->tle) != 1) {
 					/* TLE data not good */
 					sat_log_log (SAT_LOG_LEVEL_ERROR,
-						     _("%s: Invalid data for #%d"),
-						     __FUNCTION__,
-						     catnum);
+								 _("%s: Invalid data for #%d"),
+								 __FUNCTION__,
+								 catnum);
 
 					errorcode = 2;
 				}
 				else {
 					/* DATA OK, phew... */
 					sat_log_log (SAT_LOG_LEVEL_DEBUG,
-						     _("%s: Good data for #%d"),
-						     __FUNCTION__,
-						     catnum);
+								 _("%s: Good data for #%d"),
+								 __FUNCTION__,
+								 catnum);
 
 					/* VERY, VERY important! If not done, some sats
 					   will not get initialised, the first time SGP4/SDP4
@@ -509,12 +522,11 @@ gtk_sat_data_read_sat (gint catnum, sat_t *sat)
 		}
 
 		fclose (fp);
-
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Failed to open %s"),
-			     __FUNCTION__, path);
+					 _("%s: Failed to open %s"),
+					 __FUNCTION__, path);
 
 		errorcode = 3;
 	}
@@ -593,9 +605,8 @@ gtk_sat_data_init_sat (sat_t *sat, qth_t *qth)
 	sat->footprint = 2.0 * xkmper * acos (xkmper/sat->pos.w);
 	age = 0.0;
 	sat->orbit = (long) floor((sat->tle.xno * xmnpda/twopi +
-				   age * sat->tle.bstar * ae) * age +
-				  sat->tle.xmo/twopi) + sat->tle.revnum - 1;
-
+							   age * sat->tle.bstar * ae) * age +
+							  sat->tle.xmo/twopi) + sat->tle.revnum - 1;
 
 	/* orbit type */
 	sat->otype = get_orbit_type (sat);
