@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 /** \brief Satellite List Widget.
  *
@@ -140,70 +140,70 @@ static void          gtk_sat_list_init       (GtkSatList      *list);
 static void          gtk_sat_list_destroy    (GtkObject       *object);
 static GtkTreeModel *create_and_fill_model   (GHashTable      *sats);
 static void          sat_list_add_satellites (gpointer key,
-					      gpointer value,
-					      gpointer user_data);
+											  gpointer value,
+											  gpointer user_data);
 static gboolean      sat_list_update_sats    (GtkTreeModel *model,
-					      GtkTreePath  *path,
-					      GtkTreeIter  *iter,
-					      gpointer      data);
+											  GtkTreePath  *path,
+											  GtkTreeIter  *iter,
+											  gpointer      data);
 
 /* cell rendering related functions */
 static void          check_and_set_cell_renderer (GtkTreeViewColumn *column,
-						  GtkCellRenderer   *renderer,
-						  gint               i);
+												  GtkCellRenderer   *renderer,
+												  gint               i);
 
 static void          latlon_cell_data_function (GtkTreeViewColumn *col,
-						GtkCellRenderer   *renderer,
-						GtkTreeModel      *model,
-						GtkTreeIter       *iter,
-						gpointer           column);
+												GtkCellRenderer   *renderer,
+												GtkTreeModel      *model,
+												GtkTreeIter       *iter,
+												gpointer           column);
 
 static void          degree_cell_data_function (GtkTreeViewColumn *col,
-						GtkCellRenderer   *renderer,
-						GtkTreeModel      *model,
-						GtkTreeIter       *iter,
-						gpointer           column);
+												GtkCellRenderer   *renderer,
+												GtkTreeModel      *model,
+												GtkTreeIter       *iter,
+												gpointer           column);
 
 static void          distance_cell_data_function (GtkTreeViewColumn *col,
-						  GtkCellRenderer   *renderer,
-						  GtkTreeModel      *model,
-						  GtkTreeIter       *iter,
-						  gpointer           column);
+												  GtkCellRenderer   *renderer,
+												  GtkTreeModel      *model,
+												  GtkTreeIter       *iter,
+												  gpointer           column);
 
 static void          range_rate_cell_data_function (GtkTreeViewColumn *col,
-						    GtkCellRenderer   *renderer,
-						    GtkTreeModel      *model,
-						    GtkTreeIter       *iter,
-						    gpointer           column);
+													GtkCellRenderer   *renderer,
+													GtkTreeModel      *model,
+													GtkTreeIter       *iter,
+													gpointer           column);
 
 static void          float_to_int_cell_data_function (GtkTreeViewColumn *col,
-						      GtkCellRenderer   *renderer,
-						      GtkTreeModel      *model,
-						      GtkTreeIter       *iter,
-						      gpointer           column);
+													  GtkCellRenderer   *renderer,
+													  GtkTreeModel      *model,
+													  GtkTreeIter       *iter,
+													  gpointer           column);
 
 static void          two_dec_cell_data_function (GtkTreeViewColumn *col,
-						 GtkCellRenderer   *renderer,
-						 GtkTreeModel      *model,
-						 GtkTreeIter       *iter,
-						 gpointer           column);
+												 GtkCellRenderer   *renderer,
+												 GtkTreeModel      *model,
+												 GtkTreeIter       *iter,
+												 gpointer           column);
 
 static void          event_cell_data_function (GtkTreeViewColumn *col,
-					       GtkCellRenderer   *renderer,
-					       GtkTreeModel      *model,
-					       GtkTreeIter       *iter,
-					       gpointer           column);
+											   GtkCellRenderer   *renderer,
+											   GtkTreeModel      *model,
+											   GtkTreeIter       *iter,
+											   gpointer           column);
 
 static gboolean   popup_menu_cb   (GtkWidget *treeview,
-				   gpointer list);
+								   gpointer list);
 
 static gboolean   button_press_cb (GtkWidget *treeview,
-				   GdkEventButton *event,
-				   gpointer list);
+								   GdkEventButton *event,
+								   gpointer list);
 
 static void       view_popup_menu (GtkWidget *treeview,
-				   GdkEventButton *event,
-				   gpointer list);
+								   GdkEventButton *event,
+								   gpointer list);
 
 static void    Calculate_RADec (sat_t *sat, qth_t *qth, obs_astro_t *obs_set);
 
@@ -219,25 +219,25 @@ gtk_sat_list_get_type ()
 	static GType gtk_sat_list_type = 0;
 
 	if (!gtk_sat_list_type)
-	{
-		static const GTypeInfo gtk_sat_list_info =
-			{
-				sizeof (GtkSatListClass),
-				NULL,  /* base_init */
-				NULL,  /* base_finalize */
-				(GClassInitFunc) gtk_sat_list_class_init,
-				NULL,  /* class_finalize */
-				NULL,  /* class_data */
-				sizeof (GtkSatList),
-				5,     /* n_preallocs */
-				(GInstanceInitFunc) gtk_sat_list_init,
-			};
+		{
+			static const GTypeInfo gtk_sat_list_info =
+				{
+					sizeof (GtkSatListClass),
+					NULL,  /* base_init */
+					NULL,  /* base_finalize */
+					(GClassInitFunc) gtk_sat_list_class_init,
+					NULL,  /* class_finalize */
+					NULL,  /* class_data */
+					sizeof (GtkSatList),
+					5,     /* n_preallocs */
+					(GInstanceInitFunc) gtk_sat_list_init,
+				};
 
-		gtk_sat_list_type = g_type_register_static (GTK_TYPE_VBOX,
-							    "GtkSatList",
-							    &gtk_sat_list_info,
-							    0);
-	}
+			gtk_sat_list_type = g_type_register_static (GTK_TYPE_VBOX,
+														"GtkSatList",
+														&gtk_sat_list_info,
+														0);
+		}
 
 	return gtk_sat_list_type;
 }
@@ -267,19 +267,19 @@ gtk_sat_list_class_init (GtkSatListClass *class)
 static void
 gtk_sat_list_init (GtkSatList *list)
 {
-/* 	GtkWidget *vbox,*hbox; */
+	/* 	GtkWidget *vbox,*hbox; */
 
 
-/* 	hbox = gtk_hbox_new (TRUE, 5); */
-/* 	gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_label_new ("POLAR")); */
-/* 	gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_label_new ("LIST")); */
+	/* 	hbox = gtk_hbox_new (TRUE, 5); */
+	/* 	gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_label_new ("POLAR")); */
+	/* 	gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_label_new ("LIST")); */
 
-/* 	vbox = gtk_vbox_new (TRUE, 5); */
-/* 	gtk_box_pack_start_defaults (GTK_BOX (vbox), gtk_label_new ("MAP")); */
-/* 	gtk_box_pack_start_defaults (GTK_BOX (vbox), hbox); */
+	/* 	vbox = gtk_vbox_new (TRUE, 5); */
+	/* 	gtk_box_pack_start_defaults (GTK_BOX (vbox), gtk_label_new ("MAP")); */
+	/* 	gtk_box_pack_start_defaults (GTK_BOX (vbox), hbox); */
 
-/* 	gtk_container_add (GTK_CONTAINER (module), vbox); */
-/* 	gtk_widget_show_all (vbox); */
+	/* 	gtk_container_add (GTK_CONTAINER (module), vbox); */
+	/* 	gtk_widget_show_all (vbox); */
 
 	/* initialise data structures */
 
@@ -321,15 +321,15 @@ gtk_sat_list_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth, guint32 colum
 		GTK_SAT_LIST (widget)->flags = columns;
 	else
 		GTK_SAT_LIST (widget)->flags = mod_cfg_get_int (cfgdata,
-								MOD_CFG_LIST_SECTION,
-								MOD_CFG_LIST_COLUMNS,
-								SAT_CFG_INT_LIST_COLUMNS);
+														MOD_CFG_LIST_SECTION,
+														MOD_CFG_LIST_COLUMNS,
+														SAT_CFG_INT_LIST_COLUMNS);
 	
 	/* get refresh rate and cycle counter */
 	GTK_SAT_LIST (widget)->refresh = mod_cfg_get_int (cfgdata,
-							  MOD_CFG_LIST_SECTION,
-							  MOD_CFG_LIST_REFRESH,
-							  SAT_CFG_INT_LIST_REFRESH);
+													  MOD_CFG_LIST_SECTION,
+													  MOD_CFG_LIST_REFRESH,
+													  SAT_CFG_INT_LIST_REFRESH);
 
 	GTK_SAT_LIST (widget)->counter = 1;
 
@@ -337,19 +337,30 @@ gtk_sat_list_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth, guint32 colum
 	GTK_SAT_LIST (widget)->treeview = gtk_tree_view_new ();
 
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (GTK_SAT_LIST (widget)->treeview),
-				      sat_cfg_get_bool (SAT_CFG_BOOL_RULES_HINT));
+								  sat_cfg_get_bool (SAT_CFG_BOOL_RULES_HINT));
 
 	/* create treeview columns */
 	for (i = 0; i < SAT_LIST_COL_NUMBER; i++) {
 
 		renderer = gtk_cell_renderer_text_new ();
 		g_object_set (G_OBJECT (renderer), "xalign", SAT_LIST_COL_XALIGN[i], NULL);
+
+		/* in win32 use special font for direction column because default font
+		   does not have arrow symbols.
+		*/
+#ifdef G_OS_WIN32
+		if (i == SAT_LIST_COL_DIR)
+			g_object_set (G_OBJECT (renderer),
+						  "font", "courier 12",
+						  NULL);
+#endif
+
 		column = gtk_tree_view_column_new_with_attributes (SAT_LIST_COL_TITLE[i],
-								   renderer,
-								   "text", i,
-								   NULL);
+														   renderer,
+														   "text", i,
+														   NULL);
 		gtk_tree_view_insert_column (GTK_TREE_VIEW (GTK_SAT_LIST (widget)->treeview),
-					     column, -1);
+									 column, -1);
 
 		/* only aligns the headers */
 		gtk_tree_view_column_set_alignment (column, 0.5);
@@ -374,23 +385,23 @@ gtk_sat_list_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth, guint32 colum
 
 	/* satellite name should be initial sorting criteria */
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
-					      SAT_LIST_COL_NAME,
-					      GTK_SORT_ASCENDING),
+										  SAT_LIST_COL_NAME,
+										  GTK_SORT_ASCENDING),
 
-	g_object_unref (model);
+		g_object_unref (model);
 
 	g_signal_connect (GTK_SAT_LIST (widget)->treeview, "button-press-event",
-			  G_CALLBACK (button_press_cb), widget);
+					  G_CALLBACK (button_press_cb), widget);
 	g_signal_connect (GTK_SAT_LIST (widget)->treeview, "popup-menu",
-			  G_CALLBACK (popup_menu_cb), widget);
+					  G_CALLBACK (popup_menu_cb), widget);
 
 	GTK_SAT_LIST (widget)->swin = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (GTK_SAT_LIST (widget)->swin),
-					GTK_POLICY_AUTOMATIC,
-					GTK_POLICY_AUTOMATIC);
+									GTK_POLICY_AUTOMATIC,
+									GTK_POLICY_AUTOMATIC);
 
 	gtk_container_add (GTK_CONTAINER (GTK_SAT_LIST (widget)->swin),
-			   GTK_SAT_LIST (widget)->treeview);
+					   GTK_SAT_LIST (widget)->treeview);
 
 	gtk_container_add (GTK_CONTAINER (widget), GTK_SAT_LIST (widget)->swin);
 	gtk_widget_show_all (widget);
@@ -409,31 +420,31 @@ create_and_fill_model   (GHashTable      *sats)
 
 
 	liststore = gtk_list_store_new (SAT_LIST_COL_NUMBER,
-					G_TYPE_STRING,     // name
-					G_TYPE_INT,        // catnum
-					G_TYPE_DOUBLE,     // az
-					G_TYPE_DOUBLE,     // el
-					G_TYPE_STRING,     // direction
-					G_TYPE_DOUBLE,     // RA
-					G_TYPE_DOUBLE,     // Dec
-					G_TYPE_DOUBLE,     // range
-					G_TYPE_DOUBLE,     // range rate
-					G_TYPE_STRING,     // next event
-					G_TYPE_DOUBLE,     // next AOS
-					G_TYPE_DOUBLE,     // next LOS
-					G_TYPE_DOUBLE,     // ssp lat
-					G_TYPE_DOUBLE,     // ssp lon
-					G_TYPE_STRING,     // ssp qra
-					G_TYPE_DOUBLE,     // footprint
-					G_TYPE_DOUBLE,     // alt
-					G_TYPE_DOUBLE,     // vel
-					G_TYPE_DOUBLE,     // doppler
-					G_TYPE_DOUBLE,     // path loss
-					G_TYPE_DOUBLE,     // delay
-					G_TYPE_DOUBLE,     // mean anomaly
-					G_TYPE_DOUBLE,     // phase
-					G_TYPE_ULONG,      // orbit
-					G_TYPE_STRING);    // visibility
+									G_TYPE_STRING,     // name
+									G_TYPE_INT,        // catnum
+									G_TYPE_DOUBLE,     // az
+									G_TYPE_DOUBLE,     // el
+									G_TYPE_STRING,     // direction
+									G_TYPE_DOUBLE,     // RA
+									G_TYPE_DOUBLE,     // Dec
+									G_TYPE_DOUBLE,     // range
+									G_TYPE_DOUBLE,     // range rate
+									G_TYPE_STRING,     // next event
+									G_TYPE_DOUBLE,     // next AOS
+									G_TYPE_DOUBLE,     // next LOS
+									G_TYPE_DOUBLE,     // ssp lat
+									G_TYPE_DOUBLE,     // ssp lon
+									G_TYPE_STRING,     // ssp qra
+									G_TYPE_DOUBLE,     // footprint
+									G_TYPE_DOUBLE,     // alt
+									G_TYPE_DOUBLE,     // vel
+									G_TYPE_DOUBLE,     // doppler
+									G_TYPE_DOUBLE,     // path loss
+									G_TYPE_DOUBLE,     // delay
+									G_TYPE_DOUBLE,     // mean anomaly
+									G_TYPE_DOUBLE,     // phase
+									G_TYPE_ULONG,      // orbit
+									G_TYPE_STRING);    // visibility
 
 
 	g_hash_table_foreach (sats, sat_list_add_satellites, liststore);
@@ -454,32 +465,32 @@ sat_list_add_satellites (gpointer key, gpointer value, gpointer user_data)
 
 	gtk_list_store_append (store, &item);
 	gtk_list_store_set (store, &item,
-			    SAT_LIST_COL_NAME, sat->tle.sat_name,
-			    SAT_LIST_COL_CATNUM, sat->tle.catnr,
-			    SAT_LIST_COL_AZ, sat->az,
-			    SAT_LIST_COL_EL, sat->el,
-			    SAT_LIST_COL_VISIBILITY, "-",
-			    SAT_LIST_COL_RA, sat->ra,
-			    SAT_LIST_COL_DEC, sat->dec,
-			    SAT_LIST_COL_RANGE, sat->range,
-			    SAT_LIST_COL_RANGE_RATE, sat->range_rate,
-			    SAT_LIST_COL_DIR, "-",
-			    SAT_LIST_COL_NEXT_EVENT, "--- N/A ---",
-			    SAT_LIST_COL_AOS, sat->aos,
-			    SAT_LIST_COL_LOS, sat->los,
-			    SAT_LIST_COL_LAT, sat->ssplat,
-			    SAT_LIST_COL_LON, sat->ssplon,
-			    SAT_LIST_COL_SSP, "",
-			    SAT_LIST_COL_FOOTPRINT, sat->footprint,
-			    SAT_LIST_COL_ALT, sat->alt,
-			    SAT_LIST_COL_VEL, sat->velo,
-			    SAT_LIST_COL_DOPPLER, 0.0,
-			    SAT_LIST_COL_LOSS, 0.0,
-			    SAT_LIST_COL_DELAY, 0.0,
-			    SAT_LIST_COL_MA, sat->ma,
-			    SAT_LIST_COL_PHASE, sat->phase,
-			    SAT_LIST_COL_ORBIT, sat->orbit,
-			    -1);
+						SAT_LIST_COL_NAME, sat->tle.sat_name,
+						SAT_LIST_COL_CATNUM, sat->tle.catnr,
+						SAT_LIST_COL_AZ, sat->az,
+						SAT_LIST_COL_EL, sat->el,
+						SAT_LIST_COL_VISIBILITY, "-",
+						SAT_LIST_COL_RA, sat->ra,
+						SAT_LIST_COL_DEC, sat->dec,
+						SAT_LIST_COL_RANGE, sat->range,
+						SAT_LIST_COL_RANGE_RATE, sat->range_rate,
+						SAT_LIST_COL_DIR, "-",
+						SAT_LIST_COL_NEXT_EVENT, "--- N/A ---",
+						SAT_LIST_COL_AOS, sat->aos,
+						SAT_LIST_COL_LOS, sat->los,
+						SAT_LIST_COL_LAT, sat->ssplat,
+						SAT_LIST_COL_LON, sat->ssplon,
+						SAT_LIST_COL_SSP, "",
+						SAT_LIST_COL_FOOTPRINT, sat->footprint,
+						SAT_LIST_COL_ALT, sat->alt,
+						SAT_LIST_COL_VEL, sat->velo,
+						SAT_LIST_COL_DOPPLER, 0.0,
+						SAT_LIST_COL_LOSS, 0.0,
+						SAT_LIST_COL_DELAY, 0.0,
+						SAT_LIST_COL_MA, sat->ma,
+						SAT_LIST_COL_PHASE, sat->phase,
+						SAT_LIST_COL_ORBIT, sat->orbit,
+						-1);
 
 	
 }
@@ -498,8 +509,8 @@ gtk_sat_list_update          (GtkWidget *widget)
 	if ((satlist == NULL) || !IS_GTK_SAT_LIST (satlist)) {
 		
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Invalid GtkSatList!"),
-			     __FUNCTION__);
+					 _("%s: Invalid GtkSatList!"),
+					 __FUNCTION__);
 	}
 
 
@@ -518,16 +529,16 @@ gtk_sat_list_update          (GtkWidget *widget)
 		/* No, we do not do it, because it makes selections and scrolling
 		   impossible
 		*/
-/* 		g_object_ref (model); */
-/* 		gtk_tree_view_set_model (GTK_TREE_VIEW (satlist->treeview), NULL); */
+		/* 		g_object_ref (model); */
+		/* 		gtk_tree_view_set_model (GTK_TREE_VIEW (satlist->treeview), NULL); */
 
 		/* update */
 		gtk_tree_model_foreach (model, sat_list_update_sats, satlist);
 
 		/* re-attach model to view */
-/* 		gtk_tree_view_set_model (GTK_TREE_VIEW (satlist->treeview), model); */
+		/* 		gtk_tree_view_set_model (GTK_TREE_VIEW (satlist->treeview), model); */
 
-/* 		g_object_unref (model); */
+		/* 		g_object_unref (model); */
 	}
 
 }
@@ -536,9 +547,9 @@ gtk_sat_list_update          (GtkWidget *widget)
 /** \brief Update data in each column in a given row */
 static gboolean
 sat_list_update_sats (GtkTreeModel *model,
-		      GtkTreePath  *path,
-		      GtkTreeIter  *iter,
-		      gpointer      data)
+					  GtkTreePath  *path,
+					  GtkTreeIter  *iter,
+					  gpointer      data)
 {
 	GtkSatList *satlist = GTK_SAT_LIST (data);
 	guint      *catnum;
@@ -561,54 +572,54 @@ sat_list_update_sats (GtkTreeModel *model,
 	if (sat == NULL) {
 		/* satellite not tracked anymore => remove */
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s: Failed to get data for #%d."),
-			     __FUNCTION__, *catnum);
+					 _("%s: Failed to get data for #%d."),
+					 __FUNCTION__, *catnum);
 
 		gtk_list_store_remove (GTK_LIST_STORE (model), iter);
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Satellite #%d removed from list."),
-			     __FUNCTION__, *catnum);
+					 _("%s: Satellite #%d removed from list."),
+					 __FUNCTION__, *catnum);
 	}
 	else {
 		/* store new data */
 		gtk_list_store_set (GTK_LIST_STORE (model), iter,
-				    SAT_LIST_COL_AZ, sat->az,
-				    SAT_LIST_COL_EL, sat->el,
-				    SAT_LIST_COL_RANGE, sat->range,
-				    SAT_LIST_COL_RANGE_RATE, sat->range_rate,
-				    SAT_LIST_COL_LAT, sat->ssplat,
-				    SAT_LIST_COL_LON, sat->ssplon,
-				    SAT_LIST_COL_FOOTPRINT, sat->footprint,
-				    SAT_LIST_COL_ALT, sat->alt,
-				    SAT_LIST_COL_VEL, sat->velo,
-				    SAT_LIST_COL_MA, sat->ma,
-				    SAT_LIST_COL_PHASE, sat->phase,
-				    SAT_LIST_COL_ORBIT, sat->orbit,
-				    -1);
+							SAT_LIST_COL_AZ, sat->az,
+							SAT_LIST_COL_EL, sat->el,
+							SAT_LIST_COL_RANGE, sat->range,
+							SAT_LIST_COL_RANGE_RATE, sat->range_rate,
+							SAT_LIST_COL_LAT, sat->ssplat,
+							SAT_LIST_COL_LON, sat->ssplon,
+							SAT_LIST_COL_FOOTPRINT, sat->footprint,
+							SAT_LIST_COL_ALT, sat->alt,
+							SAT_LIST_COL_VEL, sat->velo,
+							SAT_LIST_COL_MA, sat->ma,
+							SAT_LIST_COL_PHASE, sat->phase,
+							SAT_LIST_COL_ORBIT, sat->orbit,
+							-1);
 
 		/* doppler shift @ 100 MHz */
 		if (satlist->flags & SAT_LIST_FLAG_DOPPLER) {
 			doppler = -100.0e06 * (sat->range_rate / 299792.4580); // Hz
 			gtk_list_store_set (GTK_LIST_STORE (model), iter,
-					    SAT_LIST_COL_DOPPLER, doppler,
-					    -1);					    
+								SAT_LIST_COL_DOPPLER, doppler,
+								-1);					    
 		}
 
 		/* delay */
 		if (satlist->flags & SAT_LIST_FLAG_DELAY) {
 			delay   = sat->range / 299.7924580;         // msec 
 			gtk_list_store_set (GTK_LIST_STORE (model), iter,
-					    SAT_LIST_COL_DELAY, delay,
-					    -1);					    
+								SAT_LIST_COL_DELAY, delay,
+								-1);					    
 		}
 
 		/* path loss */
 		if (satlist->flags & SAT_LIST_FLAG_LOSS) {
 			loss    = 72.4 + 20.0*log10(sat->range);               // dB
 			gtk_list_store_set (GTK_LIST_STORE (model), iter,
-					    SAT_LIST_COL_LOSS, loss,
-					    -1);					    
+								SAT_LIST_COL_LOSS, loss,
+								-1);					    
 		}
 
 		/* calculate direction */
@@ -626,8 +637,8 @@ sat_list_update_sats (GtkTreeModel *model,
 			}
 			else if ((sat->range_rate <= 0.001) && (sat->range_rate >= -0.001)) {
 				gtk_tree_model_get (model, iter,
-						    SAT_LIST_COL_RANGE_RATE, &oldrate,
-						    -1);
+									SAT_LIST_COL_RANGE_RATE, &oldrate,
+									-1);
 				/* turning around; don't know which way ? */
 				if (sat->range_rate < oldrate) {
 					/* starting to approach */
@@ -647,8 +658,8 @@ sat_list_update_sats (GtkTreeModel *model,
 			}
 
 			gtk_list_store_set (GTK_LIST_STORE (model), iter,
-					    SAT_LIST_COL_DIR, buff,
-					    -1);
+								SAT_LIST_COL_DIR, buff,
+								-1);
 
 			/* free memory */
 			g_free (buff);
@@ -664,8 +675,8 @@ sat_list_update_sats (GtkTreeModel *model,
 			if (retcode == RIG_OK) {
 				buff[6] = '\0';
 				gtk_list_store_set (GTK_LIST_STORE (model), iter,
-						    SAT_LIST_COL_SSP, buff,
-						    -1);
+									SAT_LIST_COL_SSP, buff,
+									-1);
 			}
 			g_free (buff);
 		}
@@ -680,9 +691,9 @@ sat_list_update_sats (GtkTreeModel *model,
 			sat->dec = Degrees(astro.dec);
 
 			gtk_list_store_set (GTK_LIST_STORE (model), iter,
-					    SAT_LIST_COL_RA, sat->ra,
-					    SAT_LIST_COL_DEC, sat->dec,
-					    -1);
+								SAT_LIST_COL_RA, sat->ra,
+								SAT_LIST_COL_DEC, sat->dec,
+								-1);
 		}
 
 
@@ -690,13 +701,13 @@ sat_list_update_sats (GtkTreeModel *model,
 		/*** FIXME: not necessary to update every time */
 		if (satlist->flags & SAT_LIST_FLAG_AOS) {
 			gtk_list_store_set (GTK_LIST_STORE (model), iter,
-					    SAT_LIST_COL_AOS, sat->aos,
-					    -1);
+								SAT_LIST_COL_AOS, sat->aos,
+								-1);
 		}
 		if (satlist->flags & SAT_LIST_FLAG_LOS) {
 			gtk_list_store_set (GTK_LIST_STORE (model), iter,
-					    SAT_LIST_COL_LOS, sat->los,
-					    -1);
+								SAT_LIST_COL_LOS, sat->los,
+								-1);
 
 		}
 		if (satlist->flags & SAT_LIST_FLAG_NEXT_EVENT) {
@@ -722,8 +733,8 @@ sat_list_update_sats (GtkTreeModel *model,
 	
 			if (number == 0.0) {
 				gtk_list_store_set (GTK_LIST_STORE (model), iter,
-						    SAT_LIST_COL_NEXT_EVENT, "--- N/A ---",
-						    -1);
+									SAT_LIST_COL_NEXT_EVENT, "--- N/A ---",
+									-1);
 			}
 			else {
 
@@ -738,10 +749,10 @@ sat_list_update_sats (GtkTreeModel *model,
 				/* format either local time or UTC depending on check box */
 				if (sat_cfg_get_bool (SAT_CFG_BOOL_USE_LOCAL_TIME))
 					size = strftime (buff, TIME_FORMAT_MAX_LENGTH,
-							 fmtstr, localtime (&t));
+									 fmtstr, localtime (&t));
 				else
 					size = strftime (buff, TIME_FORMAT_MAX_LENGTH,
-							 fmtstr, gmtime (&t));
+									 fmtstr, gmtime (&t));
 		
 				if (size < TIME_FORMAT_MAX_LENGTH)
 					buff[size]='\0';
@@ -749,8 +760,8 @@ sat_list_update_sats (GtkTreeModel *model,
 					buff[TIME_FORMAT_MAX_LENGTH]='\0';
 
 				gtk_list_store_set (GTK_LIST_STORE (model), iter,
-						    SAT_LIST_COL_NEXT_EVENT, buff,
-						    -1);
+									SAT_LIST_COL_NEXT_EVENT, buff,
+									-1);
 
 
 				g_free (fmtstr);
@@ -766,8 +777,8 @@ sat_list_update_sats (GtkTreeModel *model,
 			vis = get_sat_vis (sat, satlist->qth, sat->jul_utc);
 			buff = g_strdup_printf ("%c", vis_to_chr (vis));
 			gtk_list_store_set (GTK_LIST_STORE (model), iter,
-					    SAT_LIST_COL_VISIBILITY, buff,
-					    -1);
+								SAT_LIST_COL_VISIBILITY, buff,
+								-1);
 			g_free (buff);
 		}
 
@@ -787,8 +798,8 @@ sat_list_update_sats (GtkTreeModel *model,
 /** \brief Set cell renderer function. */
 static void
 check_and_set_cell_renderer (GtkTreeViewColumn *column,
-			     GtkCellRenderer   *renderer,
-			     gint               i)
+							 GtkCellRenderer   *renderer,
+							 gint               i)
 {
 
 	switch (i) {
@@ -803,20 +814,20 @@ check_and_set_cell_renderer (GtkTreeViewColumn *column,
 	case SAT_LIST_COL_MA:
 	case SAT_LIST_COL_PHASE:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 degree_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 degree_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 		/* LAT/LON format */
 	case SAT_LIST_COL_LAT:
 	case SAT_LIST_COL_LON:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 latlon_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 latlon_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 		/* distances and velocities */
@@ -824,45 +835,45 @@ check_and_set_cell_renderer (GtkTreeViewColumn *column,
 	case SAT_LIST_COL_ALT:
 	case SAT_LIST_COL_FOOTPRINT:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 distance_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 distance_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case SAT_LIST_COL_VEL:
 	case SAT_LIST_COL_RANGE_RATE:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 range_rate_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 range_rate_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case SAT_LIST_COL_DOPPLER:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 float_to_int_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 float_to_int_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case SAT_LIST_COL_DELAY:
 	case SAT_LIST_COL_LOSS:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 two_dec_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 two_dec_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case SAT_LIST_COL_AOS:
 	case SAT_LIST_COL_LOS:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 event_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 event_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	default:
@@ -884,10 +895,10 @@ check_and_set_cell_renderer (GtkTreeViewColumn *column,
 */
 static void
 latlon_cell_data_function (GtkTreeViewColumn *col,
-			   GtkCellRenderer   *renderer,
-			   GtkTreeModel      *model,
-			   GtkTreeIter       *iter,
-			   gpointer           column)
+						   GtkCellRenderer   *renderer,
+						   GtkTreeModel      *model,
+						   GtkTreeIter       *iter,
+						   gpointer           column)
 {
 	gdouble   number = 0.0;
 	gchar   *buff;
@@ -921,9 +932,9 @@ latlon_cell_data_function (GtkTreeViewColumn *col,
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_BUG,
-				     _("%s:%d: Invalid column: %d"),
-				     __FILE__, __LINE__,
-				     coli);
+						 _("%s:%d: Invalid column: %d"),
+						 __FILE__, __LINE__,
+						 coli);
 			hmf = '?';
 		}
 	}
@@ -931,8 +942,8 @@ latlon_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.2f\302\260%c", number, hmf);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
@@ -940,10 +951,10 @@ latlon_cell_data_function (GtkTreeViewColumn *col,
 /* general floats with 2 digits + degree char */
 static void
 degree_cell_data_function (GtkTreeViewColumn *col,
-			   GtkCellRenderer   *renderer,
-			   GtkTreeModel      *model,
-			   GtkTreeIter       *iter,
-			   gpointer           column)
+						   GtkCellRenderer   *renderer,
+						   GtkTreeModel      *model,
+						   GtkTreeIter       *iter,
+						   gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -954,8 +965,8 @@ degree_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.2f\302\260", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
@@ -963,10 +974,10 @@ degree_cell_data_function (GtkTreeViewColumn *col,
 /* distance and velocity, 0 decimal digits */
 static void
 distance_cell_data_function (GtkTreeViewColumn *col,
-			     GtkCellRenderer   *renderer,
-			     GtkTreeModel      *model,
-			     GtkTreeIter       *iter,
-			     gpointer           column)
+							 GtkCellRenderer   *renderer,
+							 GtkTreeModel      *model,
+							 GtkTreeIter       *iter,
+							 gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -982,8 +993,8 @@ distance_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.0f", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
@@ -992,10 +1003,10 @@ distance_cell_data_function (GtkTreeViewColumn *col,
 */
 static void
 range_rate_cell_data_function (GtkTreeViewColumn *col,
-			       GtkCellRenderer   *renderer,
-			       GtkTreeModel      *model,
-			       GtkTreeIter       *iter,
-			       gpointer           column)
+							   GtkCellRenderer   *renderer,
+							   GtkTreeModel      *model,
+							   GtkTreeIter       *iter,
+							   gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -1011,18 +1022,18 @@ range_rate_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.3f", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
 /* 0 decimal digits */
 static void
 float_to_int_cell_data_function (GtkTreeViewColumn *col,
-				 GtkCellRenderer   *renderer,
-				 GtkTreeModel      *model,
-				 GtkTreeIter       *iter,
-				 gpointer           column)
+								 GtkCellRenderer   *renderer,
+								 GtkTreeModel      *model,
+								 GtkTreeIter       *iter,
+								 gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -1033,18 +1044,18 @@ float_to_int_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.0f", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
 /* 2 decimal digits */
 static void
 two_dec_cell_data_function (GtkTreeViewColumn *col,
-			    GtkCellRenderer   *renderer,
-			    GtkTreeModel      *model,
-			    GtkTreeIter       *iter,
-			    gpointer           column)
+							GtkCellRenderer   *renderer,
+							GtkTreeModel      *model,
+							GtkTreeIter       *iter,
+							gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -1055,8 +1066,8 @@ two_dec_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.2f", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
@@ -1064,10 +1075,10 @@ two_dec_cell_data_function (GtkTreeViewColumn *col,
 /* AOS/LOS; convert julian date to string */
 static void
 event_cell_data_function (GtkTreeViewColumn *col,
-			  GtkCellRenderer   *renderer,
-			  GtkTreeModel      *model,
-			  GtkTreeIter       *iter,
-			  gpointer           column)
+						  GtkCellRenderer   *renderer,
+						  GtkTreeModel      *model,
+						  GtkTreeIter       *iter,
+						  gpointer           column)
 {
 	gdouble    number;
 	gchar      buff[TIME_FORMAT_MAX_LENGTH];
@@ -1081,8 +1092,8 @@ event_cell_data_function (GtkTreeViewColumn *col,
 	
 	if (number == 0.0) {
 		g_object_set (renderer,
-			      "text", "--- N/A ---",
-			      NULL);
+					  "text", "--- N/A ---",
+					  NULL);
 	}
 	else {
 
@@ -1104,8 +1115,8 @@ event_cell_data_function (GtkTreeViewColumn *col,
 			buff[TIME_FORMAT_MAX_LENGTH]='\0';
 
 		g_object_set (renderer,
-			      "text", buff,
-			      NULL);
+					  "text", buff,
+					  NULL);
 
 		g_free (fmtstr);
 	}
@@ -1171,9 +1182,9 @@ button_press_cb (GtkWidget *treeview, GdkEventButton *event, gpointer list)
 
 				/* Get tree path for row that was clicked */
 				if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview),
-								   (gint) event->x,
-								   (gint) event->y,
-								   &path, NULL, NULL, NULL)) {
+												   (gint) event->x,
+												   (gint) event->y,
+												   &path, NULL, NULL, NULL)) {
 					gtk_tree_selection_unselect_all (selection);
 					gtk_tree_selection_select_path (selection, path);
 					gtk_tree_path_free (path);
@@ -1207,28 +1218,28 @@ view_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer list)
 
 
 		gtk_tree_model_get (model, &iter,
-				    SAT_LIST_COL_CATNUM, catnum,
-				    -1);
+							SAT_LIST_COL_CATNUM, catnum,
+							-1);
 
 		sat = SAT (g_hash_table_lookup (GTK_SAT_LIST (list)->satellites, catnum));
 
 		if (sat == NULL) {
 			sat_log_log (SAT_LOG_LEVEL_MSG,
-				     _("%s:%d Failed to get data for %d."),
-				     __FILE__, __LINE__, catnum);
+						 _("%s:%d Failed to get data for %d."),
+						 __FILE__, __LINE__, catnum);
 
 		}
 		else {
 			sat_popup_menu_exec (sat, GTK_SAT_LIST (list)->qth, event,
-					     gtk_widget_get_toplevel (treeview));
+								 gtk_widget_get_toplevel (treeview));
 		}
 
 
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: There is no selection; skip popup."),
-			     __FILE__, __LINE__);
+					 _("%s:%d: There is no selection; skip popup."),
+					 __FILE__, __LINE__);
 	}
 
 	g_free (catnum);
@@ -1239,8 +1250,8 @@ view_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer list)
 static void
 Calculate_RADec (sat_t *sat, qth_t *qth, obs_astro_t *obs_set)
 {
-/* Reference:  Methods of Orbit Determination by  */
-/*                Pedro Ramon Escobal, pp. 401-402 */
+	/* Reference:  Methods of Orbit Determination by  */
+	/*                Pedro Ramon Escobal, pp. 401-402 */
 
 	double phi,theta,sin_theta,cos_theta,sin_phi,cos_phi,
 		az,el,Lxh,Lyh,Lzh,Sx,Ex,Zx,Sy,Ey,Zy,Sz,Ez,Zz,
@@ -1288,3 +1299,11 @@ Calculate_RADec (sat_t *sat, qth_t *qth, obs_astro_t *obs_set)
 }
 
 
+
+
+/** \brief Reload reference to satellites (e.g. after TLE update). */
+void
+gtk_sat_list_reload_sats (GtkWidget *satlist, GHashTable *sats)
+{
+	GTK_SAT_LIST (satlist)->satellites = sats;
+}
