@@ -33,10 +33,12 @@
 #include "gpredict-utils.h"
 #include "mod-mgr.h"
 #include "compat.h"
+#include "gtk-sky-glance.h"
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 #include "gtk-sat-module.h"
+#include "gtk-sat-module-tmg.h"
 #include "gtk-sat-module-popup.h"
 
 
@@ -46,10 +48,11 @@ static void clone_cb         (GtkWidget *menuitem, gpointer data);
 static void docking_state_cb (GtkWidget *menuitem, gpointer data);
 static void screen_state_cb  (GtkWidget *menuitem, gpointer data);
 static void sky_at_glance_cb (GtkWidget *menuitem, gpointer data);
+static void tmgr_cb          (GtkWidget *menuitem, gpointer data);
 static void delete_cb        (GtkWidget *menuitem, gpointer data);
 static void close_cb         (GtkWidget *menuitem, gpointer data);
 static void name_changed     (GtkWidget *widget, gpointer data);
-
+static gint window_delete    (GtkWidget *widget, GdkEvent *event, gpointer data);
 
 
 /** \brief Create and run GtkSatModule popup menu.
@@ -73,8 +76,8 @@ gtk_sat_module_popup (GtkSatModule *module)
 
 	if ((module == NULL) || !IS_GTK_SAT_MODULE (module)) {
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: %s called with NULL parameter!"),
-			     __FILE__, __LINE__, __FUNCTION__);
+					 _("%s:%d: %s called with NULL parameter!"),
+					 __FILE__, __LINE__, __FUNCTION__);
 
 		return;
 	}
@@ -90,7 +93,7 @@ gtk_sat_module_popup (GtkSatModule *module)
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 		gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 		g_signal_connect (menuitem, "activate",
-				  G_CALLBACK (docking_state_cb), module);
+						  G_CALLBACK (docking_state_cb), module);
 	}
 	else {
 
@@ -101,7 +104,7 @@ gtk_sat_module_popup (GtkSatModule *module)
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 		gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 		g_signal_connect (menuitem, "activate",
-				  G_CALLBACK (docking_state_cb), module);
+						  G_CALLBACK (docking_state_cb), module);
 
 	}
 
@@ -109,46 +112,22 @@ gtk_sat_module_popup (GtkSatModule *module)
 
 		menuitem = gtk_image_menu_item_new_with_label (_("Leave fullscreen"));
 		image = gtk_image_new_from_stock (GTK_STOCK_LEAVE_FULLSCREEN,
-						  GTK_ICON_SIZE_MENU);
+										  GTK_ICON_SIZE_MENU);
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 		gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 		g_signal_connect (menuitem, "activate",
-				  G_CALLBACK (screen_state_cb), module);
+						  G_CALLBACK (screen_state_cb), module);
 	}
 	else {
 		menuitem = gtk_image_menu_item_new_with_label (_("Fullscreen"));
 		image = gtk_image_new_from_stock (GTK_STOCK_FULLSCREEN,
-						  GTK_ICON_SIZE_MENU);
+										  GTK_ICON_SIZE_MENU);
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 		gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 		g_signal_connect (menuitem, "activate",
-				  G_CALLBACK (screen_state_cb), module);
+						  G_CALLBACK (screen_state_cb), module);
 	}
 
-
-	/* separator */
-	menuitem = gtk_separator_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
-
-	/* configure */
-	menuitem = gtk_image_menu_item_new_with_label (_("Configure"));
-	image = gtk_image_new_from_stock (GTK_STOCK_PROPERTIES,
-					  GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
-	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
-	g_signal_connect (menuitem, "activate",
-			  G_CALLBACK (config_cb), module);
-
-	/* clone */
-	menuitem = gtk_image_menu_item_new_with_label (_("Clone..."));
-	image = gtk_image_new_from_stock (GTK_STOCK_COPY,
-					  GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
-	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
-	g_signal_connect (menuitem, "activate",
-			  G_CALLBACK (clone_cb), module);
-
-#if 0
 	/* separator */
 	menuitem = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
@@ -161,8 +140,39 @@ gtk_sat_module_popup (GtkSatModule *module)
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 	g_signal_connect (menuitem, "activate",
-			  G_CALLBACK (sky_at_glance_cb), module);
-#endif
+					  G_CALLBACK (sky_at_glance_cb), module);
+
+	/* time manager */
+	menuitem = gtk_image_menu_item_new_with_label (_("Time Controller"));
+	buff = icon_file_name ("gpredict-clock-small.png");
+	image = gtk_image_new_from_file (buff);
+	g_free (buff);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+	g_signal_connect (menuitem, "activate", G_CALLBACK (tmgr_cb), module);
+
+
+	/* separator */
+	menuitem = gtk_separator_menu_item_new ();
+	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+
+	/* configure */
+	menuitem = gtk_image_menu_item_new_with_label (_("Configure"));
+	image = gtk_image_new_from_stock (GTK_STOCK_PROPERTIES,
+									  GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+	g_signal_connect (menuitem, "activate",
+					  G_CALLBACK (config_cb), module);
+
+	/* clone */
+	menuitem = gtk_image_menu_item_new_with_label (_("Clone..."));
+	image = gtk_image_new_from_stock (GTK_STOCK_COPY,
+									  GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+	g_signal_connect (menuitem, "activate",
+					  G_CALLBACK (clone_cb), module);
 
 	/* separator */
 	menuitem = gtk_separator_menu_item_new ();
@@ -171,25 +181,25 @@ gtk_sat_module_popup (GtkSatModule *module)
 	/* delete module */
 	menuitem = gtk_image_menu_item_new_with_label (_("Delete"));
 	image = gtk_image_new_from_stock (GTK_STOCK_DELETE,
-					  GTK_ICON_SIZE_MENU);
+									  GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 	g_signal_connect (menuitem, "activate",
-			  G_CALLBACK (delete_cb), module);
+					  G_CALLBACK (delete_cb), module);
 
 	/* close */
 	menuitem = gtk_image_menu_item_new_with_label (_("Close"));
 	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-					  GTK_ICON_SIZE_MENU);
+									  GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 	g_signal_connect (menuitem, "activate",
-			  G_CALLBACK (close_cb), module);
+					  G_CALLBACK (close_cb), module);
 
 	gtk_widget_show_all (menu);
 
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
-			0, gdk_event_get_time (NULL));
+					0, gdk_event_get_time (NULL));
 }
 
 
@@ -235,14 +245,14 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 
 
 	dialog = gtk_dialog_new_with_buttons (_("Clone Module"),
-					      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (module))),
-					      GTK_DIALOG_MODAL |
-					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CANCEL,
-					      GTK_RESPONSE_CANCEL,
-					      GTK_STOCK_OK,
-					      GTK_RESPONSE_OK,
-					      NULL);
+										  GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (module))),
+										  GTK_DIALOG_MODAL |
+										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  GTK_STOCK_CANCEL,
+										  GTK_RESPONSE_CANCEL,
+										  GTK_STOCK_OK,
+										  GTK_RESPONSE_OK,
+										  NULL);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
 	/* label */
@@ -255,22 +265,22 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 	gtk_entry_set_text (GTK_ENTRY (entry), module->name);
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, entry,
-			      _("Enter a short name for this module.\n"\
-				"Allowed charachters: 0..9, a..z, A..Z, - and _"),
-			      _("The name will be used to identify the module "\
-				"and it is also used a file name for saving the data."\
-				"Max length is 25 charachters."));
+						  _("Enter a short name for this module.\n"\
+							"Allowed charachters: 0..9, a..z, A..Z, - and _"),
+						  _("The name will be used to identify the module "\
+							"and it is also used a file name for saving the data."\
+							"Max length is 25 charachters."));
 
 	/* attach changed signal so that we can enable OK button when
 	   a proper name has been entered
 	   oh, btw. disable OK button to begin with....
 	*/
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-					   GTK_RESPONSE_OK,
-					   FALSE);
+									   GTK_RESPONSE_OK,
+									   FALSE);
 	g_signal_connect (entry, "changed", G_CALLBACK (name_changed), dialog);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-			    entry, FALSE, FALSE, 0);
+						entry, FALSE, FALSE, 0);
 
 
 	/* check button */
@@ -278,11 +288,11 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), TRUE);
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, toggle,
-			      _("If checked, the new module will be opened "\
-				"after it has been created"),
-			      NULL);
+						  _("If checked, the new module will be opened "\
+							"after it has been created"),
+						  NULL);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-			    toggle, FALSE, FALSE, 20);
+						toggle, FALSE, FALSE, 20);
 	
 
 	gtk_widget_show_all (GTK_DIALOG (dialog)->vbox);
@@ -294,31 +304,31 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 
 	case GTK_RESPONSE_OK:
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s:%d: Cloning %s => %s"),
-			     __FILE__, __LINE__, module->name,
-			     gtk_entry_get_text (GTK_ENTRY (entry)));
+					 _("%s:%d: Cloning %s => %s"),
+					 __FILE__, __LINE__, module->name,
+					 gtk_entry_get_text (GTK_ENTRY (entry)));
 
 		/* build full file names */
 		source = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-				      ".gpredict2", G_DIR_SEPARATOR_S,
-				      "modules", G_DIR_SEPARATOR_S,
-				      module->name, ".mod", NULL);
+							  ".gpredict2", G_DIR_SEPARATOR_S,
+							  "modules", G_DIR_SEPARATOR_S,
+							  module->name, ".mod", NULL);
 		target = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-				      ".gpredict2", G_DIR_SEPARATOR_S,
-				      "modules", G_DIR_SEPARATOR_S,
-				      gtk_entry_get_text (GTK_ENTRY (entry)),
-				      ".mod", NULL);
+							  ".gpredict2", G_DIR_SEPARATOR_S,
+							  "modules", G_DIR_SEPARATOR_S,
+							  gtk_entry_get_text (GTK_ENTRY (entry)),
+							  ".mod", NULL);
 
 		/* copy file */
 		if (gpredict_file_copy (source, target)) {
 			sat_log_log (SAT_LOG_LEVEL_ERROR,
-				     _("%s:%d: Failed to clone %s."),
-				     __FILE__, __LINE__, module->name);
+						 _("%s:%d: Failed to clone %s."),
+						 __FILE__, __LINE__, module->name);
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_MSG,
-				     _("%s:%d: Successfully cloned %s."),
-				     __FILE__, __LINE__, module->name);
+						 _("%s:%d: Successfully cloned %s."),
+						 __FILE__, __LINE__, module->name);
 
 			/* open module if requested */
 			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggle))) {
@@ -337,18 +347,18 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 					/* create window */
 					newmod->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 					gtk_window_set_title (GTK_WINDOW (newmod->win),
-							      newmod->name);
+										  newmod->name);
 
 					/* use size of source module */
 					gtk_window_set_default_size (GTK_WINDOW (newmod->win),
-								     GTK_WIDGET (module)->allocation.width,
-								     GTK_WIDGET (module)->allocation.height);
+												 GTK_WIDGET (module)->allocation.width,
+												 GTK_WIDGET (module)->allocation.height);
 
 					/** FIXME: window icon and such */
 
 					/* add module to window */
 					gtk_container_add (GTK_CONTAINER (newmod->win),
-							   GTK_WIDGET (newmod));
+									   GTK_WIDGET (newmod));
 
 					if (newmod->state == GTK_SAT_MOD_STATE_FULLSCREEN) {
 						gtk_window_fullscreen (GTK_WINDOW (newmod->win));
@@ -369,14 +379,14 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 
 	case GTK_RESPONSE_CANCEL:
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s:%d: Cloning cancelled by user."),
-			     __FILE__, __LINE__);
+					 _("%s:%d: Cloning cancelled by user."),
+					 __FILE__, __LINE__);
 		break;
 
 	default:
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s:%d: Cloning interrupted."),
-			     __FILE__, __LINE__);
+					 _("%s:%d: Cloning interrupted."),
+					 __FILE__, __LINE__);
 		break;
 	}
 
@@ -424,7 +434,7 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 		/* create window */
 		GTK_SAT_MODULE (module)->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 		gtk_window_set_title (GTK_WINDOW (GTK_SAT_MODULE (module)->win),
-				      GTK_SAT_MODULE (module)->name);
+							  GTK_SAT_MODULE (module)->name);
 		gtk_window_set_default_size (GTK_WINDOW (GTK_SAT_MODULE (module)->win), w, h);
 
 		/** FIXME: window icon and such */
@@ -441,6 +451,8 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 		/* show window */
 		gtk_widget_show_all (GTK_SAT_MODULE (module)->win);
 
+		/* reparent time manager window if visible */
+		/* gtk_window_Set_transient_for */
 
 		break;
 
@@ -455,7 +467,7 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 			GTK_SAT_MODULE (module)->vpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->vpaned));
 		}
 		else if ((GTK_SAT_MODULE (module)->layout == GTK_SAT_MOD_LAYOUT_3) ||
-			 (GTK_SAT_MODULE (module)->layout == GTK_SAT_MOD_LAYOUT_4)) {
+				 (GTK_SAT_MODULE (module)->layout == GTK_SAT_MOD_LAYOUT_4)) {
 
 			GTK_SAT_MODULE (module)->vpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->vpaned));
 			GTK_SAT_MODULE (module)->hpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->hpaned));
@@ -475,14 +487,17 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 		/* decrease reference count of module */
 		g_object_unref (module);
 
+		/* reparent time manager window if visible */
+		/* gtk_window_Set_transient_for */
+
 
 		break;
 
 	default:
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: Unknown module satate: %d"),
-			     __FILE__, __LINE__, GTK_SAT_MODULE (module)->state);
+					 _("%s:%d: Unknown module satate: %d"),
+					 __FILE__, __LINE__, GTK_SAT_MODULE (module)->state);
 		break;
 
 	}
@@ -520,7 +535,7 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 		/* create window */
 		GTK_SAT_MODULE (module)->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 		gtk_window_set_title (GTK_WINDOW (GTK_SAT_MODULE (module)->win),
-				      GTK_SAT_MODULE (module)->name);
+							  GTK_SAT_MODULE (module)->name);
 
 		/* add module to window */
 		gtk_container_add (GTK_CONTAINER (GTK_SAT_MODULE (module)->win), module);
@@ -560,7 +575,7 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 			GTK_SAT_MODULE (module)->vpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->vpaned));
 		}
 		else if ((GTK_SAT_MODULE (module)->layout == GTK_SAT_MOD_LAYOUT_3) ||
-			 (GTK_SAT_MODULE (module)->layout == GTK_SAT_MOD_LAYOUT_4)) {
+				 (GTK_SAT_MODULE (module)->layout == GTK_SAT_MOD_LAYOUT_4)) {
 
 			GTK_SAT_MODULE (module)->vpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->vpaned));
 			GTK_SAT_MODULE (module)->hpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->hpaned));
@@ -575,8 +590,8 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 	default:
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: Unknown module satate: %d"),
-			     __FILE__, __LINE__, GTK_SAT_MODULE (module)->state);
+					 _("%s:%d: Unknown module satate: %d"),
+					 __FILE__, __LINE__, GTK_SAT_MODULE (module)->state);
 		break;
 
 	}
@@ -593,10 +608,48 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 static void
 sky_at_glance_cb (GtkWidget *menuitem, gpointer data)
 {
-	g_print ("FIXME: SKY_AT_GLANCE not implemented\n");
+	GtkSatModule *module = GTK_SAT_MODULE (data);
+	GtkWidget    *skg;
+	GtkWidget    *window;
+	gchar        *buff;
+
+
+	/* create window */
+	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	buff = g_strdup_printf (_("The sky at a glance (%s)"), module->name);
+	gtk_window_set_title (GTK_WINDOW (window), buff);
+	g_free (buff);
+	g_signal_connect (G_OBJECT (window), "delete_event", G_CALLBACK (window_delete), NULL);    
+
+	/* window icon */
+	buff = icon_file_name ("gpredict-planner.png");
+	gtk_window_set_icon_from_file (GTK_WINDOW (window), buff, NULL);
+	g_free (buff);
+
+	/* if module is busy wait until done then go on */
+	while (module->busy)
+		g_usleep (1000);
+
+	/* create sky at a glance widget */
+	module->busy = TRUE;
+	skg = gtk_sky_glance_new (module->satellites, module->qth);
+	module->busy = FALSE;
+
+	gtk_container_set_border_width (GTK_CONTAINER (window), 10);
+	gtk_container_add (GTK_CONTAINER (window), skg);
+
+	gtk_widget_show_all (window);
+
 }
 
+/** \brief Open time manager. */
+static void
+tmgr_cb          (GtkWidget *menuitem, gpointer data)
+{
+	GtkSatModule *module = GTK_SAT_MODULE (data);
 
+	tmg_create (module);
+}
 
 /** \brief Close module.
  *
@@ -626,9 +679,9 @@ delete_cb         (GtkWidget *menuitem, gpointer data)
 
 
 	file = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-			    ".gpredict2", G_DIR_SEPARATOR_S,
-			    "modules", G_DIR_SEPARATOR_S,
-			    GTK_SAT_MODULE (data)->name, ".mod", NULL);
+						".gpredict2", G_DIR_SEPARATOR_S,
+						"modules", G_DIR_SEPARATOR_S,
+						GTK_SAT_MODULE (data)->name, ".mod", NULL);
 
 	gtk_sat_module_close_cb (menuitem, data);
 
@@ -649,13 +702,13 @@ delete_cb         (GtkWidget *menuitem, gpointer data)
 
 		if (g_remove (file)) {
 			sat_log_log (SAT_LOG_LEVEL_ERROR,
-				     _("%s:%d: Failed to delete %s."),
-				     __FILE__, __LINE__, file);
+						 _("%s:%d: Failed to delete %s."),
+						 __FILE__, __LINE__, file);
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_ERROR,
-				     _("%s:%d: %s deleted permanently."),
-				     __FILE__, __LINE__, file);
+						 _("%s:%d: %s deleted permanently."),
+						 __FILE__, __LINE__, file);
 		}
 		break;
 
@@ -685,31 +738,31 @@ name_changed          (GtkWidget *widget, gpointer data)
 
 
 	/* step 1: ensure that only valid characters are entered
-	           (stolen from xlog, tnx pg4i)
+	   (stolen from xlog, tnx pg4i)
 	*/
 	entry = gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1);
 	if ((len = g_utf8_strlen (entry, -1)) > 0)
-	{
-		end = entry + g_utf8_strlen (entry, -1);
-		for (j = entry; j < end; ++j)
 		{
-			switch (*j)
-			{
-				case '0' ... '9':
-				case 'a' ... 'z':
-				case 'A' ... 'Z':
-				case '-':
-				case '_':
-					break;
-				default:
-					gdk_beep ();
-					pos = gtk_editable_get_position (GTK_EDITABLE (widget));
-					gtk_editable_delete_text (GTK_EDITABLE (widget),
-								  pos, pos+1);
-					break;
-			}
+			end = entry + g_utf8_strlen (entry, -1);
+			for (j = entry; j < end; ++j)
+				{
+					switch (*j)
+						{
+						case '0' ... '9':
+						case 'a' ... 'z':
+						case 'A' ... 'Z':
+						case '-':
+						case '_':
+							break;
+						default:
+							gdk_beep ();
+							pos = gtk_editable_get_position (GTK_EDITABLE (widget));
+							gtk_editable_delete_text (GTK_EDITABLE (widget),
+													  pos, pos+1);
+							break;
+						}
+				}
 		}
-	}
 
 
 	/* step 2: if name seems all right, enable OK button */
@@ -717,13 +770,24 @@ name_changed          (GtkWidget *widget, gpointer data)
 
 	if (g_utf8_strlen (text, -1) > 0) {
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-						   GTK_RESPONSE_OK,
-						   TRUE);
+										   GTK_RESPONSE_OK,
+										   TRUE);
 	}
 	else {
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-						   GTK_RESPONSE_OK,
-						   FALSE);
+										   GTK_RESPONSE_OK,
+										   FALSE);
 	}
 }
 
+
+
+
+/* ensure that deleted top-level windows are destroyed */
+static gint
+window_delete      (GtkWidget *widget,
+					GdkEvent  *event,
+					gpointer   data)
+{
+	return FALSE;
+}
