@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 /** \brief Main module container.
  *
@@ -58,37 +58,41 @@
 #include "predict-tools.h"
 #include "gtk-sat-module.h"
 #include "gtk-sat-module-popup.h"
+#include "gtk-sat-module-tmg.h"
 #include "gtk-sat-list.h"
 #include "gtk-sat-map.h"
 #include "gtk-polar-view.h"
 #include "gtk-single-sat.h"
-
+//#ifdef G_OS_WIN32
+//#  include "libc_internal.h"
+//#  include "libc_interface.h"
+//#endif
 
 static void     gtk_sat_module_class_init     (GtkSatModuleClass   *class);
 static void     gtk_sat_module_init           (GtkSatModule        *module);
 static void     gtk_sat_module_destroy        (GtkObject           *object);
 static void     gtk_sat_module_read_cfg_data  (GtkSatModule *module,
-					       const gchar *cfgfile);
+											   const gchar *cfgfile);
 
 static void     gtk_sat_module_load_sats      (GtkSatModule *module);
 /* static gboolean gtk_sat_module_sats_are_equal (gconstpointer a, */
 /* 					       gconstpointer b); */
 static gboolean gtk_sat_module_timeout_cb     (gpointer module);
 static void     gtk_sat_module_update_sat     (gpointer key,
-					       gpointer val,
-					       gpointer data);
+											   gpointer val,
+											   gpointer data);
 static void     gtk_sat_module_popup_cb       (GtkWidget *button,
-					       gpointer data);
+											   gpointer data);
 
 static void     update_header                 (GtkSatModule *module);
-static void     update_child                  (GtkWidget *child);
+static void     update_child                  (GtkWidget *child, gdouble tstamp);
 static void     create_module_layout          (GtkSatModule *module);
 
 static GtkWidget *create_view                 (GtkSatModule *module, guint num);
 
 static void     fix_child_allocations   (GtkWidget *widget, gpointer data);
 
-
+static void     reload_sats_in_child (GtkWidget *widget, GtkSatModule *module);
 
 
 static GtkVBoxClass *parent_class = NULL;
@@ -99,25 +103,23 @@ gtk_sat_module_get_type ()
 {
 	static GType gtk_sat_module_type = 0;
 
-	if (!gtk_sat_module_type)
-	{
-		static const GTypeInfo gtk_sat_module_info =
-			{
-				sizeof (GtkSatModuleClass),
-				NULL,  /* base_init */
-				NULL,  /* base_finalize */
-				(GClassInitFunc) gtk_sat_module_class_init,
-				NULL,  /* class_finalize */
-				NULL,  /* class_data */
-				sizeof (GtkSatModule),
-				5,     /* n_preallocs */
-				(GInstanceInitFunc) gtk_sat_module_init,
-			};
+	if (!gtk_sat_module_type) {
+		static const GTypeInfo gtk_sat_module_info = {
+			sizeof (GtkSatModuleClass),
+			NULL,  /* base_init */
+			NULL,  /* base_finalize */
+			(GClassInitFunc) gtk_sat_module_class_init,
+			NULL,  /* class_finalize */
+			NULL,  /* class_data */
+			sizeof (GtkSatModule),
+			5,     /* n_preallocs */
+			(GInstanceInitFunc) gtk_sat_module_init,
+		};
 
 		gtk_sat_module_type = g_type_register_static (GTK_TYPE_VBOX,
-							      "GtkSatModule",
-							      &gtk_sat_module_info,
-							      0);
+													  "GtkSatModule",
+													  &gtk_sat_module_info,
+													  0);
 	}
 
 	return gtk_sat_module_type;
@@ -152,7 +154,7 @@ gtk_sat_module_init (GtkSatModule *module)
 	/* initialise data structures */
 	module->win = NULL;
 
-	module->qth = g_try_malloc (sizeof (qth_t));
+	module->qth = g_try_new0 (qth_t, 1);
 	module->qth->lat = 0.0;
 	module->qth->lon = 0.0;
 	module->qth->alt = 0;
@@ -173,8 +175,17 @@ gtk_sat_module_init (GtkSatModule *module)
 
 	module->vpanedpos = -1;
 	module->hpanedpos = -1;
+
+	module->throttle = 1;
+	module->rtNow = 0.0;
+	module->rtPrev = 0.0;
+	module->tmgActive = FALSE;
+	module->tmgPdnum = 0.0;
+	module->tmgCdnum = 0.0;
+	module->tmgReset = FALSE;
 }
 
+
 static void
 gtk_sat_module_destroy (GtkObject *object)
 {
@@ -184,12 +195,18 @@ gtk_sat_module_destroy (GtkObject *object)
 	if (module->timerid != -1)
 		g_source_remove (module->timerid);
 
+	/* destroy time controller */
+	if (module->tmgActive) {
+		gtk_widget_destroy (module->tmgWin);
+		module->tmgActive = FALSE;
+	}
+
 	/* FIXME: save state */
 
-	/* FIXME: save and free cfg data */
-
-	/* FIXME: this one crashes too */
-	//	gtk_sat_data_free_qth (module->qth);
+	if (module->qth) {
+		gtk_sat_data_free_qth (module->qth);
+		module->qth = NULL;
+	}
 
 	if (module->satellites) {
 		g_hash_table_destroy (module->satellites);
@@ -197,7 +214,6 @@ gtk_sat_module_destroy (GtkObject *object)
 	}
 
 	(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-
 }
 
 
@@ -229,8 +245,8 @@ gtk_sat_module_new (const gchar *cfgfile)
 	if ((cfgfile == NULL) || !g_file_test (cfgfile, G_FILE_TEST_EXISTS)) {
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Module %s is not valid."),
-			     __FUNCTION__, cfgfile);
+					 _("%s: Module %s is not valid."),
+					 __FUNCTION__, cfgfile);
 
 		return NULL;
 	}
@@ -239,7 +255,7 @@ gtk_sat_module_new (const gchar *cfgfile)
 	widget = g_object_new (GTK_TYPE_SAT_MODULE, NULL);
 
 	g_signal_connect (widget, "realize",
-			  G_CALLBACK (fix_child_allocations), NULL);
+					  G_CALLBACK (fix_child_allocations), NULL);
 
 	/* load configuration; note that this will also set the module name */
 	gtk_sat_module_read_cfg_data (GTK_SAT_MODULE (widget), cfgfile);
@@ -248,6 +264,13 @@ gtk_sat_module_new (const gchar *cfgfile)
 	/* FIXME: may want to put in own window */
 	GTK_SAT_MODULE (widget)->state = GTK_SAT_MOD_STATE_DOCKED;
 
+	/* initialise time keeping vars to current time */
+	GTK_SAT_MODULE (widget)->rtNow = get_current_daynum ();
+	GTK_SAT_MODULE (widget)->rtPrev = get_current_daynum ();
+	GTK_SAT_MODULE (widget)->tmgPdnum = get_current_daynum ();
+	GTK_SAT_MODULE (widget)->tmgCdnum = get_current_daynum ();
+
+
 	/* load satellites */
 	gtk_sat_module_load_sats (GTK_SAT_MODULE (widget));
 	
@@ -285,14 +308,14 @@ gtk_sat_module_new (const gchar *cfgfile)
 
 	butbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (butbox),
-			    GTK_SAT_MODULE (widget)->header,
-			    FALSE, FALSE, 10);
+						GTK_SAT_MODULE (widget)->header,
+						FALSE, FALSE, 10);
 	gtk_box_pack_end (GTK_BOX (butbox),
-			  GTK_SAT_MODULE (widget)->close_button,
-			  FALSE, FALSE, 0);
+					  GTK_SAT_MODULE (widget)->close_button,
+					  FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (butbox),
-			  GTK_SAT_MODULE (widget)->popup_button,
-			  FALSE, FALSE, 0);
+					  GTK_SAT_MODULE (widget)->popup_button,
+					  FALSE, FALSE, 0);
 
 	gtk_box_pack_start (GTK_BOX (widget), butbox, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (widget), gtk_hseparator_new (), FALSE, FALSE, 0);
@@ -304,8 +327,8 @@ gtk_sat_module_new (const gchar *cfgfile)
 
 	/* start timeout */
 	GTK_SAT_MODULE(widget)->timerid = g_timeout_add (GTK_SAT_MODULE(widget)->timeout,
-							 gtk_sat_module_timeout_cb,
-							 widget);
+													 gtk_sat_module_timeout_cb,
+													 widget);
 	
 
 	return widget;
@@ -342,11 +365,9 @@ create_module_layout (GtkSatModule *module)
 		module->child_3 = NULL;
 
 		gtk_paned_pack1 (GTK_PANED (module->vpaned),
-				 module->child_1, TRUE, TRUE);
+						 module->child_1, TRUE, TRUE);
 		gtk_paned_pack2 (GTK_PANED (module->vpaned),
-				 module->child_2, TRUE, TRUE);
-
-		gtk_container_add (GTK_CONTAINER (module), module->vpaned);
+						 module->child_2, TRUE, TRUE);
 
 		break;
 
@@ -356,19 +377,19 @@ create_module_layout (GtkSatModule *module)
 		module->hpaned = gtk_hpaned_new ();
 		gtk_container_add (GTK_CONTAINER (module), module->vpaned);
 		gtk_paned_pack2 (GTK_PANED (module->vpaned),
-				 module->hpaned,
-				 TRUE, TRUE);
+						 module->hpaned,
+						 TRUE, TRUE);
 
 		module->child_1 = create_view (module, 1);
 		module->child_2 = create_view (module, 2);
 		module->child_3 = create_view (module, 3);
 
 		gtk_paned_pack1 (GTK_PANED (module->vpaned),
-				 module->child_1, TRUE, TRUE);
+						 module->child_1, TRUE, TRUE);
 		gtk_paned_pack1 (GTK_PANED (module->hpaned),
-				 module->child_2, TRUE, TRUE);
+						 module->child_2, TRUE, TRUE);
 		gtk_paned_pack2 (GTK_PANED (module->hpaned),
-				 module->child_3, TRUE, TRUE);
+						 module->child_3, TRUE, TRUE);
 
 		break;
 
@@ -378,26 +399,26 @@ create_module_layout (GtkSatModule *module)
 		module->hpaned = gtk_hpaned_new ();
 		gtk_container_add (GTK_CONTAINER (module), module->vpaned);
 		gtk_paned_pack1 (GTK_PANED (module->vpaned),
-				 module->hpaned,
-				 TRUE, TRUE);
+						 module->hpaned,
+						 TRUE, TRUE);
 
 		module->child_1 = create_view (module, 1);
 		module->child_2 = create_view (module, 2);
 		module->child_3 = create_view (module, 3);
 
 		gtk_paned_pack1 (GTK_PANED (module->hpaned),
-				 module->child_1, TRUE, TRUE);
+						 module->child_1, TRUE, TRUE);
 		gtk_paned_pack2 (GTK_PANED (module->hpaned),
-				 module->child_2, TRUE, TRUE);
+						 module->child_2, TRUE, TRUE);
 		gtk_paned_pack2 (GTK_PANED (module->vpaned),
-				 module->child_3, TRUE, TRUE);
+						 module->child_3, TRUE, TRUE);
 
 		break;
 
 	default:
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: Invalid module layout (%d)"),
-			     __FILE__, __LINE__, module->layout);
+					 _("%s:%d: Invalid module layout (%d)"),
+					 __FILE__, __LINE__, module->layout);
 		break;
 
 	}
@@ -423,8 +444,8 @@ create_view (GtkSatModule *module, guint num)
 		break;
 	default:
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: Invalid child number (%d)"),
-			     __FILE__, __LINE__, num);
+					 _("%s:%d: Invalid child number (%d)"),
+					 __FILE__, __LINE__, num);
 		break;
 	}
 
@@ -433,38 +454,38 @@ create_view (GtkSatModule *module, guint num)
 
 	case GTK_SAT_MOD_VIEW_LIST:
 		view = gtk_sat_list_new (module->cfgdata,
-					 module->satellites,
-					 module->qth,
-					 0);
+								 module->satellites,
+								 module->qth,
+								 0);
 		break;
 
 	case GTK_SAT_MOD_VIEW_MAP:
 		view = gtk_sat_map_new (module->cfgdata,
-					module->satellites,
-					module->qth);
+								module->satellites,
+								module->qth);
 		break;
 
 	case GTK_SAT_MOD_VIEW_POLAR:
 		view = gtk_polar_view_new (module->cfgdata,
-					   module->satellites,
-					   module->qth);
+								   module->satellites,
+								   module->qth);
 		break;
 
 	case GTK_SAT_MOD_VIEW_SINGLE:
 		view = gtk_single_sat_new (module->cfgdata,
-					   module->satellites,
-					   module->qth,
-					   0);
+								   module->satellites,
+								   module->qth,
+								   0);
 		break;
 	default:
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: Invalid child type (%d)\nUsing GtkSatList..."),
-			     __FILE__, __LINE__, num);
+					 _("%s:%d: Invalid child type (%d)\nUsing GtkSatList..."),
+					 __FILE__, __LINE__, num);
 
 		view = gtk_sat_list_new (module->cfgdata,
-					 module->satellites,
-					 module->qth,
-					 0);
+								 module->satellites,
+								 module->qth,
+								 0);
 		break;
 
 	}
@@ -492,13 +513,13 @@ gtk_sat_module_read_cfg_data (GtkSatModule *module, const gchar *cfgfile)
 
 	/* Bail out with error message if data can not be read */
 	if (!g_key_file_load_from_file (module->cfgdata, cfgfile,
-					G_KEY_FILE_KEEP_COMMENTS, &error)) {
+									G_KEY_FILE_KEEP_COMMENTS, &error)) {
 
 		g_key_file_free (module->cfgdata);
 
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Could not load config data from %s (%s)."),
-			     __FUNCTION__, cfgfile, error->message);
+					 _("%s: Could not load config data from %s (%s)."),
+					 __FUNCTION__, cfgfile, error->message);
 		
 		g_clear_error (&error);
 
@@ -507,8 +528,8 @@ gtk_sat_module_read_cfg_data (GtkSatModule *module, const gchar *cfgfile)
 
 	/* debug message */
 	sat_log_log (SAT_LOG_LEVEL_DEBUG,
-		     _("%s: Reading configuration from %s"),
-		     __FUNCTION__, cfgfile);
+				 _("%s: Reading configuration from %s"),
+				 __FUNCTION__, cfgfile);
 
 	/* set module name */
 	buffer = g_path_get_basename (cfgfile);
@@ -569,39 +590,33 @@ gtk_sat_module_read_cfg_data (GtkSatModule *module, const gchar *cfgfile)
 
 	/* get timeout value */
 	module->timeout = mod_cfg_get_int (module->cfgdata,
-					   MOD_CFG_GLOBAL_SECTION,
-					   MOD_CFG_TIMEOUT_KEY,
-					   SAT_CFG_INT_MODULE_TIMEOUT);
-
-	/* get warp factor */
-	module->warp = mod_cfg_get_int (module->cfgdata,
-					MOD_CFG_GLOBAL_SECTION,
-					MOD_CFG_WARP_KEY,
-					SAT_CFG_INT_WARP_FACTOR);
+									   MOD_CFG_GLOBAL_SECTION,
+									   MOD_CFG_TIMEOUT_KEY,
+									   SAT_CFG_INT_MODULE_TIMEOUT);
 
 	/* layout */
 	module->layout = mod_cfg_get_int (module->cfgdata,
-					  MOD_CFG_GLOBAL_SECTION,
-					  MOD_CFG_LAYOUT,
-					  SAT_CFG_INT_MODULE_LAYOUT);
+									  MOD_CFG_GLOBAL_SECTION,
+									  MOD_CFG_LAYOUT,
+									  SAT_CFG_INT_MODULE_LAYOUT);
 
 	/* view 1 */
 	module->view_1 = mod_cfg_get_int (module->cfgdata,
-					  MOD_CFG_GLOBAL_SECTION,
-					  MOD_CFG_VIEW_1,
-					  SAT_CFG_INT_MODULE_VIEW_1);
+									  MOD_CFG_GLOBAL_SECTION,
+									  MOD_CFG_VIEW_1,
+									  SAT_CFG_INT_MODULE_VIEW_1);
 
 	/* view 2 */
 	module->view_2 = mod_cfg_get_int (module->cfgdata,
-					  MOD_CFG_GLOBAL_SECTION,
-					  MOD_CFG_VIEW_2,
-					  SAT_CFG_INT_MODULE_VIEW_2);
+									  MOD_CFG_GLOBAL_SECTION,
+									  MOD_CFG_VIEW_2,
+									  SAT_CFG_INT_MODULE_VIEW_2);
 
 	/* view 3 */
 	module->view_3 = mod_cfg_get_int (module->cfgdata,
-					  MOD_CFG_GLOBAL_SECTION,
-					  MOD_CFG_VIEW_3,
-					  SAT_CFG_INT_MODULE_VIEW_3);
+									  MOD_CFG_GLOBAL_SECTION,
+									  MOD_CFG_VIEW_3,
+									  SAT_CFG_INT_MODULE_VIEW_3);
 
 }
 
@@ -624,15 +639,15 @@ gtk_sat_module_load_sats      (GtkSatModule *module)
 
 	/* get list of satellites from config file; abort in case of error */
 	sats = g_key_file_get_integer_list (module->cfgdata,
-					    MOD_CFG_GLOBAL_SECTION,
-					    MOD_CFG_SATS_KEY,
-					    &length,
-					    &error);
+										MOD_CFG_GLOBAL_SECTION,
+										MOD_CFG_SATS_KEY,
+										&length,
+										&error);
 			
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Failed to get list of satellites (%s)"),
-			     __FUNCTION__, error->message);
+					 _("%s: Failed to get list of satellites (%s)"),
+					 __FUNCTION__, error->message);
 
 		g_clear_error (&error);
 
@@ -653,8 +668,8 @@ gtk_sat_module_load_sats      (GtkSatModule *module)
 
 			/* the satellite could not be read */
 			sat_log_log (SAT_LOG_LEVEL_ERROR,
-				     _("%s: Error reading data for #%d"),
-				     __FUNCTION__, sats[i]);
+						 _("%s: Error reading data for #%d"),
+						 __FUNCTION__, sats[i]);
 
 			g_free (sat);
 		}
@@ -671,21 +686,21 @@ gtk_sat_module_load_sats      (GtkSatModule *module)
 				gtk_sat_data_init_sat (sat, module->qth);
 
 				g_hash_table_insert (module->satellites,
-						     key,
-						     sat);
+									 key,
+									 sat);
 
 				succ++;
 
 				sat_log_log (SAT_LOG_LEVEL_DEBUG,
-					     _("%s: Read data for #%d"),
-					     __FUNCTION__, sats[i]);
+							 _("%s: Read data for #%d"),
+							 __FUNCTION__, sats[i]);
 
 
 			}
 			else {
 				sat_log_log (SAT_LOG_LEVEL_WARN,
-					     _("%s: Sat #%d already in list"),
-					     __FUNCTION__, sats[i]);
+							 _("%s: Sat #%d already in list"),
+							 __FUNCTION__, sats[i]);
 
 				/* it is not needed in this case */
 				g_free (sat);
@@ -695,10 +710,10 @@ gtk_sat_module_load_sats      (GtkSatModule *module)
 	}
 
 	sat_log_log (SAT_LOG_LEVEL_MSG,
-		     _("%s: Read %d out of %d satellites"),
-		     __FUNCTION__,
-		     succ,
-		     length);
+				 _("%s: Read %d out of %d satellites"),
+				 __FUNCTION__,
+				 succ,
+				 length);
 
 	g_free (sats);
 
@@ -724,14 +739,17 @@ gtk_sat_module_load_sats      (GtkSatModule *module)
 static gboolean
 gtk_sat_module_timeout_cb     (gpointer module)
 {
+	GtkSatModule *mod = GTK_SAT_MODULE (module);
 	gboolean       needupdate = FALSE;
 	GdkWindowState state;
+	gdouble   delta;
 
-	if (GTK_SAT_MODULE(module)->busy) {
+
+	if (mod->busy) {
 
 		sat_log_log (SAT_LOG_LEVEL_WARN,
-			     _("%s: Previous cycle missed it's deadline."),
-			     __FUNCTION__);
+					 _("%s: Previous cycle missed it's deadline."),
+					 __FUNCTION__);
 
 		return TRUE;
 
@@ -739,7 +757,7 @@ gtk_sat_module_timeout_cb     (gpointer module)
 
 
 	/* in docked state, update only if tab is visible */
-	switch (GTK_SAT_MODULE (module)->state) {
+	switch (mod->state) {
 
 	case GTK_SAT_MOD_STATE_DOCKED:
 
@@ -762,46 +780,75 @@ gtk_sat_module_timeout_cb     (gpointer module)
 
 	if (needupdate) {
 
-		GTK_SAT_MODULE(module)->busy = TRUE;
+		mod->busy = TRUE;
+
+
+		mod->rtNow = get_current_daynum ();
+
+		/* Update time if throttle != 0 */
+		if (mod->throttle) {
+
+			delta = mod->throttle * (mod->rtNow - mod->rtPrev);
+			mod->tmgCdnum = mod->tmgPdnum + delta;
+
+		}
+		/* else nothing to do since tmg_time_set updates
+		   mod->tmgCdnum every time
+		*/
 
 		/* time to update header? */
-		GTK_SAT_MODULE (module)->head_count++;
-		if (GTK_SAT_MODULE (module)->head_count == GTK_SAT_MODULE (module)->head_timeout) {
+		mod->head_count++;
+		if (mod->head_count == mod->head_timeout) {
 
 			/* reset counter */
-			GTK_SAT_MODULE (module)->head_count = 0;
+			mod->head_count = 0;
 			
-			update_header (GTK_SAT_MODULE (module));
+			update_header (mod);
 		}
 
 		/* time to update events? */
-		if (GTK_SAT_MODULE (module)->event_count == GTK_SAT_MODULE (module)->event_timeout) {
+		if (mod->event_count == mod->event_timeout) {
 
 			/* reset counter, this will make gtk_sat_module_update_sat
 			   recalculate events
 			*/
-			GTK_SAT_MODULE (module)->event_count = 0;
+			mod->event_count = 0;
 		}
 
 		/* update satellite data */
-		g_hash_table_foreach (GTK_SAT_MODULE(module)->satellites,
-				      gtk_sat_module_update_sat,
-				      module);
+		g_hash_table_foreach (mod->satellites,
+							  gtk_sat_module_update_sat,
+							  module);
 
 		/* update children */
-		if (GTK_SAT_MODULE (module)->child_1 != NULL)
-			update_child (GTK_SAT_MODULE (module)->child_1);
+		if (mod->child_1 != NULL)
+			update_child (mod->child_1, mod->tmgCdnum);
 
-		if (GTK_SAT_MODULE (module)->child_2 != NULL)
-			update_child (GTK_SAT_MODULE (module)->child_2);
+		if (mod->child_2 != NULL)
+			update_child (mod->child_2, mod->tmgCdnum);
 
-		if (GTK_SAT_MODULE (module)->child_3 != NULL)
-			update_child (GTK_SAT_MODULE (module)->child_3);
+		if (mod->child_3 != NULL)
+			update_child (mod->child_3, mod->tmgCdnum);
 
 
-		GTK_SAT_MODULE (module)->event_count++;
+		mod->event_count++;
 
-		GTK_SAT_MODULE(module)->busy = FALSE;
+		/* store time keeping variables */
+		mod->rtPrev = mod->rtNow;
+		mod->tmgPdnum = mod->tmgCdnum;
+
+		if (mod->tmgActive) {
+
+			/* update time control spin buttons when we are
+			   in RT or SRT mode */
+			if (mod->throttle) {
+				tmg_update_widgets (mod);
+			}
+
+		}
+
+
+		mod->busy = FALSE;
 
 	}
 
@@ -810,23 +857,33 @@ gtk_sat_module_timeout_cb     (gpointer module)
 
 
 static void
-update_child (GtkWidget *child)
+update_child (GtkWidget *child, gdouble tstamp)
 {
-	if (IS_GTK_SAT_LIST(child))
+	if (IS_GTK_SAT_LIST(child)) {
+		GTK_SAT_LIST (child)->tstamp = tstamp;
 		gtk_sat_list_update (child);
-	else if (IS_GTK_SAT_MAP(child))
+	}
+
+	else if (IS_GTK_SAT_MAP(child)) {
+		GTK_SAT_MAP (child)->tstamp = tstamp;
 		gtk_sat_map_update (child);
+	}
 
-	else if (IS_GTK_POLAR_VIEW(child))
+	else if (IS_GTK_POLAR_VIEW(child)) {
+		GTK_POLAR_VIEW (child)->tstamp = tstamp;
 		gtk_polar_view_update (child);
+	}
 
-	else if (IS_GTK_SINGLE_SAT(child))
+	else if (IS_GTK_SINGLE_SAT(child)) {
+		GTK_SINGLE_SAT (child)->tstamp = tstamp;
 		gtk_single_sat_update (child);
+	}
 
-	else
+	else {
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%f:%d: Unknown child type"),
-			     __FILE__, __LINE__);
+					 _("%f:%d: Unknown child type"),
+					 __FILE__, __LINE__);
+	}
 }
 
 
@@ -856,10 +913,8 @@ gtk_sat_module_update_sat    (gpointer key, gpointer val, gpointer data)
 	module = GTK_SAT_MODULE (data);
 
 
-	/*** FIXME: This should be replaced with a call to the time manager
-	     of the GtkSatModule
-	*/
-	daynum = get_current_daynum ();
+	/* get current time (real or simulated */
+	daynum = module->tmgCdnum;
 
 	/* update events if the event counter has been reset
 	   and the other requirements are fulfilled
@@ -924,8 +979,8 @@ gtk_sat_module_update_sat    (gpointer key, gpointer val, gpointer data)
 	sat->footprint = 12756.33 * acos (xkmper / (xkmper+sat->alt));
 	age = sat->jul_utc - sat->jul_epoch;
 	sat->orbit = (long) floor((sat->tle.xno * xmnpda/twopi +
-				   age * sat->tle.bstar * ae) * age +
-				  sat->tle.xmo/twopi) + sat->tle.revnum - 1;
+							   age * sat->tle.bstar * ae) * age +
+							  sat->tle.xmo/twopi) + sat->tle.revnum - 1;
 
 
 	/*** FIXME: Squint + AOS / LOS code */
@@ -969,8 +1024,8 @@ gtk_sat_module_close_cb       (GtkWidget *button, gpointer data)
 	name = g_strdup (module->name);
 
 	sat_log_log (SAT_LOG_LEVEL_DEBUG,
-		     _("%s: Module %s recevied CLOSE signal."),
-		     __FUNCTION__, name);
+				 _("%s: Module %s recevied CLOSE signal."),
+				 __FUNCTION__, name);
 
 	/* no need, in fact, should NOT save config here otherwise
 	   we may overwrite new configuration.
@@ -981,32 +1036,32 @@ gtk_sat_module_close_cb       (GtkWidget *button, gpointer data)
 
 	case GTK_SAT_MOD_STATE_DOCKED:
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s: Module %s is in DOCKED state."),
-			     __FUNCTION__, name);
+					 _("%s: Module %s is in DOCKED state."),
+					 __FUNCTION__, name);
 
 		retcode = mod_mgr_remove_module (GTK_WIDGET (module));
 
 		if (retcode) {
 			sat_log_log (SAT_LOG_LEVEL_BUG,
-				     _("%s: Module %s was not found in mod-mgr (%d)\n"\
-				       "Internal state is corrupt?"),
-				     __FUNCTION__, name, retcode);
+						 _("%s: Module %s was not found in mod-mgr (%d)\n"\
+						   "Internal state is corrupt?"),
+						 __FUNCTION__, name, retcode);
 		}
 
 		break;
 
 	case GTK_SAT_MOD_STATE_WINDOW:
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s: Module %s is in WINDOW state."),
-			     __FUNCTION__, name);
+					 _("%s: Module %s is in WINDOW state."),
+					 __FUNCTION__, name);
 
 		retcode = mod_mgr_remove_module (GTK_WIDGET (module));
 
 		if (retcode) {
 			sat_log_log (SAT_LOG_LEVEL_BUG,
-				     _("%s: Module %s was not found in mod-mgr (%d)\n"\
-				       "Internal state is corrupt?"),
-				     __FUNCTION__, name, retcode);
+						 _("%s: Module %s was not found in mod-mgr (%d)\n"\
+						   "Internal state is corrupt?"),
+						 __FUNCTION__, name, retcode);
 		}
 
 		/* increase referene count */
@@ -1014,7 +1069,7 @@ gtk_sat_module_close_cb       (GtkWidget *button, gpointer data)
 
 		/* remove module from window, destroy window */
 		gtk_container_remove (GTK_CONTAINER (GTK_SAT_MODULE (module)->win),
-				      GTK_WIDGET (module));
+							  GTK_WIDGET (module));
 		gtk_widget_destroy (GTK_SAT_MODULE (module)->win);
 		GTK_SAT_MODULE (module)->win = NULL;
 
@@ -1025,16 +1080,16 @@ gtk_sat_module_close_cb       (GtkWidget *button, gpointer data)
 
 	case GTK_SAT_MOD_STATE_FULLSCREEN:
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s: Module %s is in FULLSCREEN state."),
-			     __FUNCTION__, name);
+					 _("%s: Module %s is in FULLSCREEN state."),
+					 __FUNCTION__, name);
 
 		retcode = mod_mgr_remove_module (GTK_WIDGET (module));
 
 		if (retcode) {
 			sat_log_log (SAT_LOG_LEVEL_BUG,
-				     _("%s: Module %s was not found in mod-mgr (%d)\n"\
-				       "Internal state is corrupt?"),
-				     __FUNCTION__, name, retcode);
+						 _("%s: Module %s was not found in mod-mgr (%d)\n"\
+						   "Internal state is corrupt?"),
+						 __FUNCTION__, name, retcode);
 		}
 
 
@@ -1043,7 +1098,7 @@ gtk_sat_module_close_cb       (GtkWidget *button, gpointer data)
 
 		/* remove module from window, destroy window */
 		gtk_container_remove (GTK_CONTAINER (GTK_SAT_MODULE (module)->win),
-				      GTK_WIDGET (module));
+							  GTK_WIDGET (module));
 		gtk_widget_destroy (GTK_SAT_MODULE (module)->win);
 		GTK_SAT_MODULE (module)->win = NULL;
 
@@ -1054,8 +1109,8 @@ gtk_sat_module_close_cb       (GtkWidget *button, gpointer data)
 
 	default:
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Module %s has unknown state: %d"),
-			     __FUNCTION__, name, module->state);
+					 _("%s: Module %s has unknown state: %d"),
+					 __FUNCTION__, name, module->state);
 		break;
 	}
 
@@ -1063,8 +1118,8 @@ gtk_sat_module_close_cb       (GtkWidget *button, gpointer data)
 	/* gtk_widget_destroy (GTK_WIDGET (module)); */
 
 	sat_log_log (SAT_LOG_LEVEL_MSG,
-		     _("%s: Module %s closed."),
-		     __FUNCTION__, name);
+				 _("%s: Module %s closed."),
+				 __FUNCTION__, name);
 
 	g_free (name);
 		     
@@ -1104,8 +1159,8 @@ gtk_sat_module_config_cb       (GtkWidget *button, gpointer data)
 	name = g_strdup (module->name);
 
 	sat_log_log (SAT_LOG_LEVEL_DEBUG,
-		     _("%s: Module %s recevied CONFIG signal."),
-		     __FUNCTION__, name);
+				 _("%s: Module %s recevied CONFIG signal."),
+				 __FUNCTION__, name);
 
 	/* stop timeout */
 	if (!g_source_remove (module->timerid)) {
@@ -1113,9 +1168,9 @@ gtk_sat_module_config_cb       (GtkWidget *button, gpointer data)
 		   to be invalid.
 		*/
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Could not stop timeout callback\n"\
-			       "%s: Source ID %d seems invalid."),
-			     __FUNCTION__, __FUNCTION__, module->timerid);
+					 _("%s: Could not stop timeout callback\n"\
+					   "%s: Source ID %d seems invalid."),
+					 __FUNCTION__, __FUNCTION__, module->timerid);
 
 	}
 	else {
@@ -1146,13 +1201,13 @@ gtk_sat_module_config_cb       (GtkWidget *button, gpointer data)
 				gtk_sat_module_close_cb (NULL, module);
 
 				cfgfile = g_strconcat (g_get_home_dir (),
-						       G_DIR_SEPARATOR_S,
-						       ".gpredict2",
-						       G_DIR_SEPARATOR_S,
-						       "modules",
-						       G_DIR_SEPARATOR_S,
-						       name, ".mod",
-						       NULL);
+									   G_DIR_SEPARATOR_S,
+									   ".gpredict2",
+									   G_DIR_SEPARATOR_S,
+									   "modules",
+									   G_DIR_SEPARATOR_S,
+									   name, ".mod",
+									   NULL);
 
 				module = GTK_SAT_MODULE (gtk_sat_module_new (cfgfile));
 				module->state = laststate;
@@ -1181,15 +1236,15 @@ gtk_sat_module_config_cb       (GtkWidget *button, gpointer data)
 					/* create window */
 					module->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 					gtk_window_set_title (GTK_WINDOW (module->win),
-							      module->name);
+										  module->name);
 					gtk_window_set_default_size (GTK_WINDOW (module->win),
-								     w, h);
+												 w, h);
 
 					/** FIXME: window icon and such */
 
 					/* add module to window */
 					gtk_container_add (GTK_CONTAINER (module->win),
-							   GTK_WIDGET (module));
+									   GTK_WIDGET (module));
 
 					/* show window */
 					gtk_widget_show_all (module->win);
@@ -1204,15 +1259,15 @@ gtk_sat_module_config_cb       (GtkWidget *button, gpointer data)
 					/* create window */
 					module->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 					gtk_window_set_title (GTK_WINDOW (module->win),
-							      module->name);
+										  module->name);
 					gtk_window_set_default_size (GTK_WINDOW (module->win),
-								     w, h);
+												 w, h);
 
 					/** FIXME: window icon and such */
 
 					/* add module to window */
 					gtk_container_add (GTK_CONTAINER (module->win),
-							   GTK_WIDGET (module));
+									   GTK_WIDGET (module));
 
 					/* show window */
 					gtk_widget_show_all (module->win);
@@ -1223,8 +1278,8 @@ gtk_sat_module_config_cb       (GtkWidget *button, gpointer data)
 
 				default:
 					sat_log_log (SAT_LOG_LEVEL_BUG,
-						     _("%s: Module %s has unknown state: %d"),
-						     __FUNCTION__, name, module->state);
+								 _("%s: Module %s has unknown state: %d"),
+								 __FUNCTION__, name, module->state);
 					break;
 				}
 					
@@ -1237,8 +1292,8 @@ gtk_sat_module_config_cb       (GtkWidget *button, gpointer data)
 		else {
 			/* user cancelled => just re-start timer */
 			module->timerid = g_timeout_add (module->timeout,
-							 gtk_sat_module_timeout_cb,
-							 data);
+											 gtk_sat_module_timeout_cb,
+											 data);
 			
 		}
 	}
@@ -1252,16 +1307,13 @@ static void
 update_header (GtkSatModule *module)
 {
 	gchar *fmtstr;
-	struct timeval tval;
-	struct timezone tzone;
 	time_t t;
-	gint x;
 	guint size;
 	gchar buff[TIME_FORMAT_MAX_LENGTH+1];
 
 
-	x = gettimeofday (&tval, &tzone);
-	t = (time_t ) tval.tv_sec;
+
+	t = (module->tmgCdnum - 2440587.5)*86400.;
 
 	fmtstr = sat_cfg_get_str (SAT_CFG_STR_TIME_FORMAT);
 	
@@ -1277,8 +1329,10 @@ update_header (GtkSatModule *module)
 		buff[TIME_FORMAT_MAX_LENGTH]='\0';
 
 	gtk_label_set_text (GTK_LABEL (module->header), buff);
-
 	g_free (fmtstr);
+
+	if (module->tmgActive)
+		tmg_update_state (module);
 }
 
 
@@ -1309,11 +1363,11 @@ fix_child_allocations            (GtkWidget *widget, gpointer data)
 	case GTK_SAT_MOD_LAYOUT_2:
 		if (module->vpanedpos != -1) {
 			gtk_paned_set_position (GTK_PANED (module->vpaned),
-						module->vpanedpos);
+									module->vpanedpos);
 		}
 		else if (widget->allocation.height > 0) {
 			gtk_paned_set_position (GTK_PANED (module->vpaned),
-						widget->allocation.height / 2);
+									widget->allocation.height / 2);
 		}
 		else {
 		}
@@ -1324,20 +1378,20 @@ fix_child_allocations            (GtkWidget *widget, gpointer data)
 	case GTK_SAT_MOD_LAYOUT_4:
 		if (module->vpanedpos == -1) {
 			gtk_paned_set_position (GTK_PANED (module->vpaned),
-						widget->allocation.height / 2);
+									widget->allocation.height / 2);
 		}
 		else {
 			gtk_paned_set_position (GTK_PANED (module->vpaned),
-						module->vpanedpos);
+									module->vpanedpos);
 		}
 
 		if (module->hpanedpos == -1) {
 			gtk_paned_set_position (GTK_PANED (module->hpaned),
-						widget->allocation.width / 2);
+									widget->allocation.width / 2);
 		}
 		else {
 			gtk_paned_set_position (GTK_PANED (module->hpaned),
-						module->hpanedpos);
+									module->hpanedpos);
 		}
 
 		break;
@@ -1361,3 +1415,104 @@ gtk_sat_module_fix_size (GtkWidget *module)
 }
 
 
+
+static gboolean empty (gpointer key, gpointer val, gpointer data)
+{
+	/* TRUE => sat removed from hash table */
+	return TRUE;
+}
+
+
+/** \brief Reload satellites.
+ *  \param module Pointer to a GtkSatModule widget.
+ *
+ * This function is used to reload the satellites in a module. This is can be
+ * useful when:
+ *
+ *   1. The TLE files have been updated.
+ *   2. The module configuration has changed (i.e. which satellites to track).
+ *
+ * The function assumes that module->cfgdata has already been updated, and so
+ * all it has to do is to free module->satellites and re-execute the satellite
+ * loading sequence.
+ */
+void
+gtk_sat_module_reload_sats    (GtkSatModule *module)
+{
+
+	g_return_if_fail (IS_GTK_SAT_MODULE (module));
+
+	/* lock module */
+	module->busy = TRUE;
+
+	sat_log_log (SAT_LOG_LEVEL_MSG,
+				 _("%s: Reloading satellites for module %s"),
+				 __FUNCTION__, module->name);
+
+	/* remove each element from the hash table, but keep the hash table */
+	g_hash_table_foreach_remove (module->satellites, empty, NULL);
+
+	/* reset event counter so that next AOS/LOS gets re-calculated */
+	module->event_count = 0;	   
+
+	/* load satellites */
+	gtk_sat_module_load_sats (module);
+
+	/* update children */
+	if (GTK_SAT_MODULE (module)->child_1 != NULL)
+		reload_sats_in_child (GTK_SAT_MODULE (module)->child_1, GTK_SAT_MODULE (module));
+	
+	if (GTK_SAT_MODULE (module)->child_2 != NULL)
+		reload_sats_in_child (GTK_SAT_MODULE (module)->child_2, GTK_SAT_MODULE (module));
+	
+	if (GTK_SAT_MODULE (module)->child_3 != NULL)
+		reload_sats_in_child (GTK_SAT_MODULE (module)->child_3, GTK_SAT_MODULE (module));
+	
+
+	/* unlock module */
+	module->busy = FALSE;
+
+}
+
+
+/** \brief Reload satellites in view */
+static void
+reload_sats_in_child (GtkWidget *widget, GtkSatModule *module)
+{
+ 
+ 
+	if (IS_GTK_SINGLE_SAT (G_OBJECT (widget))) {
+		gtk_single_sat_reload_sats (widget, module->satellites);
+	}
+
+	else if (IS_GTK_POLAR_VIEW (widget)) {
+		gtk_polar_view_reload_sats (widget, module->satellites);
+	}
+
+	else if (IS_GTK_SAT_MAP (widget)) {
+		gtk_sat_map_reload_sats (widget, module->satellites);
+	}
+
+	else if (IS_GTK_SAT_LIST (widget)) {
+	}
+
+	else {
+		sat_log_log (SAT_LOG_LEVEL_BUG,
+					 _("%f:%d: Unknown child type"),
+					 __FILE__, __LINE__);
+	}
+
+}
+
+
+/** \brief Re-configure module.
+ *  \param module The module.
+ *  \param local Flag indicating whether reconfiguration is requested from 
+ *               local configuration dialog.
+ *
+ */
+void
+gtk_sat_module_reconf         (GtkSatModule *module, gboolean local)
+{
+}
+
