@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 /** \brief Satellite selector.
  *
@@ -50,27 +50,27 @@ static void          gtk_sat_tree_destroy    (GtkObject       *object);
 
 static GtkTreeModel *create_and_fill_model (guint flags);
 static void          column_toggled        (GtkCellRendererToggle *cell,
-					    gchar                 *path_str,
-					    gpointer               data);
+											gchar                 *path_str,
+											gpointer               data);
 
 static gint          scan_tle_file         (const gchar *path,
-					    GtkTreeStore *store,
-					    GtkTreeIter *node);
+											GtkTreeStore *store,
+											GtkTreeIter *node);
 
 static gboolean      check_and_select_sat (GtkTreeModel *model,
-					   GtkTreePath  *path,
-					   GtkTreeIter  *iter,
-					   gpointer      data);
+										   GtkTreePath  *path,
+										   GtkTreeIter  *iter,
+										   gpointer      data);
 
 static gboolean      uncheck_sat          (GtkTreeModel *model,
-					   GtkTreePath  *path,
-					   GtkTreeIter  *iter,
-					   gpointer      data);
+										   GtkTreePath  *path,
+										   GtkTreeIter  *iter,
+										   gpointer      data);
 
 static gint     compare_func (GtkTreeModel *model,
-			      GtkTreeIter  *a,
-			      GtkTreeIter  *b,
-			      gpointer      userdata);
+							  GtkTreeIter  *a,
+							  GtkTreeIter  *b,
+							  gpointer      userdata);
 
 static void expand_cb   (GtkWidget *button, gpointer tree);
 static void collapse_cb (GtkWidget *button, gpointer tree);
@@ -87,25 +87,25 @@ gtk_sat_tree_get_type ()
 	static GType gtk_sat_tree_type = 0;
 
 	if (!gtk_sat_tree_type)
-	{
-		static const GTypeInfo gtk_sat_tree_info =
-			{
-				sizeof (GtkSatTreeClass),
-				NULL,  /* base_init */
-				NULL,  /* base_finalize */
-				(GClassInitFunc) gtk_sat_tree_class_init,
-				NULL,  /* class_finalize */
-				NULL,  /* class_data */
-				sizeof (GtkSatTree),
-				1,     /* n_preallocs */
-				(GInstanceInitFunc) gtk_sat_tree_init,
-			};
+		{
+			static const GTypeInfo gtk_sat_tree_info =
+				{
+					sizeof (GtkSatTreeClass),
+					NULL,  /* base_init */
+					NULL,  /* base_finalize */
+					(GClassInitFunc) gtk_sat_tree_class_init,
+					NULL,  /* class_finalize */
+					NULL,  /* class_data */
+					sizeof (GtkSatTree),
+					1,     /* n_preallocs */
+					(GInstanceInitFunc) gtk_sat_tree_init,
+				};
 
-		gtk_sat_tree_type = g_type_register_static (GTK_TYPE_VBOX,
-								    "GtkSatTree",
-								    &gtk_sat_tree_info,
-								    0);
-	}
+			gtk_sat_tree_type = g_type_register_static (GTK_TYPE_VBOX,
+														"GtkSatTree",
+														&gtk_sat_tree_info,
+														0);
+		}
 
 	return gtk_sat_tree_type;
 }
@@ -198,20 +198,20 @@ gtk_sat_tree_new (guint flags)
 
 	/* sort the tree by name */
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 GTK_SAT_TREE_COL_NAME,
-					 compare_func,
-					 NULL,
-					 NULL);
+									 GTK_SAT_TREE_COL_NAME,
+									 compare_func,
+									 NULL,
+									 NULL);
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
-					      GTK_SAT_TREE_COL_NAME,
-					      GTK_SORT_ASCENDING);
+										  GTK_SAT_TREE_COL_NAME,
+										  GTK_SORT_ASCENDING);
 
 	/* create tree view columns */
 	/* label column */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Satellite"), renderer,
-							   "text", GTK_SAT_TREE_COL_NAME,
-							   NULL);
+													   "text", GTK_SAT_TREE_COL_NAME,
+													   NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (sat_tree->tree), column, -1);
 	if (!(flags & GTK_SAT_TREE_FLAG_NAME))
 		gtk_tree_view_column_set_visible (column, FALSE);
@@ -219,9 +219,9 @@ gtk_sat_tree_new (guint flags)
 	/* catalogue number */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Catnum"), renderer,
-							   "text", GTK_SAT_TREE_COL_CATNUM,
-							   "visible", GTK_SAT_TREE_COL_VIS,
-							   NULL);
+													   "text", GTK_SAT_TREE_COL_CATNUM,
+													   "visible", GTK_SAT_TREE_COL_VIS,
+													   NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (sat_tree->tree), column, -1);
 	if (!(flags & GTK_SAT_TREE_FLAG_CATNUM))
 		gtk_tree_view_column_set_visible (column, FALSE);
@@ -229,9 +229,9 @@ gtk_sat_tree_new (guint flags)
 	/* epoch */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Epoch"), renderer,
-							   "text", GTK_SAT_TREE_COL_EPOCH,
-							   "visible", GTK_SAT_TREE_COL_VIS,
-							   NULL);
+													   "text", GTK_SAT_TREE_COL_EPOCH,
+													   "visible", GTK_SAT_TREE_COL_VIS,
+													   NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (sat_tree->tree), column, -1);
 	if (!(flags & GTK_SAT_TREE_FLAG_EPOCH))
 		gtk_tree_view_column_set_visible (column, FALSE);
@@ -239,12 +239,12 @@ gtk_sat_tree_new (guint flags)
 	/* checkbox column */
 	renderer = gtk_cell_renderer_toggle_new ();
 	sat_tree->handler_id = g_signal_connect (renderer, "toggled",
-						 G_CALLBACK (column_toggled), widget);
+											 G_CALLBACK (column_toggled), widget);
 
 	column = gtk_tree_view_column_new_with_attributes (_("Selected"), renderer,
-							   "active", GTK_SAT_TREE_COL_SEL,
-							   "visible", GTK_SAT_TREE_COL_VIS,
-							   NULL);
+													   "active", GTK_SAT_TREE_COL_SEL,
+													   "visible", GTK_SAT_TREE_COL_VIS,
+													   NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (sat_tree->tree), column);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	if (!(flags & GTK_SAT_TREE_FLAG_SEL))
@@ -254,10 +254,10 @@ gtk_sat_tree_new (guint flags)
 	/* scrolled window */
 	GTK_SAT_TREE (widget)->swin = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (GTK_SAT_TREE (widget)->swin),
-					GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+									GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 
 	gtk_container_add (GTK_CONTAINER (GTK_SAT_TREE (widget)->swin),
-			   GTK_SAT_TREE (widget)->tree);
+					   GTK_SAT_TREE (widget)->tree);
 
 	//gtk_container_add (GTK_CONTAINER (widget), GTK_SAT_TREE (widget)->swin);
 	gtk_box_pack_start (GTK_BOX (widget), GTK_SAT_TREE (widget)->swin, TRUE, TRUE, 0);
@@ -266,15 +266,15 @@ gtk_sat_tree_new (guint flags)
 	expbut = gtk_button_new_with_label (_("Expand"));
 	tips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tips, expbut,
-			      _("Expand all nodes in the tree to make it searchable"),
-			      NULL);
+						  _("Expand all nodes in the tree to make it searchable"),
+						  NULL);
 	g_signal_connect (expbut, "clicked", G_CALLBACK (expand_cb), sat_tree);
 
 	colbut = gtk_button_new_with_label (_("Collapse"));
 	tips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tips, colbut,
-			      _("Collapse all nodes in the tree"),
-			      NULL);
+						  _("Collapse all nodes in the tree"),
+						  NULL);
 	g_signal_connect (colbut, "clicked", G_CALLBACK (collapse_cb), sat_tree);
 
 	hbox = gtk_hbutton_box_new ();
@@ -313,32 +313,32 @@ create_and_fill_model (guint flags)
 
 	/* create a new tree store */
 	store = gtk_tree_store_new (GTK_SAT_TREE_COL_NUM,
-				    G_TYPE_STRING,    // name
-				    G_TYPE_INT,       // catnum
-				    G_TYPE_STRING,    // epoch
-				    G_TYPE_BOOLEAN,   // selected
-				    G_TYPE_BOOLEAN    // visible
-				    );
+								G_TYPE_STRING,    // name
+								G_TYPE_INT,       // catnum
+								G_TYPE_STRING,    // epoch
+								G_TYPE_BOOLEAN,   // selected
+								G_TYPE_BOOLEAN    // visible
+								);
 
 
 	dirname = g_strconcat (g_get_home_dir (),
-			       G_DIR_SEPARATOR_S, ".gpredict2",
-			       G_DIR_SEPARATOR_S, "tle",
-			       NULL);
+						   G_DIR_SEPARATOR_S, ".gpredict2",
+						   G_DIR_SEPARATOR_S, "tle",
+						   NULL);
 
 
 	/* debug message */
 	sat_log_log (SAT_LOG_LEVEL_DEBUG,
-		     _("%s:%d: Directory is: %s"),
-		     __FILE__, __LINE__, dirname);
+				 _("%s:%d: Directory is: %s"),
+				 __FILE__, __LINE__, dirname);
 
 	dir = g_dir_open (dirname, 0, NULL);
 
 	/* no tle files */
 	if (!dir) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: No .tle files found in %s."),
-			     __FILE__, __LINE__, dirname);
+					 _("%s:%d: No .tle files found in %s."),
+					 __FILE__, __LINE__, dirname);
 
 		g_free (dirname);
 		
@@ -360,13 +360,13 @@ create_and_fill_model (guint flags)
 			/* create a new top level node in the tree */
 			gtk_tree_store_append (store, &node, NULL);
 			gtk_tree_store_set (store, &node,
-					    GTK_SAT_TREE_COL_NAME, nodename,
-					    GTK_SAT_TREE_COL_VIS, FALSE,
-					    -1);
+								GTK_SAT_TREE_COL_NAME, nodename,
+								GTK_SAT_TREE_COL_VIS, FALSE,
+								-1);
 
 			/* build full path til file and sweep it for sats */
 			path = g_strconcat (dirname, G_DIR_SEPARATOR_S,
-					    fname, NULL);
+								fname, NULL);
 			
 			num = scan_tle_file (path, store, &node);
 
@@ -375,8 +375,8 @@ create_and_fill_model (guint flags)
 			g_strfreev (buffv);
 
 			sat_log_log (SAT_LOG_LEVEL_MSG,
-				     _("%s:%d: Read %d sats from %s "),
-				     __FILE__, __LINE__, num, fname);
+						 _("%s:%d: Read %d sats from %s "),
+						 __FILE__, __LINE__, num, fname);
 		}
 
 	}
@@ -417,8 +417,8 @@ scan_tle_file (const gchar *path, GtkTreeStore *store, GtkTreeIter *node)
 
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Failed to open %s (%s)"),
-			     __FILE__, __LINE__, path, error->message);
+					 _("%s:%d: Failed to open %s (%s)"),
+					 __FILE__, __LINE__, path, error->message);
 		g_clear_error (&error);
 	}
 	else if (tlefile) {
@@ -432,9 +432,12 @@ scan_tle_file (const gchar *path, GtkTreeStore *store, GtkTreeIter *node)
 			satnam = g_strdup (line);
 			g_strchomp (satnam);
 
+			/* free allocated line */
+			g_free (line);
+
 			/* extract catnum from second line; index 2..6 */
 			g_io_channel_read_line (tlefile, &line, &length,
-						NULL, NULL);
+									NULL, NULL);
 			
 			for (j = 2; j < 7; j++) {
 				catstr[j-2] = line[j];
@@ -446,19 +449,25 @@ scan_tle_file (const gchar *path, GtkTreeStore *store, GtkTreeIter *node)
 			/* insert satnam and catnum */
 			gtk_tree_store_append (store, &sat_iter, node);
 			gtk_tree_store_set (store, &sat_iter,
-					    GTK_SAT_TREE_COL_NAME, satnam,
-					    GTK_SAT_TREE_COL_CATNUM, catnum,
-					    GTK_SAT_TREE_COL_SEL, FALSE,
-					    GTK_SAT_TREE_COL_VIS, TRUE,
-					    -1);
+								GTK_SAT_TREE_COL_NAME, satnam,
+								GTK_SAT_TREE_COL_CATNUM, catnum,
+								GTK_SAT_TREE_COL_SEL, FALSE,
+								GTK_SAT_TREE_COL_VIS, TRUE,
+								-1);
 			
 
 			/* free mem */
 			g_free (satnam);
 
+			/* free allocated line */
+			g_free (line);
+
 			/* read the third line */
 			g_io_channel_read_line (tlefile, &line, &length, NULL, NULL);
 
+			/* free allocated line */
+			g_free (line);
+
 			i++;
 		}
 
@@ -481,8 +490,8 @@ scan_tle_file (const gchar *path, GtkTreeStore *store, GtkTreeIter *node)
  */
 static void
 column_toggled        (GtkCellRendererToggle *cell,
-		       gchar                 *path_str,
-		       gpointer               data)
+					   gchar                 *path_str,
+					   gpointer               data)
 {
 	GtkSatTree   *sat_tree = GTK_SAT_TREE (data);
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (sat_tree->tree));
@@ -495,9 +504,9 @@ column_toggled        (GtkCellRendererToggle *cell,
 	/* get toggled iter */
 	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (model, &iter,
-			    GTK_SAT_TREE_COL_CATNUM, &catnum,
-			    GTK_SAT_TREE_COL_SEL, &toggle_item,
-			    -1);
+						GTK_SAT_TREE_COL_CATNUM, &catnum,
+						GTK_SAT_TREE_COL_SEL, &toggle_item,
+						-1);
 
 	/* do something with the value */
 	toggle_item ^= 1;
@@ -507,10 +516,10 @@ column_toggled        (GtkCellRendererToggle *cell,
 		/* only append if sat not already in list */
 		if (!g_slist_find (sat_tree->selection, GUINT_TO_POINTER (catnum))) {
 			sat_tree->selection = g_slist_append (sat_tree->selection,
-							      GUINT_TO_POINTER (catnum));
+												  GUINT_TO_POINTER (catnum));
 			sat_log_log (SAT_LOG_LEVEL_DEBUG,
-				     _("%s:%d: Satellite %d selected."),
-				     __FILE__, __LINE__, catnum);
+						 _("%s:%d: Satellite %d selected."),
+						 __FILE__, __LINE__, catnum);
 
 			/* Scan the tree for other instances of this sat. For example is
 			   CUTE-1.7 present in both AMATEUR and CUBESAT.
@@ -525,16 +534,16 @@ column_toggled        (GtkCellRendererToggle *cell,
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_MSG,
-				     _("%s:%d: Satellite %d already selected; skip..."),
-				     __FILE__, __LINE__, catnum);
+						 _("%s:%d: Satellite %d already selected; skip..."),
+						 __FILE__, __LINE__, catnum);
 		}
 	}
 	else {
 		sat_tree->selection = g_slist_remove (sat_tree->selection,
-						      GUINT_TO_POINTER (catnum));
+											  GUINT_TO_POINTER (catnum));
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s:%d: Satellite %d de-selected."),
-			     __FILE__, __LINE__, catnum);
+					 _("%s:%d: Satellite %d de-selected."),
+					 __FILE__, __LINE__, catnum);
 		
 		/* Scan the tree for other instances of this sat. For example is
 		   CUTE-1.7 present in both AMATEUR and CUBESAT.
@@ -549,8 +558,8 @@ column_toggled        (GtkCellRendererToggle *cell,
 
 	/* set new value */
 	gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
-			    GTK_SAT_TREE_COL_SEL, toggle_item,
-			    -1);
+						GTK_SAT_TREE_COL_SEL, toggle_item,
+						-1);
 
 	/* clean up */
 	gtk_tree_path_free (path);
@@ -569,8 +578,8 @@ gtk_sat_tree_select    (GtkSatTree *sat_tree, guint catnum)
 	if ((sat_tree == NULL) || !IS_GTK_SAT_TREE (sat_tree)) {
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Invalid GtkSatTree!"),
-			     __FUNCTION__);
+					 _("%s: Invalid GtkSatTree!"),
+					 __FUNCTION__);
 
 		return;
 	}
@@ -591,8 +600,8 @@ gtk_sat_tree_select    (GtkSatTree *sat_tree, guint catnum)
 	else {
 		/* else do nothing since the sat is already selected */
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s: Satellite %d already selected; skip..."),
-			     __FUNCTION__, catnum);
+					 _("%s: Satellite %d already selected; skip..."),
+					 __FUNCTION__, catnum);
 	}
 }
 
@@ -617,9 +626,9 @@ gtk_sat_tree_select    (GtkSatTree *sat_tree, guint catnum)
  */
 static gboolean
 check_and_select_sat (GtkTreeModel *model,
-		      GtkTreePath  *path,
-		      GtkTreeIter  *iter,
-		      gpointer      data)
+					  GtkTreePath  *path,
+					  GtkTreeIter  *iter,
+					  gpointer      data)
 {
 	GtkSatTree *sat_tree = GTK_SAT_TREE (data);
 	guint cat1, cat2;
@@ -628,27 +637,27 @@ check_and_select_sat (GtkTreeModel *model,
 	cat1 = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (data), "tmp"));
 
 	gtk_tree_model_get (model, iter,
-			    GTK_SAT_TREE_COL_CATNUM, &cat2,
-			    -1);
+						GTK_SAT_TREE_COL_CATNUM, &cat2,
+						-1);
 
 	if (cat1 == cat2) {
 		/* we have a match */
 		gtk_tree_store_set (GTK_TREE_STORE (model), iter,
-				    GTK_SAT_TREE_COL_SEL, TRUE,
-				    -1);
+							GTK_SAT_TREE_COL_SEL, TRUE,
+							-1);
 
 		/* only append if sat not already in list */
 		if (!g_slist_find (sat_tree->selection, GUINT_TO_POINTER (cat1))) {
 			sat_tree->selection = g_slist_append (sat_tree->selection,
-							      GUINT_TO_POINTER (cat1));
+												  GUINT_TO_POINTER (cat1));
 			sat_log_log (SAT_LOG_LEVEL_DEBUG,
-				     _("%s:%d: Satellite %d selected."),
-				     __FILE__, __LINE__, cat1);
+						 _("%s:%d: Satellite %d selected."),
+						 __FILE__, __LINE__, cat1);
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_MSG,
-				     _("%s:%d: Satellite %d already selected; skip..."),
-				     __FILE__, __LINE__, cat1);
+						 _("%s:%d: Satellite %d already selected; skip..."),
+						 __FILE__, __LINE__, cat1);
 		}
 
 		/* If we return TRUE here, the foreach would terminate.
@@ -676,9 +685,9 @@ check_and_select_sat (GtkTreeModel *model,
  */
 static gboolean
 uncheck_sat (GtkTreeModel *model,
-	     GtkTreePath  *path,
-	     GtkTreeIter  *iter,
-	     gpointer      data)
+			 GtkTreePath  *path,
+			 GtkTreeIter  *iter,
+			 gpointer      data)
 {
 	guint cat1, cat2;
 
@@ -686,14 +695,14 @@ uncheck_sat (GtkTreeModel *model,
 	cat1 = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (data), "tmp"));
 
 	gtk_tree_model_get (model, iter,
-			    GTK_SAT_TREE_COL_CATNUM, &cat2,
-			    -1);
+						GTK_SAT_TREE_COL_CATNUM, &cat2,
+						-1);
 
 	if (cat1 == cat2) {
 		/* we have a match */
 		gtk_tree_store_set (GTK_TREE_STORE (model), iter,
-				    GTK_SAT_TREE_COL_SEL, FALSE,
-				    -1);
+							GTK_SAT_TREE_COL_SEL, FALSE,
+							-1);
 	}
 
 	/* continue in order to catch ALL instances of sat */
@@ -722,8 +731,8 @@ gtk_sat_tree_get_selected (GtkSatTree *sat_tree, gsize *size)
 	if ((sat_tree == NULL) || !IS_GTK_SAT_TREE (sat_tree)) {
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Invalid GtkSatTree!"),
-			     __FUNCTION__);
+					 _("%s: Invalid GtkSatTree!"),
+					 __FUNCTION__);
 
 		return NULL;
 	}
@@ -733,8 +742,8 @@ gtk_sat_tree_get_selected (GtkSatTree *sat_tree, gsize *size)
 
 	if (s < 1) {
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s: There are no satellites selected => NULL."),
-			     __FUNCTION__);
+					 _("%s: There are no satellites selected => NULL."),
+					 __FUNCTION__);
 
 		*size = 0;
 
@@ -767,16 +776,16 @@ gtk_sat_tree_get_selected (GtkSatTree *sat_tree, gsize *size)
  */
 static gint
 compare_func (GtkTreeModel *model,
-	      GtkTreeIter  *a,
-	      GtkTreeIter  *b,
-	      gpointer      userdata)
+			  GtkTreeIter  *a,
+			  GtkTreeIter  *b,
+			  gpointer      userdata)
 {
 	gchar *sat1,*sat2;
 	gint ret = 0;
 
 
-        gtk_tree_model_get(model, a, GTK_SAT_TREE_COL_NAME, &sat1, -1);
-        gtk_tree_model_get(model, b, GTK_SAT_TREE_COL_NAME, &sat2, -1);
+	gtk_tree_model_get(model, a, GTK_SAT_TREE_COL_NAME, &sat1, -1);
+	gtk_tree_model_get(model, b, GTK_SAT_TREE_COL_NAME, &sat2, -1);
 
 	ret = g_ascii_strcasecmp (sat1, sat2);
 
