@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 /** \brief Satellite List Widget.
  *
@@ -51,56 +51,56 @@
 /** \brief Column titles indexed with column symb. refs. */
 const gchar *SINGLE_SAT_FIELD_TITLE[SINGLE_SAT_FIELD_NUMBER] = {
 	N_("Azimuth :"),
-        N_("Elevation :"),
-        N_("Direction :"),
-        N_("Right Asc. :"),
-        N_("Declination :"),
-        N_("Slant Range :"),
-        N_("Range Rate :"),
-        N_("Next Event :"),
-        N_("Next AOS :"),
-        N_("Next LOS :"),
-        N_("SSP Lat. :"),
-        N_("SSP Lon. :"),
-        N_("SSP Loc. :"),
-        N_("Footprint :"),
-        N_("Altitude :"),
-        N_("Velocity :"),
-        N_("Doppler :"),
-        N_("Sig. Loss :"),
-        N_("Sig. Delay :"),
-        N_("Mean Anom. :"),
-        N_("Orbit Phase :"),
-        N_("Orbit Num. :"),
-        N_("Visibility :")
+	N_("Elevation :"),
+	N_("Direction :"),
+	N_("Right Asc. :"),
+	N_("Declination :"),
+	N_("Slant Range :"),
+	N_("Range Rate :"),
+	N_("Next Event :"),
+	N_("Next AOS :"),
+	N_("Next LOS :"),
+	N_("SSP Lat. :"),
+	N_("SSP Lon. :"),
+	N_("SSP Loc. :"),
+	N_("Footprint :"),
+	N_("Altitude :"),
+	N_("Velocity :"),
+	N_("Doppler :"),
+	N_("Sig. Loss :"),
+	N_("Sig. Delay :"),
+	N_("Mean Anom. :"),
+	N_("Orbit Phase :"),
+	N_("Orbit Num. :"),
+	N_("Visibility :")
 };
 
 
 /** \brief Column title hints indexed with column symb. refs. */
 const gchar *SINGLE_SAT_FIELD_HINT[SINGLE_SAT_FIELD_NUMBER] = {
 	N_("Azimuth"),
-        N_("Elevation"),
-        N_("Direction"),
-        N_("Right Ascension"),
-        N_("Declination"),
-        N_("Slant Range"),
-        N_("Range Rate"),
-        N_("Next Event"),
-        N_("Next AOS"),
-        N_("Next LOS"),
-        N_("Latitude"),
-        N_("Longitude"),
-        N_("Sub-Satellite Point"),
-        N_("Footprint"),
-        N_("Altitude"),
-        N_("Velocity"),
-        N_("Doppler Shift @ 100MHz"),
-        N_("Signal Loss @ 100MHz"),
-        N_("Signal Delay"),
-        N_("Mean Anomaly"),
-        N_("Orbit Phase"),
-        N_("Orbit Number"),
-        N_("Visibility")
+	N_("Elevation"),
+	N_("Direction"),
+	N_("Right Ascension"),
+	N_("Declination"),
+	N_("Slant Range"),
+	N_("Range Rate"),
+	N_("Next Event"),
+	N_("Next AOS"),
+	N_("Next LOS"),
+	N_("Latitude"),
+	N_("Longitude"),
+	N_("Sub-Satellite Point"),
+	N_("Footprint"),
+	N_("Altitude"),
+	N_("Velocity"),
+	N_("Doppler Shift @ 100MHz"),
+	N_("Signal Loss @ 100MHz"),
+	N_("Signal Delay"),
+	N_("Mean Anomaly"),
+	N_("Orbit Phase"),
+	N_("Orbit Number"),
+	N_("Visibility")
 };
 
 
@@ -124,25 +124,24 @@ gtk_single_sat_get_type ()
 {
 	static GType gtk_single_sat_type = 0;
 
-	if (!gtk_single_sat_type)
-	{
-		static const GTypeInfo gtk_single_sat_info =
-			{
-				sizeof (GtkSingleSatClass),
-				NULL,  /* base_init */
-				NULL,  /* base_finalize */
-				(GClassInitFunc) gtk_single_sat_class_init,
-				NULL,  /* class_finalize */
-				NULL,  /* class_data */
-				sizeof (GtkSingleSat),
-				5,     /* n_preallocs */
-				(GInstanceInitFunc) gtk_single_sat_init,
-			};
+	if (!gtk_single_sat_type) {
+
+		static const GTypeInfo gtk_single_sat_info = {
+			sizeof (GtkSingleSatClass),
+			NULL,  /* base_init */
+			NULL,  /* base_finalize */
+			(GClassInitFunc) gtk_single_sat_class_init,
+			NULL,  /* class_finalize */
+			NULL,  /* class_data */
+			sizeof (GtkSingleSat),
+			5,     /* n_preallocs */
+			(GInstanceInitFunc) gtk_single_sat_init,
+		};
 
 		gtk_single_sat_type = g_type_register_static (GTK_TYPE_VBOX,
-							      "GtkSingleSat",
-							      &gtk_single_sat_info,
-							      0);
+													  "GtkSingleSat",
+													  &gtk_single_sat_info,
+													  0);
 	}
 
 	return gtk_single_sat_type;
@@ -173,19 +172,19 @@ gtk_single_sat_class_init (GtkSingleSatClass *class)
 static void
 gtk_single_sat_init (GtkSingleSat *list)
 {
-/* 	GtkWidget *vbox,*hbox; */
+	/* 	GtkWidget *vbox,*hbox; */
 
 
-/* 	hbox = gtk_hbox_new (TRUE, 5); */
-/* 	gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_label_new ("POLAR")); */
-/* 	gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_label_new ("LIST")); */
+	/* 	hbox = gtk_hbox_new (TRUE, 5); */
+	/* 	gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_label_new ("POLAR")); */
+	/* 	gtk_box_pack_start_defaults (GTK_BOX (hbox), gtk_label_new ("LIST")); */
 
-/* 	vbox = gtk_vbox_new (TRUE, 5); */
-/* 	gtk_box_pack_start_defaults (GTK_BOX (vbox), gtk_label_new ("MAP")); */
-/* 	gtk_box_pack_start_defaults (GTK_BOX (vbox), hbox); */
+	/* 	vbox = gtk_vbox_new (TRUE, 5); */
+	/* 	gtk_box_pack_start_defaults (GTK_BOX (vbox), gtk_label_new ("MAP")); */
+	/* 	gtk_box_pack_start_defaults (GTK_BOX (vbox), hbox); */
 
-/* 	gtk_container_add (GTK_CONTAINER (module), vbox); */
-/* 	gtk_widget_show_all (vbox); */
+	/* 	gtk_container_add (GTK_CONTAINER (module), vbox); */
+	/* 	gtk_widget_show_all (vbox); */
 
 	/* initialise data structures */
 
@@ -230,24 +229,24 @@ gtk_single_sat_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth, guint32 fie
 		GTK_SINGLE_SAT (widget)->flags = fields;
 	else
 		GTK_SINGLE_SAT (widget)->flags = mod_cfg_get_int (cfgdata,
-								  MOD_CFG_SINGLE_SAT_SECTION,
-								  MOD_CFG_SINGLE_SAT_FIELDS,
-								  SAT_CFG_INT_SINGLE_SAT_FIELDS);
+														  MOD_CFG_SINGLE_SAT_SECTION,
+														  MOD_CFG_SINGLE_SAT_FIELDS,
+														  SAT_CFG_INT_SINGLE_SAT_FIELDS);
 	
 
 	/* get refresh rate and cycle counter */
 	GTK_SINGLE_SAT (widget)->refresh = mod_cfg_get_int (cfgdata,
-							    MOD_CFG_SINGLE_SAT_SECTION,
-							    MOD_CFG_SINGLE_SAT_REFRESH,
-							    SAT_CFG_INT_SINGLE_SAT_REFRESH);
+														MOD_CFG_SINGLE_SAT_SECTION,
+														MOD_CFG_SINGLE_SAT_REFRESH,
+														SAT_CFG_INT_SINGLE_SAT_REFRESH);
 	GTK_SINGLE_SAT (widget)->counter = 1;
 
 	/* popup button */
 	GTK_SINGLE_SAT (widget)->popup_button =
 		gpredict_mini_mod_button ("gpredict-mod-popup.png",
-					  _("Satellite options / shortcuts"));
+								  _("Satellite options / shortcuts"));
 	g_signal_connect (GTK_SINGLE_SAT (widget)->popup_button, "clicked",
-			  G_CALLBACK (gtk_single_sat_popup_cb), widget);
+					  G_CALLBACK (gtk_single_sat_popup_cb), widget);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), GTK_SINGLE_SAT (widget)->popup_button, FALSE, FALSE, 0);
@@ -280,8 +279,8 @@ gtk_single_sat_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth, guint32 fie
 			label1 = gtk_label_new (SINGLE_SAT_FIELD_TITLE[i]);
 			gtk_misc_set_alignment (GTK_MISC (label1), 1.0, 0.5);
 			gtk_table_attach (GTK_TABLE (GTK_SINGLE_SAT (widget)->table), label1,
-					  0, 1, i, i+1,
-					  GTK_FILL,  GTK_SHRINK, 0, 0);
+							  0, 1, i, i+1,
+							  GTK_FILL,  GTK_SHRINK, 0, 0);
 			/* FIXME: does not work
 			   tips = gtk_tooltips_new ();
 			   gtk_tooltips_set_tip (tips, label1, SINGLE_SAT_FIELD_HINT[i], NULL);
@@ -290,8 +289,8 @@ gtk_single_sat_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth, guint32 fie
 			label2 = gtk_label_new ("-");
 			gtk_misc_set_alignment (GTK_MISC (label2), 0.0, 0.5);
 			gtk_table_attach (GTK_TABLE (GTK_SINGLE_SAT (widget)->table), label2,
-					  1, 2, i, i+1,
-					  GTK_FILL,  GTK_SHRINK, 0, 0);
+							  1, 2, i, i+1,
+							  GTK_FILL,  GTK_SHRINK, 0, 0);
 
 			/* store reference */
 			GTK_SINGLE_SAT (widget)->labels[i] = label2;
@@ -303,9 +302,9 @@ gtk_single_sat_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth, guint32 fie
 	/* create and initialise scrolled window */
 	GTK_SINGLE_SAT (widget)->swin = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (GTK_SINGLE_SAT (widget)->swin),
-					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+									GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (GTK_SINGLE_SAT (widget)->swin),
-					       GTK_SINGLE_SAT (widget)->table);
+										   GTK_SINGLE_SAT (widget)->table);
 
 
 	gtk_box_pack_end (GTK_BOX (widget), GTK_SINGLE_SAT (widget)->swin, TRUE, TRUE, 0);
@@ -332,8 +331,8 @@ gtk_single_sat_update          (GtkWidget *widget)
 	if ((ssat == NULL) || !IS_GTK_SINGLE_SAT (ssat)) {
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Invalid GtkSingleSat!"),
-			     __FUNCTION__);
+					 _("%s: Invalid GtkSingleSat!"),
+					 __FUNCTION__);
 	}
 
 
@@ -391,8 +390,8 @@ update_field            (GtkSingleSat *ssat, guint i)
 	if (ssat->labels[i] == NULL) {
 
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: Can not update invisible field (I:%d F:%d)"),
-			     __FILE__, __LINE__, i, ssat->flags);
+					 _("%s:%d: Can not update invisible field (I:%d F:%d)"),
+					 __FILE__, __LINE__, i, ssat->flags);
 
 		return;
 	}
@@ -674,8 +673,8 @@ update_field            (GtkSingleSat *ssat, guint i)
 
 	default:
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: Invalid field number (%d)"),
-			     __FILE__, __LINE__, i);
+					 _("%s:%d: Invalid field number (%d)"),
+					 __FILE__, __LINE__, i);
 
 		break;
 
@@ -690,12 +689,6 @@ update_field            (GtkSingleSat *ssat, guint i)
 }
 
 
-/** \brief Reload configuration */
-void
-gtk_single_sat_reconf          (GtkWidget *widget, GKeyFile *cfgdat)
-{
-}
-
 
 
 /** \brief Copy satellite from hash table to singly linked list.
@@ -715,8 +708,8 @@ store_sats (gpointer key, gpointer value, gpointer user_data)
 static void
 Calculate_RADec (sat_t *sat, qth_t *qth, obs_astro_t *obs_set)
 {
-/* Reference:  Methods of Orbit Determination by  */
-/*                Pedro Ramon Escobal, pp. 401-402 */
+	/* Reference:  Methods of Orbit Determination by  */
+	/*                Pedro Ramon Escobal, pp. 401-402 */
 
 	double phi,theta,sin_theta,cos_theta,sin_phi,cos_phi,
 		az,el,Lxh,Lyh,Lzh,Sx,Ex,Zx,Sy,Ey,Zy,Sz,Ez,Zz,
@@ -799,15 +792,15 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
 	g_free (buff);
 	gtk_container_add (GTK_CONTAINER (menuitem), label);
 	image = gtk_image_new_from_stock (GTK_STOCK_INFO,
-					  GTK_ICON_SIZE_MENU);
+									  GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 
 	/* attach data to menuitem and connect callback */
 	g_object_set_data (G_OBJECT (menuitem), "sat", sat);
 	g_object_set_data (G_OBJECT (menuitem), "qth", single_sat->qth);
 	g_signal_connect (menuitem, "activate",
-			  G_CALLBACK (show_sat_info),
-			  gtk_widget_get_toplevel (button));
+					  G_CALLBACK (show_sat_info),
+					  gtk_widget_get_toplevel (button));
 
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 
@@ -818,24 +811,24 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
 	/* next pass and predict passes */
 	menuitem = gtk_image_menu_item_new_with_label (_("Show next pass"));
 	image = gtk_image_new_from_stock (GTK_STOCK_JUSTIFY_FILL,
-					  GTK_ICON_SIZE_MENU);
+									  GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 	g_object_set_data (G_OBJECT (menuitem), "sat", sat);
 	g_object_set_data (G_OBJECT (menuitem), "qth", single_sat->qth);
 	g_signal_connect (menuitem, "activate",
-			  G_CALLBACK (show_next_pass),
-			  gtk_widget_get_toplevel (button));
+					  G_CALLBACK (show_next_pass),
+					  gtk_widget_get_toplevel (button));
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 		
 	menuitem = gtk_image_menu_item_new_with_label (_("Future passes"));
 	image = gtk_image_new_from_stock (GTK_STOCK_INDEX,
-					  GTK_ICON_SIZE_MENU);
+									  GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
 	g_object_set_data (G_OBJECT (menuitem), "sat", sat);
 	g_object_set_data (G_OBJECT (menuitem), "qth", single_sat->qth);
 	g_signal_connect (menuitem, "activate",
-			  G_CALLBACK (show_future_passes),
-			  gtk_widget_get_toplevel (button));
+					  G_CALLBACK (show_future_passes),
+					  gtk_widget_get_toplevel (button));
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 
 	/* separator */
@@ -860,7 +853,7 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
 
 		/* connect signal */
 		g_signal_connect_after (menuitem, "activate",
-				  G_CALLBACK (select_satellite), single_sat);
+								G_CALLBACK (select_satellite), single_sat);
 
 		gtk_menu_shell_append (GTK_MENU_SHELL (select_menu), menuitem);
 		//gtk_widget_show (menuitem);
@@ -891,7 +884,7 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
 	/* Note: event can be NULL here when called from view_onPopupMenu;
 	 *  gdk_event_get_time() accepts a NULL argument */
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
-			0, gdk_event_get_time ((GdkEvent*) NULL));
+					0, gdk_event_get_time ((GdkEvent*) NULL));
 		
 
 }
@@ -921,3 +914,71 @@ select_satellite        (GtkWidget *menuitem, gpointer data)
 
 	}
 }
+
+
+
+/** \brief Refresh internal references to the satellites.
+ */
+void
+gtk_single_sat_reload_sats (GtkWidget *single_sat, GHashTable *sats)
+{
+
+	/* free GSlists */
+	g_slist_free (GTK_SINGLE_SAT (single_sat)->sats);
+	GTK_SINGLE_SAT (single_sat)->sats = NULL;
+
+	/* reload satellites */
+	g_hash_table_foreach (sats, store_sats, single_sat);
+
+}
+
+
+/** \brief Reload configuration.
+ *  \param widget The GtkSingleSat widget.
+ *  \param newcfg The new configuration data for the module
+ *  \param sats   The satellites.
+ *  \param local  Flag indicating whether reconfiguration is requested from 
+ *                local configuration dialog.
+ */
+void
+gtk_single_sat_reconf          (GtkWidget    *widget,
+								GKeyFile     *newcfg,
+								GHashTable   *sats,
+								qth_t        *qth,
+								gboolean      local)
+{
+	guint32 fields;
+
+
+	/* store pointer to new cfg data */
+	GTK_SINGLE_SAT (widget)->cfgdata = newcfg;
+
+	/* get visible fields from new configuration */
+	fields = mod_cfg_get_int (newcfg,
+							  MOD_CFG_SINGLE_SAT_SECTION,
+							  MOD_CFG_SINGLE_SAT_FIELDS,
+							  SAT_CFG_INT_SINGLE_SAT_FIELDS);
+
+	if (fields != GTK_SINGLE_SAT (widget)->flags) {
+		GTK_SINGLE_SAT (widget)->flags = fields;
+
+		/* */
+	}
+
+	/* if this is a local reconfiguration sats may have changed */
+	if (local) {
+		gtk_single_sat_reload_sats (widget, sats);
+	}
+
+	/* QTH may have changed too since we have a default QTH */
+	GTK_SINGLE_SAT (widget)->qth = qth;
+
+
+	/* get refresh rate and cycle counter */
+	GTK_SINGLE_SAT (widget)->refresh = mod_cfg_get_int (newcfg,
+														MOD_CFG_SINGLE_SAT_SECTION,
+														MOD_CFG_SINGLE_SAT_REFRESH,
+														SAT_CFG_INT_SINGLE_SAT_REFRESH);
+	GTK_SINGLE_SAT (widget)->counter = 1;
+}
+
