@@ -40,11 +40,14 @@
 #include <glib/gi18n.h>
 #include "sat-pref.h"
 #include "mod-cfg.h"
+#include "sat-cfg.h"
 #include "mod-mgr.h"
 #include "sat-log.h"
 #include "about.h"
 #include "gtk-sat-module.h"
 #include "gpredict-help.h"
+#include "tle-update.h"
+#include "compat.h"
 #include "menubar.h"
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -59,13 +62,12 @@ static void   menubar_open_mod_cb  (GtkWidget *widget, gpointer data);
 static void   menubar_app_exit_cb  (GtkWidget *widget, gpointer data);
 static void   menubar_freq_edit_cb (GtkWidget *widget, gpointer data);
 static void   menubar_pref_cb      (GtkWidget *widget, gpointer data);
-static void   menubar_tle_cb       (GtkWidget *widget, gpointer data);
-static void   menubar_list_cb      (GtkWidget *widget, gpointer data);
-static void   menubar_plot_cb      (GtkWidget *widget, gpointer data);
+static void   menubar_tle_net_cb   (GtkWidget *widget, gpointer data);
+static void   menubar_tle_local_cb (GtkWidget *widget, gpointer data);
+static void   menubar_tle_manual_cb (GtkWidget *widget, gpointer data);
 static void   menubar_glance_cb    (GtkWidget *widget, gpointer data);
 static void   menubar_window_cb    (GtkWidget *widget, gpointer data);
 static void   menubar_predict_cb   (GtkWidget *widget, gpointer data);
-static void   menubar_lab_cb       (GtkWidget *widget, gpointer data);
 static void   menubar_getting_started_cb (GtkWidget *widget, gpointer data);
 static void   menubar_help_cb      (GtkWidget *widget, gpointer data);
 static void   menubar_about_cb     (GtkWidget *widget, gpointer data);
@@ -78,6 +80,7 @@ static gchar *select_module        (void);
 static GtkActionEntry entries[] = {
 	{ "FileMenu", NULL, N_("_File") },
 	{ "EditMenu", NULL, N_("_Edit") },
+	{ "TleMenu", GTK_STOCK_REFRESH, N_("_Update TLE") },
 	{ "ToolsMenu", NULL, N_("_Tools") },
 	{ "HelpMenu", NULL, N_("_Help") },
 
@@ -90,6 +93,17 @@ static GtkActionEntry entries[] = {
 	  N_("Exit the program"), G_CALLBACK (menubar_app_exit_cb) },
 
 	/* Edit menu */
+	/*	{ "Tle", GTK_STOCK_REFRESH, N_("Update TLE"), NULL,
+		N_("Update Keplerian elements"), NULL},*/
+	{ "Net", GTK_STOCK_NETWORK, N_("From _network"), NULL,
+	  N_("Update Keplerian elements from a network server"),
+	  G_CALLBACK(menubar_tle_net_cb)},
+	{ "Local", GTK_STOCK_HARDDISK, N_("From l_ocal files"), NULL,
+	  N_("Update Keplerian elements from local files"),
+	  G_CALLBACK(menubar_tle_local_cb)},
+	{ "Man", GTK_STOCK_DND, N_("Using TLE _editor"), NULL,
+	  N_("Add or update Keplerian elements using the TLE editor"),
+	  G_CALLBACK(menubar_tle_manual_cb)},
 	{ "Freq", NULL, N_("_Transponders"), NULL,
 	  N_("Edit satellite transponder frequencies"),
 	  G_CALLBACK (menubar_freq_edit_cb)},
@@ -97,15 +111,14 @@ static GtkActionEntry entries[] = {
 	  N_("Edit user preferences"), G_CALLBACK (menubar_pref_cb)},
 
 	/* Tools menu */
-	{ "Tle", GTK_STOCK_REFRESH, N_("Update TLE"), "<control>T",
-	  N_("Update Keplerian elements"), G_CALLBACK (menubar_tle_cb)},
-	{ "Glance", GTK_STOCK_PASTE, N_("Sky at a glance"), "<control>G",
+	{ "Glance", NULL, N_("Sky at a glance"), "<control>G",
 	  N_("Show quick overview of the sky now and in the near future"),
 	  G_CALLBACK (menubar_glance_cb)},
 	{ "Window", NULL, N_("Window"), "<control>W",
-	  N_("Predict windows between two observers"), G_CALLBACK (menubar_window_cb)},
+	  N_("Predict windows between two observers"),
+	  G_CALLBACK (menubar_window_cb)},
 	{ "Predict", GTK_STOCK_DND_MULTIPLE, N_("Advanced Predict"), NULL,
-	  N_("Opean advanced pass predictor"), G_CALLBACK (menubar_predict_cb)},
+	  N_("Open advanced pass predictor"), G_CALLBACK (menubar_predict_cb)},
 
 	/* Help menu */
 	{ "GettingStarted", GTK_STOCK_EXECUTE, N_("Getting Started"), NULL,
@@ -131,11 +144,16 @@ static const char *menu_desc =
 "         <menuitem action='Exit'/>"
 "      </menu>"
 "      <menu action='EditMenu'>"
+"         <menu action='TleMenu'>"
+"            <menuitem action='Net'/>"
+"            <menuitem action='Local'/>"
+"            <menuitem action='Man'/>"
+"         </menu>"
 /* "         <menuitem action='Freq'/>" */
+"         <separator/>"
 "         <menuitem action='Pref'/>"
 "      </menu>"
 /* "      <menu action='ToolsMenu'>" */
-/* "         <menuitem action='Tle'/>" */
 /* "         <separator/>" */
 /* "         <menuitem action='Glance'/>" */
 /* "         <menuitem action='Predict'/>" */
@@ -168,6 +186,10 @@ menubar_create (GtkWidget *window)
 	GtkUIManager   *uimgr;
 	GtkAccelGroup  *accgrp;
 	GError         *error = NULL;
+	GtkWidget      *menuitem;
+	GtkWidget      *image;
+	gchar          *icon;
+
 
 	/* create action group */
 	actgrp = gtk_action_group_new ("MenuActions");
@@ -189,6 +211,13 @@ menubar_create (GtkWidget *window)
 		return NULL;
 	}
 
+	/* load custom icons */
+/* 	icon = icon_file_name ("gpredict-planner-small.png"); */
+/* 	image = gtk_image_new_from_file (icon); */
+/* 	g_free (icon); */
+/* 	menuitem = gtk_ui_manager_get_widget (uimgr, "/GpredictMenu/ToolsMenu/Glance"); */
+/* 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image); */
+
 	/* now, finally, get the menubar */
 	menubar = gtk_ui_manager_get_widget (uimgr, "/GpredictMenu");
 
@@ -344,7 +373,6 @@ menubar_open_mod_cb  (GtkWidget *widget, gpointer data)
 static void
 menubar_app_exit_cb  (GtkWidget *widget, gpointer data)
 {
-
 	gtk_widget_destroy (app);
 }
 
@@ -362,24 +390,297 @@ menubar_pref_cb      (GtkWidget *widget, gpointer data)
 }
 
 
+/** \brief Update TLE from network.
+ *  \param widget The menu item (unused).
+ *  \param data User data (unused).
+ *
+ * This function is called when the user selects
+ *      Edit -> Update TLE -> Update from network
+ * in the menubar.
+ * The function calls tle_update_from_network with silent flag FALSE.
+ */
 static void
-menubar_tle_cb       (GtkWidget *widget, gpointer data)
+menubar_tle_net_cb       (GtkWidget *widget, gpointer data)
 {
+	GtkWidget *dialog;          /* dialog window  */
+	GtkWidget *label;           /* misc labels */
+	GtkWidget *progress;        /* progress indicator */
+	GtkWidget *label1,*label2;  /* activitity and stats labels */
+	GtkWidget *box;
+
+
+	/* create new dialog with progress indicator */
+	dialog = gtk_dialog_new_with_buttons (_("TLE Update"),
+										  GTK_WINDOW (app),
+										  GTK_DIALOG_MODAL | 
+										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  GTK_STOCK_CLOSE,
+										  GTK_RESPONSE_ACCEPT,
+										  NULL);
+	//gtk_window_set_default_size (GTK_WINDOW (dialog), 500, 300);
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
+									   GTK_RESPONSE_ACCEPT,
+									   FALSE);
+
+
+	/* create a vbox */
+	box = gtk_vbox_new (FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (box), 20);
+		
+	/* add static label */
+	label = gtk_label_new (NULL);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
+	gtk_label_set_markup (GTK_LABEL (label),
+						  _("<b>Updating TLE files from network</b>"));
+	gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+
+	/* activity label */
+	label1 = gtk_label_new ("...");
+	gtk_misc_set_alignment (GTK_MISC (label1), 0.5, 0.5);
+	gtk_box_pack_start (GTK_BOX (box), label1, FALSE, FALSE, 0);
+								  
+	/* add progress bar */
+	progress = gtk_progress_bar_new ();
+	gtk_box_pack_start (GTK_BOX (box), progress, FALSE, FALSE, 10);
+
+	/* statistics */
+	label2 = gtk_label_new (_("Satellites updated:\t 0\n"\
+							  "Satellites skipped:\t 0\n"\
+							  "Missing Satellites:\t 0"));
+	gtk_box_pack_start (GTK_BOX (box), label2, TRUE, TRUE, 0);		
+
+	/* finalise dialog */
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), box);
+	g_signal_connect_swapped (dialog,
+							  "response", 
+							  G_CALLBACK (gtk_widget_destroy),
+							  dialog);
+
+	gtk_widget_show_all (dialog);
+
+	/* Force the drawing queue to be processed otherwise the dialog
+	   may not appear before we enter the TLE updating func
+	   - see Gtk+ FAQ http://www.gtk.org/faq/#AEN602
+	*/
+	while (g_main_context_iteration (NULL, FALSE));
+
+	/* update TLE */
+	tle_update_from_network (FALSE, progress, label1, label2);
+
+	/* set progress bar to 100% */
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress), 1.0);
+
+	gtk_label_set_text (GTK_LABEL (label1), _("Finished"));
+
+	/* enable close button */
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
+									   GTK_RESPONSE_ACCEPT,
+									   TRUE);
+
+	/* reload satellites */
+	mod_mgr_reload_sats ();
+
 }
 
 
+/** \brief Update TLE from local files.
+ *  \param widget The menu item (unused).
+ *  \param data User data (unused).
+ *
+ * This function is called when the user selects
+ *      Edit -> Update TLE -> From local files
+ * in the menubar.
+ *
+ * First the function creates the GUI status indicator infrastructure
+ * with the possibility to select a directory, then it calls the
+ * tle_update_from_files with the corresponding parameters.
+ *
+ * Finally, the programs signals the module manager to reload the
+ * satellites in each module.
+ *
+ * FIXME: fork as a thread?
+ */
 static void
-menubar_list_cb (GtkWidget *widget, gpointer data)
+menubar_tle_local_cb       (GtkWidget *widget, gpointer data)
 {
+	gchar     *dir;          /* selected directory */
+	GtkWidget *dir_chooser;  /* directory chooser button */
+	GtkWidget *dialog;       /* dialog window  */
+	GtkWidget *label;        /* misc labels */
+	GtkWidget *progress;     /* progress indicator */
+	GtkWidget *label1,*label2;  /* activitity and stats labels */
+	GtkWidget *box;
+	gint       response;     /* dialog response */
+	gboolean   doupdate = FALSE;
+
+
+	/* get last used directory */
+	dir = sat_cfg_get_str (SAT_CFG_STR_TLE_FILE_DIR);
+
+	/* if there is no last used dir fall back to $HOME */
+	if (dir == NULL) {
+		dir = g_strdup (g_get_home_dir ());
+	}
+
+	/* create file chooser */
+	dir_chooser = gtk_file_chooser_button_new (_("Select directory"),
+											   GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
+	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dir_chooser), dir);
+	g_free (dir);
+
+	/* create label */
+	label = gtk_label_new (_("Select TLE directory:"));
+
+	/* pack label and chooser into a hbox */
+	box = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 5);
+	gtk_box_pack_start (GTK_BOX (box), dir_chooser, TRUE, TRUE, 5);
+	gtk_widget_show_all (box);
+
+	/* create the dalog */
+	dialog = gtk_dialog_new_with_buttons (_("Update TLE from files"),
+										  GTK_WINDOW (app),
+										  GTK_DIALOG_MODAL | 
+										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  GTK_STOCK_CANCEL,
+										  GTK_RESPONSE_REJECT,
+										  GTK_STOCK_OK,
+										  GTK_RESPONSE_ACCEPT,
+										  NULL);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), box, TRUE, TRUE, 30);
+
+	response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	switch (response) {
+
+	case GTK_RESPONSE_ACCEPT:
+		/* set flag to indicate that we should do an update */
+		doupdate = TRUE;
+		break;
+
+	default:
+		doupdate = FALSE;
+		break;
+	}
+
+
+	/* get directory before we destroy the dialog */
+	dir = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dir_chooser));
+
+	/* nuke the dialog */
+	gtk_widget_destroy (dialog);
+
+	if (doupdate) {
+
+		sat_log_log (SAT_LOG_LEVEL_MSG,
+					 _("%s: Running TLE update from %s"),
+					 __FUNCTION__, dir);
+
+		/* store last used TLE dir */
+		sat_cfg_set_str (SAT_CFG_STR_TLE_FILE_DIR, dir);
+
+		/* create new dialog with progress indicator */
+		dialog = gtk_dialog_new_with_buttons (_("TLE Update"),
+											  GTK_WINDOW (app),
+											  GTK_DIALOG_MODAL | 
+											  GTK_DIALOG_DESTROY_WITH_PARENT,
+											  GTK_STOCK_CLOSE,
+											  GTK_RESPONSE_ACCEPT,
+											  NULL);
+		//gtk_window_set_default_size (GTK_WINDOW (dialog), 400,250);
+		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
+										   GTK_RESPONSE_ACCEPT,
+										   FALSE);
+
+		/* create a vbox */
+		box = gtk_vbox_new (FALSE, 0);
+		gtk_container_set_border_width (GTK_CONTAINER (box), 20);
+		
+		/* add static label */
+		label = gtk_label_new (NULL);
+		gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
+		gtk_label_set_markup (GTK_LABEL (label),
+							  _("<b>Updating TLE files from files</b>"));
+		gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+
+		/* activity label */
+		label1 = gtk_label_new ("...");
+		gtk_misc_set_alignment (GTK_MISC (label1), 0.5, 0.5);
+		gtk_box_pack_start (GTK_BOX (box), label1, FALSE, FALSE, 0);
+		
+									  
+		/* add progress bar */
+		progress = gtk_progress_bar_new ();
+		gtk_box_pack_start (GTK_BOX (box), progress, FALSE, FALSE, 10);
+
+		/* statistics */
+		label2 = gtk_label_new (_("Satellites updated:\t 0\n"\
+								  "Satellites skipped:\t 0\n"\
+								  "Missing Satellites:\t 0"));
+		gtk_box_pack_start (GTK_BOX (box), label2, TRUE, TRUE, 0);		
+
+		/* finalise dialog */
+		gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), box);
+		g_signal_connect_swapped (dialog,
+								  "response", 
+								  G_CALLBACK (gtk_widget_destroy),
+								  dialog);
+
+		gtk_widget_show_all (dialog);
+
+		/* Force the drawing queue to be processed otherwise the dialog
+		   may not appear before we enter the TLE updating func
+		   - see Gtk+ FAQ http://www.gtk.org/faq/#AEN602
+		*/
+		while (g_main_context_iteration (NULL, FALSE));
+
+		/* update TLE */
+		tle_update_from_files (dir, NULL, FALSE, progress, label1, label2);
+
+		/* set progress bar to 100% */
+		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress), 1.0);
+
+		gtk_label_set_text (GTK_LABEL (label1), _("Finished"));
+
+		/* enable close button */
+		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
+										   GTK_RESPONSE_ACCEPT,
+										   TRUE);
+
+	}
+
+	if (dir)
+		g_free (dir);
+
+	/* reload satellites */
+	mod_mgr_reload_sats ();
 }
 
 
+/** \brief Start Manual TLE editor. */
 static void
-menubar_plot_cb (GtkWidget *widget, gpointer data)
+menubar_tle_manual_cb       (GtkWidget *widget, gpointer data)
 {
+	GtkWidget *dialog;
+
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (app),
+									 GTK_DIALOG_DESTROY_WITH_PARENT,
+									 GTK_MESSAGE_INFO,
+									 GTK_BUTTONS_OK,
+									 _("This function is still under development."));
+
+	/* Destroy the dialog when the user responds to it (e.g. clicks a button) */
+	g_signal_connect_swapped (dialog, "response",
+							  G_CALLBACK (gtk_widget_destroy),
+							  dialog);
+
+	gtk_widget_show_all (dialog);
 }
 
 
+
+
 static void
 menubar_glance_cb (GtkWidget *widget, gpointer data)
 {
@@ -397,10 +698,6 @@ menubar_predict_cb   (GtkWidget *widget, gpointer data)
 {
 }
 
-static void
-menubar_lab_cb   (GtkWidget *widget, gpointer data)
-{
-}
 
 static void
 menubar_getting_started_cb (GtkWidget *widget, gpointer data)
