@@ -1,58 +1,58 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 /*
 
-        +------------------------------------+
-        |           +---------------------+  |
-        |  Name     | My Kool Module      |  |
-        |           +---------------------+  |
-        |           +-----------+---+ +---+  |
-        |  Location | OZ9AEC    | v | | + |  |
-        |           +-----------+---+ +---+  |
-        | ---------------------------------- |
-        |             Satellites             |
-        | +--------------------------+-----+ |
-        | | Name                     | Sel | |
-        | +--------------------------+-----+ |      
-        | | > Amateur                |     | |
-        | | v Weather                |     | |
-        | |     NOAA 14              |  x  | |
-        | |     NOAA 15              |  x  | |
-        | |     NOAA 17              |  x  | |
-        | | > Military               |     | |
-        | +--------------------------+-----+ |
-        | ---------------------------------- |
-        | +----------------------+ +------+  |
-        | |  (not implemented)   | | Find |  |
-        | +----------------------+ +------+  |
-        |                                    |
-        |      Advanced Settings             |
-        +------------------------------------+
++------------------------------------+
+|           +---------------------+  |
+|  Name     | My Kool Module      |  |
+|           +---------------------+  |
+|           +-----------+---+ +---+  |
+|  Location | OZ9AEC    | v | | + |  |
+|           +-----------+---+ +---+  |
+| ---------------------------------- |
+|             Satellites             |
+| +--------------------------+-----+ |
+| | Name                     | Sel | |
+| +--------------------------+-----+ |      
+| | > Amateur                |     | |
+| | v Weather                |     | |
+| |     NOAA 14              |  x  | |
+| |     NOAA 15              |  x  | |
+| |     NOAA 17              |  x  | |
+| | > Military               |     | |
+| +--------------------------+-----+ |
+| ---------------------------------- |
+| +----------------------+ +------+  |
+| |  (not implemented)   | | Find |  |
+| +----------------------+ +------+  |
+|                                    |
+|      Advanced Settings             |
++------------------------------------+
 */
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -83,8 +83,8 @@ static GtkWidget *tree;   /* GtkSatTree for selecting satellites */
 
 /* private functions prototype */
 static GtkWidget *mod_cfg_editor_create (const gchar *modname,
-					 GKeyFile *cfgdata,
-					 GtkWidget *toplevel);
+										 GKeyFile *cfgdata,
+										 GtkWidget *toplevel);
 static void       mod_cfg_apply         (GKeyFile *cfgdata);
 static void       name_changed          (GtkWidget *widget, gpointer data);
 static GtkWidget *create_loc_selector   (GKeyFile *cfgdata);
@@ -136,27 +136,27 @@ mod_cfg_new    ()
 
 				/* check if there is already a module with this name */
 				filename = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-							".gpredict2", G_DIR_SEPARATOR_S,
-							"modules", G_DIR_SEPARATOR_S,
-							gtk_entry_get_text (GTK_ENTRY (namew)),
-							".mod", NULL);
+										".gpredict2", G_DIR_SEPARATOR_S,
+										"modules", G_DIR_SEPARATOR_S,
+										gtk_entry_get_text (GTK_ENTRY (namew)),
+										".mod", NULL);
 
 				if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 					GtkWidget *warn;
 
 					sat_log_log (SAT_LOG_LEVEL_DEBUG,
-						     _("%s: Already have module %s. Ask user to confirm..."),
-						     __FUNCTION__, gtk_entry_get_text (GTK_ENTRY (namew)));
+								 _("%s: Already have module %s. Ask user to confirm..."),
+								 __FUNCTION__, gtk_entry_get_text (GTK_ENTRY (namew)));
 
 					warn = gtk_message_dialog_new (//NULL,
-								       GTK_WINDOW (app),
-								       GTK_DIALOG_MODAL |
-								       GTK_DIALOG_DESTROY_WITH_PARENT,
-								       GTK_MESSAGE_QUESTION,
-								       GTK_BUTTONS_YES_NO,
-								       _("There is already a module called %s.\n"\
-									 "Do you want to overwrite this module?"),
-								       gtk_entry_get_text (GTK_ENTRY (namew)));
+												   GTK_WINDOW (app),
+												   GTK_DIALOG_MODAL |
+												   GTK_DIALOG_DESTROY_WITH_PARENT,
+												   GTK_MESSAGE_QUESTION,
+												   GTK_BUTTONS_YES_NO,
+												   _("There is already a module called %s.\n"\
+													 "Do you want to overwrite this module?"),
+												   gtk_entry_get_text (GTK_ENTRY (namew)));
 					switch (gtk_dialog_run (GTK_DIALOG (warn))) {
 
 					case GTK_RESPONSE_YES:
@@ -180,8 +180,8 @@ mod_cfg_new    ()
 					if (status != MOD_CFG_OK) {
 						/* send an error message */
 						sat_log_log (SAT_LOG_LEVEL_ERROR,
-							     _("%s: Error while saving module data (%d)."),
-							     __FUNCTION__, status);
+									 _("%s: Error while saving module data (%d)."),
+									 __FUNCTION__, status);
 					}
 
 					finished = TRUE;
@@ -191,20 +191,20 @@ mod_cfg_new    ()
 			}
 			else {
 				sat_log_log (SAT_LOG_LEVEL_DEBUG,
-					     _("%s: User tried to create module with no sats."),
-					     __FUNCTION__);
+							 _("%s: User tried to create module with no sats."),
+							 __FUNCTION__);
 
 				/* tell user to behave nicely */
 				GtkWidget *errdialog;
 
 				errdialog = gtk_message_dialog_new (NULL,
-								    //GTK_WINDOW (app),
-								    GTK_DIALOG_MODAL |
-								    GTK_DIALOG_DESTROY_WITH_PARENT,
-								    GTK_MESSAGE_ERROR,
-								    GTK_BUTTONS_OK,
-								    _("Please select at least one satellite "\
-								      "from the list."));
+													//GTK_WINDOW (app),
+													GTK_DIALOG_MODAL |
+													GTK_DIALOG_DESTROY_WITH_PARENT,
+													GTK_MESSAGE_ERROR,
+													GTK_BUTTONS_OK,
+													_("Please select at least one satellite "\
+													  "from the list."));
 				gtk_dialog_run (GTK_DIALOG (errdialog));
 				gtk_widget_destroy (errdialog);
 			}
@@ -280,19 +280,19 @@ mod_cfg_edit   (gchar *modname, GKeyFile *cfgdata, GtkWidget *toplevel)
 			}
 			else {
 				sat_log_log (SAT_LOG_LEVEL_DEBUG,
-					     _("%s: User tried to create module with no sats."),
-					     __FUNCTION__);
+							 _("%s: User tried to create module with no sats."),
+							 __FUNCTION__);
 
 				/* tell user not to do that */
 				GtkWidget *errdialog;
 
 				errdialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-								    GTK_DIALOG_MODAL |
-								    GTK_DIALOG_DESTROY_WITH_PARENT,
-								    GTK_MESSAGE_ERROR,
-								    GTK_BUTTONS_OK,
-								    _("Please select at least one satellite "\
-								      "from the list."));
+													GTK_DIALOG_MODAL |
+													GTK_DIALOG_DESTROY_WITH_PARENT,
+													GTK_MESSAGE_ERROR,
+													GTK_BUTTONS_OK,
+													_("Please select at least one satellite "\
+													  "from the list."));
 				gtk_dialog_run (GTK_DIALOG (errdialog));
 				gtk_widget_destroy (errdialog);
 			}
@@ -341,15 +341,15 @@ mod_cfg_save   (gchar *modname, GKeyFile *cfgdata)
 
 	if (!modname) {
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Attempt to save data to empty file name."),
-			     __FUNCTION__);
+					 _("%s: Attempt to save data to empty file name."),
+					 __FUNCTION__);
 
 		return MOD_CFG_ERROR;
 	}
 	if (!cfgdata) {
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s: Attempt to save NULL data."),
-			     __FUNCTION__);
+					 _("%s: Attempt to save NULL data."),
+					 __FUNCTION__);
 
 		return MOD_CFG_ERROR;
 	}
@@ -359,8 +359,8 @@ mod_cfg_save   (gchar *modname, GKeyFile *cfgdata)
 
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Could not create config data (%s)."),
-			     __FUNCTION__, error->message);
+					 _("%s: Could not create config data (%s)."),
+					 __FUNCTION__, error->message);
 
 		g_clear_error (&error);
 
@@ -369,16 +369,16 @@ mod_cfg_save   (gchar *modname, GKeyFile *cfgdata)
 
 	/* create file and write data stream */
 	filename = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-				".gpredict2", G_DIR_SEPARATOR_S,
-				"modules", G_DIR_SEPARATOR_S,
-				modname, ".mod", NULL);
+							".gpredict2", G_DIR_SEPARATOR_S,
+							"modules", G_DIR_SEPARATOR_S,
+							modname, ".mod", NULL);
 
 	cfgfile = g_io_channel_new_file (filename, "w", &error);
 
 	if (error != NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s: Could not create config file (%s)."),
-			     __FUNCTION__, error->message);
+					 _("%s: Could not create config file (%s)."),
+					 __FUNCTION__, error->message);
 
 		g_clear_error (&error);
 
@@ -386,18 +386,18 @@ mod_cfg_save   (gchar *modname, GKeyFile *cfgdata)
 	}
 	else {
 		g_io_channel_write_chars (cfgfile,
-					  datastream,
-					  length,
-					  &written,
-					  &error);
+								  datastream,
+								  length,
+								  &written,
+								  &error);
 
 		g_io_channel_shutdown (cfgfile, TRUE, NULL);
 		g_io_channel_unref (cfgfile);
 
 		if (error != NULL) {
 			sat_log_log (SAT_LOG_LEVEL_ERROR,
-				     _("%s: Error writing config data (%s)."),
-				     __FUNCTION__, error->message);
+						 _("%s: Error writing config data (%s)."),
+						 __FUNCTION__, error->message);
 			
 			g_clear_error (&error);
 			
@@ -405,15 +405,15 @@ mod_cfg_save   (gchar *modname, GKeyFile *cfgdata)
 		}
 		else if (length != written) {
 			sat_log_log (SAT_LOG_LEVEL_WARN,
-				     _("%s: Wrote only %d out of %d chars."),
-				     __FUNCTION__, written, length);
+						 _("%s: Wrote only %d out of %d chars."),
+						 __FUNCTION__, written, length);
 			
 			err = 1;
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_MSG,
-				     _("%s: Configuration saved for module %s."),
-				     __FUNCTION__, modname);
+						 _("%s: Configuration saved for module %s."),
+						 __FUNCTION__, modname);
 			
 			err = 0;
 		}
@@ -455,6 +455,7 @@ mod_cfg_editor_create (const gchar *modname, GKeyFile *cfgdata, GtkWidget *tople
 	GtkWidget   *table;
 	GtkWidget   *label;
 	GtkTooltips *tooltips;
+	gchar       *icon;      /* windo icon file name */
 
 
 
@@ -462,33 +463,42 @@ mod_cfg_editor_create (const gchar *modname, GKeyFile *cfgdata, GtkWidget *tople
 
 	if (new) {
 		dialog = gtk_dialog_new_with_buttons (_("Create New Module"),
-						      GTK_WINDOW (toplevel),
-						      GTK_DIALOG_MODAL |
-						      GTK_DIALOG_DESTROY_WITH_PARENT,
-						      GTK_STOCK_PROPERTIES,
-						      GTK_RESPONSE_HELP,
-						      GTK_STOCK_CANCEL,
-						      GTK_RESPONSE_CANCEL,
-						      GTK_STOCK_OK,
-						      GTK_RESPONSE_OK,
-						      NULL);
+											  GTK_WINDOW (toplevel),
+											  GTK_DIALOG_MODAL |
+											  GTK_DIALOG_DESTROY_WITH_PARENT,
+											  GTK_STOCK_PROPERTIES,
+											  GTK_RESPONSE_HELP,
+											  GTK_STOCK_CANCEL,
+											  GTK_RESPONSE_CANCEL,
+											  GTK_STOCK_OK,
+											  GTK_RESPONSE_OK,
+											  NULL);
 	}
 	else {
 		dialog = gtk_dialog_new_with_buttons (_("Edit Module"),
-						      GTK_WINDOW (toplevel),
-						      GTK_DIALOG_MODAL |
-						      GTK_DIALOG_DESTROY_WITH_PARENT,
-						      GTK_STOCK_PROPERTIES,
-						      GTK_RESPONSE_HELP,
-						      GTK_STOCK_CANCEL,
-						      GTK_RESPONSE_CANCEL,
-						      GTK_STOCK_OK,
-						      GTK_RESPONSE_OK,
-						      NULL);
+											  GTK_WINDOW (toplevel),
+											  GTK_DIALOG_MODAL |
+											  GTK_DIALOG_DESTROY_WITH_PARENT,
+											  GTK_STOCK_PROPERTIES,
+											  GTK_RESPONSE_HELP,
+											  GTK_STOCK_CANCEL,
+											  GTK_RESPONSE_CANCEL,
+											  GTK_STOCK_OK,
+											  GTK_RESPONSE_OK,
+											  NULL);
 	}
 
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
+	/* window icon */
+	icon = icon_file_name ("gpredict-sat-pref.png");
+	if (g_file_test (icon, G_FILE_TEST_EXISTS)) {
+		gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
+									   icon,
+									   NULL);
+	}
+	g_free (icon);
+
 	/* module name */
 	namew = gtk_entry_new ();
 
@@ -502,19 +512,19 @@ mod_cfg_editor_create (const gchar *modname, GKeyFile *cfgdata, GtkWidget *tople
 		gtk_entry_set_max_length (GTK_ENTRY (namew), 25);
 		tooltips = gtk_tooltips_new ();
 		gtk_tooltips_set_tip (tooltips, namew,
-				      _("Enter a short name for this module.\n"\
-					"Allowed charachters: 0..9, a..z, A..Z, - and _"),
-				      _("The name will be used to identify the module "\
-					"and it is also used a file name for saving the data."\
-					"Max length is 25 charachters."));
+							  _("Enter a short name for this module.\n"\
+								"Allowed charachters: 0..9, a..z, A..Z, - and _"),
+							  _("The name will be used to identify the module "\
+								"and it is also used a file name for saving the data."\
+								"Max length is 25 charachters."));
 
 		/* attach changed signal so that we can enable OK button when
 		   a proper name has been entered
 		   oh, btw. disable OK button to begin with....
 		*/
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-						   GTK_RESPONSE_OK,
-						   FALSE);
+										   GTK_RESPONSE_OK,
+										   FALSE);
 		g_signal_connect (namew, "changed", G_CALLBACK (name_changed), dialog);
 		
 	}
@@ -542,7 +552,7 @@ mod_cfg_editor_create (const gchar *modname, GKeyFile *cfgdata, GtkWidget *tople
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-			    gtk_hseparator_new (), FALSE, FALSE, 5);
+						gtk_hseparator_new (), FALSE, FALSE, 5);
 
 	label = gtk_label_new (NULL);
 	gtk_label_set_markup (GTK_LABEL (label), _("<b>Select Satellites:</b>"));
@@ -558,15 +568,15 @@ mod_cfg_editor_create (const gchar *modname, GKeyFile *cfgdata, GtkWidget *tople
 		guint   i;
 
 		sats = g_key_file_get_integer_list (cfgdata,
-						    MOD_CFG_GLOBAL_SECTION,
-						    MOD_CFG_SATS_KEY,
-						    &length,
-						    &error);
+											MOD_CFG_GLOBAL_SECTION,
+											MOD_CFG_SATS_KEY,
+											&length,
+											&error);
 			
 		if (error != NULL) {
 			sat_log_log (SAT_LOG_LEVEL_ERROR,
-				     _("%s: Failed to get list of satellites (%s)"),
-				     __FUNCTION__, error->message);
+						 _("%s: Failed to get list of satellites (%s)"),
+						 __FUNCTION__, error->message);
 
 			g_clear_error (&error);
 
@@ -609,31 +619,31 @@ name_changed          (GtkWidget *widget, gpointer data)
 
 
 	/* step 1: ensure that only valid characters are entered
-	           (stolen from xlog, tnx pg4i)
+	   (stolen from xlog, tnx pg4i)
 	*/
 	entry = gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1);
 	if ((len = g_utf8_strlen (entry, -1)) > 0)
-	{
-		end = entry + g_utf8_strlen (entry, -1);
-		for (j = entry; j < end; ++j)
 		{
-			switch (*j)
-			{
-				case '0' ... '9':
-				case 'a' ... 'z':
-				case 'A' ... 'Z':
-				case '-':
-				case '_':
-					break;
-				default:
-					gdk_beep ();
-					pos = gtk_editable_get_position (GTK_EDITABLE (widget));
-					gtk_editable_delete_text (GTK_EDITABLE (widget),
-								  pos, pos+1);
-					break;
-			}
+			end = entry + g_utf8_strlen (entry, -1);
+			for (j = entry; j < end; ++j)
+				{
+					switch (*j)
+						{
+						case '0' ... '9':
+						case 'a' ... 'z':
+						case 'A' ... 'Z':
+						case '-':
+						case '_':
+							break;
+						default:
+							gdk_beep ();
+							pos = gtk_editable_get_position (GTK_EDITABLE (widget));
+							gtk_editable_delete_text (GTK_EDITABLE (widget),
+													  pos, pos+1);
+							break;
+						}
+				}
 		}
-	}
 
 
 	/* step 2: if name seems all right, enable OK button */
@@ -641,13 +651,13 @@ name_changed          (GtkWidget *widget, gpointer data)
 
 	if (g_utf8_strlen (text, -1) > 0) {
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-						   GTK_RESPONSE_OK,
-						   TRUE);
+										   GTK_RESPONSE_OK,
+										   TRUE);
 	}
 	else {
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-						   GTK_RESPONSE_OK,
-						   FALSE);
+										   GTK_RESPONSE_OK,
+										   FALSE);
 	}
 }
 
@@ -655,7 +665,7 @@ name_changed          (GtkWidget *widget, gpointer data)
 /** \brief Create location selector combo box.
  *
  * This function creates the location selector combo box and initialises it
- * with the names of the existingf locations.
+ * with the names of the existing locations.
  */
 static GtkWidget *
 create_loc_selector   (GKeyFile *cfgdata)
@@ -665,29 +675,30 @@ create_loc_selector   (GKeyFile *cfgdata)
 	GError       *error = NULL;
 	gchar        *dirname;
 	const gchar  *filename;
-	gchar        *defqth;
+	gchar        *defqth = NULL;
 	gchar       **buffv;
-	gint         idx = 0;
+	gint         idx = -1;
 	gint         count = 0;
 
 
 	combo = gtk_combo_box_new_text ();
 
-	/* get qth file name from cfgdata; if cfgdataas no QTH
-	   get the defult one from sat-cfg
+	/* get qth file name from cfgdata; if cfg data has no QTH
+	   set defqth = "** DEFAULT **"
 	*/
-	defqth = g_key_file_get_string (cfgdata,
-					MOD_CFG_GLOBAL_SECTION,
-					MOD_CFG_QTH_FILE_KEY,
-					&error);
-	if ((defqth == NULL) || (error != NULL)) {
+
+	if (g_key_file_has_key (cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_QTH_FILE_KEY, NULL)) {
+		defqth = g_key_file_get_string (cfgdata,
+										MOD_CFG_GLOBAL_SECTION,
+										MOD_CFG_QTH_FILE_KEY,
+										&error);
+	}
+	else {
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s: Module has no QTH; use default."),
-			     __FUNCTION__);
+					 _("%s: Module has no QTH; use default."),
+					 __FUNCTION__);
 
-		g_clear_error (&error);
-
-		defqth = sat_cfg_get_str (SAT_CFG_STR_DEF_QTH);
+		defqth = g_strdup (_("** DEFAULT **"));
 	}
 
 
@@ -695,7 +706,7 @@ create_loc_selector   (GKeyFile *cfgdata)
 	   add the contents of each .qth file to the list store
 	*/
 	dirname = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-			       ".gpredict2", NULL);
+						   ".gpredict2", NULL);
 	dir = g_dir_open (dirname, 0, &error);
 
 	if (dir) {
@@ -705,8 +716,9 @@ create_loc_selector   (GKeyFile *cfgdata)
 
 				buffv = g_strsplit (filename, ".qth", 0);
 				gtk_combo_box_append_text (GTK_COMBO_BOX (combo), buffv[0]);
+				g_strfreev (buffv);
 
-				/* is this the default QTH? */
+				/* is this the QTH for this module? */
 				if (!g_ascii_strcasecmp (defqth, filename)) {
 					idx = count;
 				}
@@ -719,13 +731,28 @@ create_loc_selector   (GKeyFile *cfgdata)
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Failed to open user cfg dir %s (%s)"),
-			     __FILE__, __LINE__, dirname, error->message);
+					 _("%s:%d: Failed to open user cfg dir %s (%s)"),
+					 __FILE__, __LINE__, dirname, error->message);
 		g_clear_error (&error);
 	}
 
-	/* select default qth */
-	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), idx);
+	/* finally, add "** DEFAULT **" string; secting this will
+	   clear the MOD_CFG_QTH_FILE_KEY module configuration
+	   key ensuring that the module will use the default QTH
+	*/
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("** DEFAULT **"));
+
+
+	/* select the qth of this module;
+	   if idx == -1 we should select the "** DEFAULT **"
+	   string corresponding to index = count
+	*/
+	if (idx == -1) {
+		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), count);
+	}
+	else {
+		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), idx);
+	}
 
 	g_free (defqth);
 	g_free (dirname);
@@ -751,19 +778,32 @@ mod_cfg_apply         (GKeyFile *cfgdata)
 	guint *sats;
 	gsize num;
 	guint i;
-	gchar *satstr;
+	gchar *satstr = NULL;
 	gchar *buff;
 
 
 	/* store location */
 	buff = gtk_combo_box_get_active_text (GTK_COMBO_BOX (locw));
-	satstr = g_strconcat (buff, ".qth", NULL);
-	g_key_file_set_string (cfgdata,
-			       MOD_CFG_GLOBAL_SECTION,
-			       MOD_CFG_QTH_FILE_KEY,
-			       satstr);
+
+	/* is buff == "** DEFAULT **" clear the configuration key
+	   otherwise store the filename
+	*/
+	if (!g_ascii_strcasecmp (buff, _("** DEFAULT **"))) {
+		g_key_file_remove_key (cfgdata,
+							   MOD_CFG_GLOBAL_SECTION,
+							   MOD_CFG_QTH_FILE_KEY,
+							   NULL);
+	}
+	else {
+		satstr = g_strconcat (buff, ".qth", NULL);
+		g_key_file_set_string (cfgdata,
+							   MOD_CFG_GLOBAL_SECTION,
+							   MOD_CFG_QTH_FILE_KEY,
+							   satstr);
+		g_free (satstr);
+	}
+
 	g_free (buff);
-	g_free (satstr);
 
 	/* store satellites */
 	sats = gtk_sat_tree_get_selected (GTK_SAT_TREE (tree), &num);
@@ -782,15 +822,15 @@ mod_cfg_apply         (GKeyFile *cfgdata)
 	}
 
 	g_key_file_set_string (cfgdata,
-			       MOD_CFG_GLOBAL_SECTION,
-			       MOD_CFG_SATS_KEY,
-			       satstr);
+						   MOD_CFG_GLOBAL_SECTION,
+						   MOD_CFG_SATS_KEY,
+						   satstr);
 	g_free (satstr);
 	g_free (sats);
 
 	sat_log_log (SAT_LOG_LEVEL_MSG,
-		     _("%s: Applied changes to %s."),
-		     __FUNCTION__, gtk_entry_get_text (GTK_ENTRY (namew)));
+				 _("%s: Applied changes to %s."),
+				 __FUNCTION__, gtk_entry_get_text (GTK_ENTRY (namew)));
 }
 
 
@@ -809,17 +849,26 @@ edit_advanced_settings (GtkDialog *parent, GKeyFile *cfgdata)
 {
 	GtkWidget *dialog;
 	GtkWidget *contents;
-
+	gchar     *icon;      /* window icon file name */
 
 	dialog = gtk_dialog_new_with_buttons (_("Module Properties"),
-					      GTK_WINDOW (parent),
-					      GTK_DIALOG_MODAL |
-					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CANCEL,
-					      GTK_RESPONSE_REJECT,
-					      GTK_STOCK_OK,
-					      GTK_RESPONSE_ACCEPT,
-					      NULL);
+										  GTK_WINDOW (parent),
+										  GTK_DIALOG_MODAL |
+										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  GTK_STOCK_CANCEL,
+										  GTK_RESPONSE_REJECT,
+										  GTK_STOCK_OK,
+										  GTK_RESPONSE_ACCEPT,
+										  NULL);
+
+	/* window icon */
+	icon = icon_file_name ("gpredict-sat-pref.png");
+	if (g_file_test (icon, G_FILE_TEST_EXISTS)) {
+		gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
+									   icon,
+									   NULL);
+	}
+
 
 	contents = sat_pref_modules_create (cfgdata);
 	gtk_widget_show_all (contents);
@@ -879,7 +928,7 @@ add_qth_cb (GtkWidget *button, gpointer data)
 			g_free (qth.wx);
 		if (qth.qra != NULL)
 			g_free (qth.qra);
-/* 		if (qth.data != NULL) */
-/* 			g_key_file_free (data); */
+		/* 		if (qth.data != NULL) */
+		/* 			g_key_file_free (data); */
 	}
 }
