@@ -37,6 +37,7 @@
 #include "gtk-sat-data.h"
 #include "time-tools.h"
 #include "sat-cfg.h"
+#include "orbit-tools.h"
 #include "predict-tools.h"
 
 
@@ -128,11 +129,22 @@ find_aos (sat_t *sat, qth_t *qth, gdouble start)
 	gdouble t = start;
 	gdouble aostime = 0.0;
 
+
 	/* make sure current sat values are
 	   in sync with the time
 	*/
 	predict_calc (sat, qth, start);
 
+	/* check whether satellite has aos */
+	if ((sat->otype == ORBIT_TYPE_GEO) || 
+		(sat->otype == ORBIT_TYPE_DECAYED) ||
+	    !has_aos (sat, qth)) {
+
+		return 0.0;
+
+	}
+
+
 	if (sat->el > 0.0) 
 		t = find_los (sat, qth, start) + 0.014; // +20 min
 
@@ -193,6 +205,16 @@ find_los (sat_t *sat, qth_t *qth, gdouble start)
 	
 	predict_calc (sat, qth, start);
 
+	/* check whether satellite has aos */
+	if ((sat->otype == ORBIT_TYPE_GEO) || 
+		(sat->otype == ORBIT_TYPE_DECAYED) ||
+	    !has_aos (sat, qth)) {
+
+		return 0.0;
+
+	}
+
+
 	if (sat->el < 0.0)
 		t = find_aos (sat, qth, start) + 0.001; // +1.5 min
 
@@ -225,6 +247,7 @@ find_los (sat_t *sat, qth_t *qth, gdouble start)
  *  \param sat The satellite to find AOS for.
  *  \param qth The ground station.
  *  \param start Start time, prefereably now.
+ *  \return The time of the previous AOS or 0.0 if the satellite has no AOS.
  *
  * This function can be used to find the AOS time in the past of the
  * current pass.
@@ -240,6 +263,15 @@ find_prev_aos (sat_t *sat, qth_t *qth, gdouble start)
 	*/
 	predict_calc (sat, qth, start);
 
+	/* check whether satellite has aos */
+	if ((sat->otype == ORBIT_TYPE_GEO) || 
+		(sat->otype == ORBIT_TYPE_DECAYED) ||
+	    !has_aos (sat, qth)) {
+
+		return 0.0;
+
+	}
+
 	while (sat->el >= 0.0) {
 		aostime -= 0.0005; // 0.75 min
 		predict_calc (sat, qth, aostime);
@@ -352,16 +384,22 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 	tres = sat_cfg_get_int (SAT_CFG_INT_PRED_RESOLUTION) / 86400.0;
 
 	/* loop until we find a pass with elevation > SAT_CFG_INT_PRED_MIN_EL
+	   or we run out of time
 	   FIXME: we should have a safety break
 	*/
 	while (!done) {
 
 		aos = find_aos (sat, qth, t0);
 
+		/* aos = 0.0 means no aos */
+		if (aos == 0.0) {
+			done = TRUE;
+		}
+
 		/* check whether we are within time limits;
 		   maxdt = 0 mean no time limit.
 		*/
-		if ((maxdt > 0.0) && (aos > (start + maxdt))) {
+		else if ((maxdt > 0.0) && (aos > (start + maxdt)) ) {
 			done = TRUE;
 		}
 		else {
@@ -437,8 +475,8 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 				case SAT_VIS_VISIBLE:
 					pass->vis[0] = 'V';
 					break;
-				case SAT_VIS_IN_SUNLIGHT:
-					pass->vis[1] = 'S';
+				case SAT_VIS_DAYLIGHT:
+					pass->vis[1] = 'D';
 					break;
 				case SAT_VIS_ECLIPSED:
 					pass->vis[2] = 'E';
@@ -477,6 +515,7 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 				done = FALSE;
 				t0 = los + 0.014; // +20 min
 				free_pass (pass);
+				pass = NULL;
 			}
 
 			iter++;
@@ -512,7 +551,7 @@ GSList *
 get_passes (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt, guint num)
 {
 	GSList *passes = NULL;
-	pass_t *pass;
+	pass_t *pass = NULL;
 	guint   i;
 	gdouble t;
 
@@ -529,7 +568,14 @@ get_passes (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt, guint num)
 
 		if (pass != NULL) {
 			passes = g_slist_prepend (passes, pass);
-			t = pass->los + 0.014; // +20 min			
+			t = pass->los + 0.014; // +20 min
+
+			/* if maxdt > 0.0 check whether we have reached t = start+maxdt
+			   if yes finish predictions
+			*/
+			if ((maxdt > 0.0) && (t >= (start+maxdt))) {
+				i = num;
+			}
 		}
 		else {
 			/* we can't get any more passes */
@@ -538,7 +584,8 @@ get_passes (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt, guint num)
 
 	}
 
-	passes = g_slist_reverse (passes);
+	if (passes != NULL)
+		passes = g_slist_reverse (passes);
 
 	return passes;
 }
@@ -550,25 +597,27 @@ copy_pass         (pass_t *pass)
 {
 	pass_t *new;
 
-	new = g_new (pass_t, 1);
+	new = g_try_new (pass_t, 1);
 
-	new->aos = pass->aos;
-	new->los = pass->los;
-	new->max_el = pass->max_el;
-	new->aos_az = pass->aos_az;
-	new->los_az = pass->los_az;
-	new->orbit = pass->orbit;
-	new->maxel_az = pass->maxel_az;
-	new->vis[0] = pass->vis[0];
-	new->vis[1] = pass->vis[1];
-	new->vis[2] = pass->vis[2];
-	new->vis[3] = pass->vis[3];
-	new->details = copy_pass_details (pass->details);
-
-	if (pass->satname != NULL)
-		new->satname = g_strdup (pass->satname);
-	else
-		new->satname = NULL;
+	if (new != NULL) {
+		new->aos = pass->aos;
+		new->los = pass->los;
+		new->max_el = pass->max_el;
+		new->aos_az = pass->aos_az;
+		new->los_az = pass->los_az;
+		new->orbit = pass->orbit;
+		new->maxel_az = pass->maxel_az;
+		new->vis[0] = pass->vis[0];
+		new->vis[1] = pass->vis[1];
+		new->vis[2] = pass->vis[2];
+		new->vis[3] = pass->vis[3];
+		new->details = copy_pass_details (pass->details);
+		
+		if (pass->satname != NULL)
+			new->satname = g_strdup (pass->satname);
+		else
+			new->satname = NULL;
+	}
 
 	return new;
 }
@@ -580,8 +629,8 @@ copy_pass_details (GSList *details)
 	GSList *new = NULL;
 	guint   i,n;
 
-	n = g_slist_length (details);
 
+	n = g_slist_length (details);
 	for (i = 0; i < n; i++) {
 		new = g_slist_prepend (new, 
 				       copy_pass_detail (PASS_DETAIL (g_slist_nth_data (details, i))));
@@ -837,8 +886,8 @@ get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 			case SAT_VIS_VISIBLE:
 				pass->vis[0] = 'V';
 				break;
-			case SAT_VIS_IN_SUNLIGHT:
-				pass->vis[1] = 'S';
+			case SAT_VIS_DAYLIGHT:
+				pass->vis[1] = 'D';
 				break;
 			case SAT_VIS_ECLIPSED:
 				pass->vis[2] = 'E';
