@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 /** \brief Dialogs to show satellite passes
  */
@@ -36,12 +36,15 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
+#include "compat.h"
 #include "locator.h"
 #include "gtk-sat-data.h"
 #include "predict-tools.h"
 #include "pass-popup-menu.h"
 #include "sat-vis.h"
 #include "sat-pass-dialogs.h"
+#include "gtk-polar-plot.h"
+#include "gtk-azel-plot.h"
 
 
 
@@ -92,23 +95,23 @@ const gdouble MULTI_PASS_COL_XALIGN[MULTI_PASS_COL_NUMBER] = {
 const gchar *SINGLE_PASS_COL_TITLE[SINGLE_PASS_COL_NUMBER] = {
 	N_("Time"),
 	N_("Az"),
-        N_("El"),
-        N_("Ra"),
-        N_("Dec"),
-        N_("Range"),
-        N_("Rate"),
-        N_("Lat"),
-        N_("Lon"),
-        N_("SSP"),
-        N_("Footp"),
-        N_("Alt"),
-        N_("Vel"),
-        N_("Dop"),
-        N_("Loss"),
-        N_("Del"),
-        N_("MA"),
-        N_("Phase"),
-        N_("Vis")
+	N_("El"),
+	N_("Ra"),
+	N_("Dec"),
+	N_("Range"),
+	N_("Rate"),
+	N_("Lat"),
+	N_("Lon"),
+	N_("SSP"),
+	N_("Footp"),
+	N_("Alt"),
+	N_("Vel"),
+	N_("Dop"),
+	N_("Loss"),
+	N_("Del"),
+	N_("MA"),
+	N_("Phase"),
+	N_("Vis")
 };
 
 
@@ -116,23 +119,23 @@ const gchar *SINGLE_PASS_COL_TITLE[SINGLE_PASS_COL_NUMBER] = {
 const gchar *SINGLE_PASS_COL_HINT[SINGLE_PASS_COL_NUMBER] = {
 	N_("Time"),
 	N_("Azimuth"),
-        N_("Elevation"),
-        N_("Right Ascension"),
-        N_("Declination"),
-        N_("Slant Range"),
-        N_("Range Rate"),
-        N_("Latitude"),
-        N_("Longitude"),
-        N_("Sub-Satellite Point"),
-        N_("Footprint"),
-        N_("Altitude"),
-        N_("Velocity"),
-        N_("Doppler Shift @ 100MHz"),
-        N_("Signal Loss @ 100MHz"),
-        N_("Signal Delay"),
-        N_("Mean Anomaly"),
-        N_("Orbit Phase"),
-        N_("Visibility")
+	N_("Elevation"),
+	N_("Right Ascension"),
+	N_("Declination"),
+	N_("Slant Range"),
+	N_("Range Rate"),
+	N_("Latitude"),
+	N_("Longitude"),
+	N_("Sub-Satellite Point"),
+	N_("Footprint"),
+	N_("Altitude"),
+	N_("Velocity"),
+	N_("Doppler Shift @ 100MHz"),
+	N_("Signal Loss @ 100MHz"),
+	N_("Signal Delay"),
+	N_("Mean Anomaly"),
+	N_("Orbit Phase"),
+	N_("Visibility")
 };
 
 const gdouble SINGLE_PASS_COL_XALIGN[SINGLE_PASS_COL_NUMBER] = {
@@ -159,60 +162,60 @@ const gdouble SINGLE_PASS_COL_XALIGN[SINGLE_PASS_COL_NUMBER] = {
 
 
 static void check_and_set_single_cell_renderer (GtkTreeViewColumn *column,
-						GtkCellRenderer   *renderer,
-						gint               i);
+												GtkCellRenderer   *renderer,
+												gint               i);
 
 static void check_and_set_multi_cell_renderer (GtkTreeViewColumn *column,
-						GtkCellRenderer   *renderer,
-						gint               i);
+											   GtkCellRenderer   *renderer,
+											   gint               i);
 
 static void          latlon_cell_data_function (GtkTreeViewColumn *col,
-						GtkCellRenderer   *renderer,
-						GtkTreeModel      *model,
-						GtkTreeIter       *iter,
-						gpointer           column);
+												GtkCellRenderer   *renderer,
+												GtkTreeModel      *model,
+												GtkTreeIter       *iter,
+												gpointer           column);
 
 static void          degree_cell_data_function (GtkTreeViewColumn *col,
-						GtkCellRenderer   *renderer,
-						GtkTreeModel      *model,
-						GtkTreeIter       *iter,
-						gpointer           column);
+												GtkCellRenderer   *renderer,
+												GtkTreeModel      *model,
+												GtkTreeIter       *iter,
+												gpointer           column);
 
 static void          distance_cell_data_function (GtkTreeViewColumn *col,
-						  GtkCellRenderer   *renderer,
-						  GtkTreeModel      *model,
-						  GtkTreeIter       *iter,
-						  gpointer           column);
+												  GtkCellRenderer   *renderer,
+												  GtkTreeModel      *model,
+												  GtkTreeIter       *iter,
+												  gpointer           column);
 
 static void          range_rate_cell_data_function (GtkTreeViewColumn *col,
-						    GtkCellRenderer   *renderer,
-						    GtkTreeModel      *model,
-						    GtkTreeIter       *iter,
-						    gpointer           column);
+													GtkCellRenderer   *renderer,
+													GtkTreeModel      *model,
+													GtkTreeIter       *iter,
+													gpointer           column);
 
 static void          float_to_int_cell_data_function (GtkTreeViewColumn *col,
-						      GtkCellRenderer   *renderer,
-						      GtkTreeModel      *model,
-						      GtkTreeIter       *iter,
-						      gpointer           column);
+													  GtkCellRenderer   *renderer,
+													  GtkTreeModel      *model,
+													  GtkTreeIter       *iter,
+													  gpointer           column);
 
 static void          two_dec_cell_data_function (GtkTreeViewColumn *col,
-						 GtkCellRenderer   *renderer,
-						 GtkTreeModel      *model,
-						 GtkTreeIter       *iter,
-						 gpointer           column);
+												 GtkCellRenderer   *renderer,
+												 GtkTreeModel      *model,
+												 GtkTreeIter       *iter,
+												 gpointer           column);
 
 static void          time_cell_data_function (GtkTreeViewColumn *col,
-					      GtkCellRenderer   *renderer,
-					      GtkTreeModel      *model,
-					      GtkTreeIter       *iter,
-					      gpointer           column);
+											  GtkCellRenderer   *renderer,
+											  GtkTreeModel      *model,
+											  GtkTreeIter       *iter,
+											  gpointer           column);
 
 static void          duration_cell_data_function (GtkTreeViewColumn *col,
-						  GtkCellRenderer   *renderer,
-						  GtkTreeModel      *model,
-						  GtkTreeIter       *iter,
-						  gpointer           column);
+												  GtkCellRenderer   *renderer,
+												  GtkTreeModel      *model,
+												  GtkTreeIter       *iter,
+												  gpointer           column);
 
 
 static gint single_pass_dialog_delete  (GtkWidget *, GdkEvent *, gpointer);
@@ -224,15 +227,15 @@ static void multi_pass_dialog_destroy  (GtkWidget *, gpointer);
 static gboolean   popup_menu_cb   (GtkWidget *treeview, gpointer data);
 
 static gboolean   button_press_cb (GtkWidget *treeview,
-				   GdkEventButton *event,
-				   gpointer data);
+								   GdkEventButton *event,
+								   gpointer data);
 
 static void       view_popup_menu (GtkWidget *treeview,
-				   GdkEventButton *event,
-				   gpointer data);
+								   GdkEventButton *event,
+								   gpointer data);
 
 static void Calc_RADec (gdouble jul_utc, gdouble saz, gdouble sel,
-			qth_t *qth, obs_astro_t *obs_set);
+						qth_t *qth, obs_astro_t *obs_set);
 
 
 
@@ -243,8 +246,10 @@ static void Calc_RADec (gdouble jul_utc, gdouble saz, gdouble sel,
  *  \param pass The pass info.
  *  \param toplevel The toplevel window or NULL.
  *
- * This function creates a dialog window with a list showing the
- * details of a pass.
+ * This function creates a dialog window containing a notebook with three pages:
+ *   1. A list showing the details of a pass
+ *   2. Polar plot of the pass
+ *   3. Az/El plot of the pass
  *
  * Reference to the parent widget is needed to acquire the correct top-level
  * window, otherwise simply using the main window would bring that to front
@@ -255,13 +260,18 @@ static void Calc_RADec (gdouble jul_utc, gdouble saz, gdouble sel,
 void
 show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 {
-	GtkWidget         *dialog;
+	GtkWidget         *dialog;      /* the dialogue window */
+	GtkWidget         *notebook;    /* the notebook widet */
 	GtkWidget         *list;
 	GtkListStore      *liststore;
 	GtkCellRenderer   *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeIter        item;
-	GtkWidget         *swin;
+	GtkWidget         *swin;        /* scrolled window containing the list view */
+	GtkWidget         *polar;       /* polar plot */
+	GtkWidget         *azel;        /* Az/El plot */
+	GtkWidget         *hbox;        /* hbox used in tab headers */
+	GtkWidget         *image;       /* icon used in tab header */
 	gchar             *title;
 	guint              flags;
 	guint              i, num;
@@ -275,7 +285,6 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 	gdouble            ra,dec;
 
 
-
 	/* get columns flags */
 	flags = sat_cfg_get_int (SAT_CFG_INT_PRED_SINGLE_COL);
 
@@ -288,9 +297,9 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 		renderer = gtk_cell_renderer_text_new ();
 		g_object_set (G_OBJECT (renderer), "xalign", SINGLE_PASS_COL_XALIGN[i], NULL);
 		column = gtk_tree_view_column_new_with_attributes (SINGLE_PASS_COL_TITLE[i],
-								   renderer,
-								   "text", i,
-								   NULL);
+														   renderer,
+														   "text", i,
+														   NULL);
 		gtk_tree_view_insert_column (GTK_TREE_VIEW (list), column, -1);
 
 		/* only aligns the headers */
@@ -309,25 +318,25 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 
 	/* create and fill model */
 	liststore = gtk_list_store_new (SINGLE_PASS_COL_NUMBER,
-					G_TYPE_DOUBLE,   // time
-					G_TYPE_DOUBLE,   // az
-					G_TYPE_DOUBLE,   // el
-					G_TYPE_DOUBLE,   // ra
-					G_TYPE_DOUBLE,   // dec
-					G_TYPE_DOUBLE,   // range
-					G_TYPE_DOUBLE,   // range rate
-					G_TYPE_DOUBLE,   // lat
-					G_TYPE_DOUBLE,   // lon
-					G_TYPE_STRING,   // SSP
-					G_TYPE_DOUBLE,   // footprint
-					G_TYPE_DOUBLE,   // alt
-					G_TYPE_DOUBLE,   // vel
-					G_TYPE_DOUBLE,   // doppler
-					G_TYPE_DOUBLE,   // loss
-					G_TYPE_DOUBLE,   // delay
-					G_TYPE_DOUBLE,   // ma
-					G_TYPE_DOUBLE,   // phase
-					G_TYPE_STRING);  // visibility
+									G_TYPE_DOUBLE,   // time
+									G_TYPE_DOUBLE,   // az
+									G_TYPE_DOUBLE,   // el
+									G_TYPE_DOUBLE,   // ra
+									G_TYPE_DOUBLE,   // dec
+									G_TYPE_DOUBLE,   // range
+									G_TYPE_DOUBLE,   // range rate
+									G_TYPE_DOUBLE,   // lat
+									G_TYPE_DOUBLE,   // lon
+									G_TYPE_STRING,   // SSP
+									G_TYPE_DOUBLE,   // footprint
+									G_TYPE_DOUBLE,   // alt
+									G_TYPE_DOUBLE,   // vel
+									G_TYPE_DOUBLE,   // doppler
+									G_TYPE_DOUBLE,   // loss
+									G_TYPE_DOUBLE,   // delay
+									G_TYPE_DOUBLE,   // ma
+									G_TYPE_DOUBLE,   // phase
+									G_TYPE_STRING);  // visibility
 
 	/* add rows to list store */
 	num = g_slist_length (pass->details);
@@ -339,19 +348,19 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 
 		gtk_list_store_append (liststore, &item);
 		gtk_list_store_set (liststore, &item,
-				    SINGLE_PASS_COL_TIME, detail->time,
-				    SINGLE_PASS_COL_AZ, detail->az,
-				    SINGLE_PASS_COL_EL, detail->el,
-				    SINGLE_PASS_COL_RANGE, detail->range,
-				    SINGLE_PASS_COL_RANGE_RATE, detail->range_rate,
-				    SINGLE_PASS_COL_LAT, detail->lat,
-				    SINGLE_PASS_COL_LON, detail->lon,
-				    SINGLE_PASS_COL_FOOTPRINT, detail->footprint,
-				    SINGLE_PASS_COL_ALT, detail->alt,
-				    SINGLE_PASS_COL_VEL, detail->velo,
-				    SINGLE_PASS_COL_MA, detail->ma,
-				    SINGLE_PASS_COL_PHASE, detail->phase,
-				    -1);
+							SINGLE_PASS_COL_TIME, detail->time,
+							SINGLE_PASS_COL_AZ, detail->az,
+							SINGLE_PASS_COL_EL, detail->el,
+							SINGLE_PASS_COL_RANGE, detail->range,
+							SINGLE_PASS_COL_RANGE_RATE, detail->range_rate,
+							SINGLE_PASS_COL_LAT, detail->lat,
+							SINGLE_PASS_COL_LON, detail->lon,
+							SINGLE_PASS_COL_FOOTPRINT, detail->footprint,
+							SINGLE_PASS_COL_ALT, detail->alt,
+							SINGLE_PASS_COL_VEL, detail->velo,
+							SINGLE_PASS_COL_MA, detail->ma,
+							SINGLE_PASS_COL_PHASE, detail->phase,
+							-1);
 			    
 		/* 	SINGLE_PASS_COL_RA */
 		/* 	SINGLE_PASS_COL_DEC */
@@ -363,9 +372,9 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 			dec = Degrees(astro.dec);
 
 			gtk_list_store_set (liststore, &item,
-					    SINGLE_PASS_COL_RA, ra,
-					    SINGLE_PASS_COL_DEC, dec,
-					    -1);
+								SINGLE_PASS_COL_RA, ra,
+								SINGLE_PASS_COL_DEC, dec,
+								-1);
 		}
 		
 		/* 	SINGLE_PASS_COL_SSP */
@@ -377,8 +386,8 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 			if (retcode == RIG_OK) {
 				buff[6] = '\0';
 				gtk_list_store_set (liststore, &item,
-						    SINGLE_PASS_COL_SSP, buff,
-						    -1);
+									SINGLE_PASS_COL_SSP, buff,
+									-1);
 			}
 			g_free (buff);
 		}
@@ -387,32 +396,32 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 		if (flags & SINGLE_PASS_FLAG_DOPPLER) {
 			doppler = -100.0e06 * (detail->range_rate / 299792.4580); // Hz
 			gtk_list_store_set (liststore, &item,
-					    SINGLE_PASS_COL_DOPPLER, doppler,
-					    -1);					    
+								SINGLE_PASS_COL_DOPPLER, doppler,
+								-1);					    
 		}
 
 		/* 	SINGLE_PASS_COL_LOSS */
 		if (flags & SINGLE_PASS_FLAG_LOSS) {
 			loss = 72.4 + 20.0*log10(detail->range);               // dB
 			gtk_list_store_set (liststore, &item,
-					    SINGLE_PASS_COL_LOSS, loss,
-					    -1);					    
+								SINGLE_PASS_COL_LOSS, loss,
+								-1);					    
 		}
 
 		/* 	SINGLE_PASS_COL_DELAY */
 		if (flags & SINGLE_PASS_FLAG_DELAY) {
 			delay   = detail->range / 299.7924580;         // msec 
 			gtk_list_store_set (liststore, &item,
-					    SINGLE_PASS_COL_DELAY, delay,
-					    -1);					    
+								SINGLE_PASS_COL_DELAY, delay,
+								-1);					    
 		}
 
 		/* 	SINGLE_PASS_COL_VIS */
 		if (flags & SINGLE_PASS_FLAG_VIS) {
 			buff = g_strdup_printf ("%c", vis_to_chr (detail->vis));
 			gtk_list_store_set (liststore, &item,
-					    SINGLE_PASS_COL_VIS, buff,
-					    -1);					    
+								SINGLE_PASS_COL_VIS, buff,
+								-1);					    
 			g_free (buff);
 		}
 
@@ -425,25 +434,59 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 	/* scrolled window */
 	swin = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
-					GTK_POLICY_NEVER,
-					GTK_POLICY_AUTOMATIC);
+									GTK_POLICY_NEVER,
+									GTK_POLICY_AUTOMATIC);
+
+
 
 	gtk_container_add (GTK_CONTAINER (swin), list);
 
 
+	/* create notebook and add pages */
+	notebook = gtk_notebook_new ();
+	image = gtk_image_new_from_stock (GTK_STOCK_JUSTIFY_FILL, GTK_ICON_SIZE_MENU);
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_("Data")), FALSE, TRUE, 5);
+	gtk_widget_show_all (hbox);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), swin, hbox);
+
+	/* polar plot */
+	polar = gtk_polar_plot_new (qth, pass);
+	buff = icon_file_name ("gpredict-polar-small.png");
+	image = gtk_image_new_from_file (buff);
+	g_free (buff);
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_("Polar")), FALSE, TRUE, 5);
+	gtk_widget_show_all (hbox);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), polar, hbox);
+
+	/* Az/El plot */
+	azel = gtk_azel_plot_new (qth, pass);
+	buff = icon_file_name ("gpredict-azel-small.png");
+	image = gtk_image_new_from_file (buff);
+	g_free (buff);
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_("Az/El")), FALSE, TRUE, 5);
+	gtk_widget_show_all (hbox);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), azel, hbox);
+
+
 	/* create dialog */
 	title = g_strdup_printf (_("Pass details for %s (orbit %d)"),
-				 satname, pass->orbit);
+							 satname, pass->orbit);
 
 	/* use NULL as parent to avoid conflict when using undocked windows
 	   as parents.
 	*/
 	dialog = gtk_dialog_new_with_buttons (title,
-					      GTK_WINDOW (toplevel),
-					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CLOSE,
-					      GTK_RESPONSE_ACCEPT,
-					      NULL);
+										  GTK_WINDOW (toplevel),
+										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  GTK_STOCK_CLOSE,
+										  GTK_RESPONSE_ACCEPT,
+										  NULL);
 	g_free (title);
 
 	/*** FIXME: set list-like window icon */
@@ -455,14 +498,14 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 
 
 	g_signal_connect (dialog, "response",
-			  G_CALLBACK (gtk_widget_destroy), NULL);
+					  G_CALLBACK (gtk_widget_destroy), NULL);
  	g_signal_connect (dialog, "destroy",
-			  G_CALLBACK (single_pass_dialog_destroy), NULL);
+					  G_CALLBACK (single_pass_dialog_destroy), NULL);
 	g_signal_connect (dialog, "delete_event",
-			  G_CALLBACK (single_pass_dialog_delete), NULL);    
+					  G_CALLBACK (single_pass_dialog_delete), NULL);    
 
 
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), swin);
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), notebook);
 
 	gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 300);
 	gtk_widget_show_all (dialog);
@@ -474,8 +517,8 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 /** \brief Set cell renderer function. */
 static void
 check_and_set_single_cell_renderer (GtkTreeViewColumn *column,
-				   GtkCellRenderer   *renderer,
-				   gint               i)
+									GtkCellRenderer   *renderer,
+									gint               i)
 {
 
 	switch (i) {
@@ -490,20 +533,20 @@ check_and_set_single_cell_renderer (GtkTreeViewColumn *column,
 	case SINGLE_PASS_COL_MA:
 	case SINGLE_PASS_COL_PHASE:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 degree_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 degree_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 		/* LAT/LON format */
 	case SINGLE_PASS_COL_LAT:
 	case SINGLE_PASS_COL_LON:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 latlon_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 latlon_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 		/* distances and velocities */
@@ -511,44 +554,44 @@ check_and_set_single_cell_renderer (GtkTreeViewColumn *column,
 	case SINGLE_PASS_COL_ALT:
 	case SINGLE_PASS_COL_FOOTPRINT:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 distance_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 distance_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case SINGLE_PASS_COL_VEL:
 	case SINGLE_PASS_COL_RANGE_RATE:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 range_rate_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 range_rate_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case SINGLE_PASS_COL_DOPPLER:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 float_to_int_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 float_to_int_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case SINGLE_PASS_COL_DELAY:
 	case SINGLE_PASS_COL_LOSS:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 two_dec_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 two_dec_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case SINGLE_PASS_COL_TIME:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 time_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 time_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	default:
@@ -570,10 +613,10 @@ check_and_set_single_cell_renderer (GtkTreeViewColumn *column,
 */
 static void
 latlon_cell_data_function (GtkTreeViewColumn *col,
-			   GtkCellRenderer   *renderer,
-			   GtkTreeModel      *model,
-			   GtkTreeIter       *iter,
-			   gpointer           column)
+						   GtkCellRenderer   *renderer,
+						   GtkTreeModel      *model,
+						   GtkTreeIter       *iter,
+						   gpointer           column)
 {
 	gdouble   number = 0.0;
 	gchar   *buff;
@@ -607,9 +650,9 @@ latlon_cell_data_function (GtkTreeViewColumn *col,
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_BUG,
-				     _("%s:%d: Invalid column: %d"),
-				     __FILE__, __LINE__,
-				     coli);
+						 _("%s:%d: Invalid column: %d"),
+						 __FILE__, __LINE__,
+						 coli);
 			hmf = '?';
 		}
 	}
@@ -617,9 +660,9 @@ latlon_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.2f\302\260%c", number, hmf);
 	g_object_set (renderer,
-		      "text", buff,
-		      "xalign", 1.0,
-		      NULL);
+				  "text", buff,
+				  "xalign", 1.0,
+				  NULL);
 	g_free (buff);
 }
 
@@ -627,10 +670,10 @@ latlon_cell_data_function (GtkTreeViewColumn *col,
 /* general floats with 2 digits + degree char */
 static void
 degree_cell_data_function (GtkTreeViewColumn *col,
-			   GtkCellRenderer   *renderer,
-			   GtkTreeModel      *model,
-			   GtkTreeIter       *iter,
-			   gpointer           column)
+						   GtkCellRenderer   *renderer,
+						   GtkTreeModel      *model,
+						   GtkTreeIter       *iter,
+						   gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -641,9 +684,9 @@ degree_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.2f\302\260", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      "xalign", 1.0,
-		      NULL);
+				  "text", buff,
+				  "xalign", 1.0,
+				  NULL);
 	g_free (buff);
 }
 
@@ -651,10 +694,10 @@ degree_cell_data_function (GtkTreeViewColumn *col,
 /* distance and velocity, 0 decimal digits */
 static void
 distance_cell_data_function (GtkTreeViewColumn *col,
-			     GtkCellRenderer   *renderer,
-			     GtkTreeModel      *model,
-			     GtkTreeIter       *iter,
-			     gpointer           column)
+							 GtkCellRenderer   *renderer,
+							 GtkTreeModel      *model,
+							 GtkTreeIter       *iter,
+							 gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -670,8 +713,8 @@ distance_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.0f", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
@@ -680,10 +723,10 @@ distance_cell_data_function (GtkTreeViewColumn *col,
 */
 static void
 range_rate_cell_data_function (GtkTreeViewColumn *col,
-			       GtkCellRenderer   *renderer,
-			       GtkTreeModel      *model,
-			       GtkTreeIter       *iter,
-			       gpointer           column)
+							   GtkCellRenderer   *renderer,
+							   GtkTreeModel      *model,
+							   GtkTreeIter       *iter,
+							   gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -699,18 +742,18 @@ range_rate_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.3f", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
 /* 0 decimal digits */
 static void
 float_to_int_cell_data_function (GtkTreeViewColumn *col,
-				 GtkCellRenderer   *renderer,
-				 GtkTreeModel      *model,
-				 GtkTreeIter       *iter,
-				 gpointer           column)
+								 GtkCellRenderer   *renderer,
+								 GtkTreeModel      *model,
+								 GtkTreeIter       *iter,
+								 gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -721,18 +764,18 @@ float_to_int_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.0f", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
 /* 2 decimal digits */
 static void
 two_dec_cell_data_function (GtkTreeViewColumn *col,
-			    GtkCellRenderer   *renderer,
-			    GtkTreeModel      *model,
-			    GtkTreeIter       *iter,
-			    gpointer           column)
+							GtkCellRenderer   *renderer,
+							GtkTreeModel      *model,
+							GtkTreeIter       *iter,
+							gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -743,8 +786,8 @@ two_dec_cell_data_function (GtkTreeViewColumn *col,
 	/* format the number */
 	buff = g_strdup_printf ("%.2f", number);
 	g_object_set (renderer,
-		      "text", buff,
-		      NULL);
+				  "text", buff,
+				  NULL);
 	g_free (buff);
 }
 
@@ -752,10 +795,10 @@ two_dec_cell_data_function (GtkTreeViewColumn *col,
 /* AOS/LOS; convert julian date to string */
 static void
 time_cell_data_function (GtkTreeViewColumn *col,
-			 GtkCellRenderer   *renderer,
-			 GtkTreeModel      *model,
-			 GtkTreeIter       *iter,
-			 gpointer           column)
+						 GtkCellRenderer   *renderer,
+						 GtkTreeModel      *model,
+						 GtkTreeIter       *iter,
+						 gpointer           column)
 {
 	gdouble    number;
 	gchar      buff[TIME_FORMAT_MAX_LENGTH];
@@ -769,8 +812,8 @@ time_cell_data_function (GtkTreeViewColumn *col,
 	
 	if (number == 0.0) {
 		g_object_set (renderer,
-			      "text", "--- N/A ---",
-			      NULL);
+					  "text", "--- N/A ---",
+					  NULL);
 	}
 	else {
 
@@ -792,8 +835,8 @@ time_cell_data_function (GtkTreeViewColumn *col,
 			buff[TIME_FORMAT_MAX_LENGTH]='\0';
 
 		g_object_set (renderer,
-			      "text", buff,
-			      NULL);
+					  "text", buff,
+					  NULL);
 
 		g_free (fmtstr);
 	}
@@ -823,7 +866,7 @@ single_pass_dialog_destroy (GtkWidget *dialog, gpointer data)
 /*** FIXME: formalise with other copies */
 static void
 Calc_RADec (gdouble jul_utc, gdouble saz, gdouble sel,
-	    qth_t *qth, obs_astro_t *obs_set)
+			qth_t *qth, obs_astro_t *obs_set)
 {
 
 	double phi,theta,sin_theta,cos_theta,sin_phi,cos_phi,
@@ -911,9 +954,9 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 		renderer = gtk_cell_renderer_text_new ();
 		g_object_set (G_OBJECT (renderer), "xalign", MULTI_PASS_COL_XALIGN[i], NULL);
 		column = gtk_tree_view_column_new_with_attributes (MULTI_PASS_COL_TITLE[i],
-								   renderer,
-								   "text", i,
-								   NULL);
+														   renderer,
+														   "text", i,
+														   NULL);
 		gtk_tree_view_insert_column (GTK_TREE_VIEW (list), column, -1);
 
 		/* only aligns the headers */
@@ -932,17 +975,17 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 
 	/* create and fill model */
 	liststore = gtk_list_store_new (MULTI_PASS_COL_NUMBER+1,
-					G_TYPE_DOUBLE,   // aos time
-					G_TYPE_DOUBLE,   // tca time
-					G_TYPE_DOUBLE,   // los time
-					G_TYPE_DOUBLE,   // duration
-					G_TYPE_DOUBLE,   // aos az
-					G_TYPE_DOUBLE,   // max el
-					G_TYPE_DOUBLE,   // az @ max el
-					G_TYPE_DOUBLE,   // los az
-					G_TYPE_INT,      // orbit
-					G_TYPE_STRING,   // visibility
-					G_TYPE_INT);     // row number
+									G_TYPE_DOUBLE,   // aos time
+									G_TYPE_DOUBLE,   // tca time
+									G_TYPE_DOUBLE,   // los time
+									G_TYPE_DOUBLE,   // duration
+									G_TYPE_DOUBLE,   // aos az
+									G_TYPE_DOUBLE,   // max el
+									G_TYPE_DOUBLE,   // az @ max el
+									G_TYPE_DOUBLE,   // los az
+									G_TYPE_INT,      // orbit
+									G_TYPE_STRING,   // visibility
+									G_TYPE_INT);     // row number
 
 	/* add rows to list store */
 	num = g_slist_length (passes);
@@ -953,18 +996,18 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 
 		gtk_list_store_append (liststore, &item);
 		gtk_list_store_set (liststore, &item,
-				    MULTI_PASS_COL_AOS_TIME, pass->aos,
-				    MULTI_PASS_COL_TCA, pass->tca,
-				    MULTI_PASS_COL_LOS_TIME, pass->los,
-				    MULTI_PASS_COL_DURATION, (pass->los - pass->aos),
-				    MULTI_PASS_COL_AOS_AZ, pass->aos_az,
-				    MULTI_PASS_COL_MAX_EL, pass->max_el,
-				    MULTI_PASS_COL_MAX_EL_AZ, pass->maxel_az,
-				    MULTI_PASS_COL_LOS_AZ, pass->los_az,
-				    MULTI_PASS_COL_ORBIT, pass->orbit,
-				    MULTI_PASS_COL_VIS, pass->vis,
-				    MULTI_PASS_COL_NUMBER, i,
-				    -1);
+							MULTI_PASS_COL_AOS_TIME, pass->aos,
+							MULTI_PASS_COL_TCA, pass->tca,
+							MULTI_PASS_COL_LOS_TIME, pass->los,
+							MULTI_PASS_COL_DURATION, (pass->los - pass->aos),
+							MULTI_PASS_COL_AOS_AZ, pass->aos_az,
+							MULTI_PASS_COL_MAX_EL, pass->max_el,
+							MULTI_PASS_COL_MAX_EL_AZ, pass->maxel_az,
+							MULTI_PASS_COL_LOS_AZ, pass->los_az,
+							MULTI_PASS_COL_ORBIT, pass->orbit,
+							MULTI_PASS_COL_VIS, pass->vis,
+							MULTI_PASS_COL_NUMBER, i,
+							-1);
 
 
 		//MULTI_PASS_COL_VIS
@@ -982,15 +1025,15 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 
 	/* mouse events => popup menu */
 	g_signal_connect (list, "button-press-event",
-			  G_CALLBACK (button_press_cb), NULL);
+					  G_CALLBACK (button_press_cb), NULL);
 	g_signal_connect (list, "popup-menu",
-			  G_CALLBACK (popup_menu_cb), NULL);
+					  G_CALLBACK (popup_menu_cb), NULL);
 
 	/* scrolled window */
 	swin = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
-					GTK_POLICY_NEVER,
-					GTK_POLICY_AUTOMATIC);
+									GTK_POLICY_NEVER,
+									GTK_POLICY_AUTOMATIC);
 
 	gtk_container_add (GTK_CONTAINER (swin), list);
 
@@ -1001,11 +1044,11 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 	/* use NULL as parent to avoid conflict when using undocked windows
 	   as parents.	*/
 	dialog = gtk_dialog_new_with_buttons (title,
-					      GTK_WINDOW (toplevel),
-					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CLOSE,
-					      GTK_RESPONSE_ACCEPT,
-					      NULL);
+										  GTK_WINDOW (toplevel),
+										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  GTK_STOCK_CLOSE,
+										  GTK_RESPONSE_ACCEPT,
+										  NULL);
 	g_free (title);
 
 	/*** FIXME: set list-like window icon */
@@ -1017,11 +1060,11 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 
 
 	g_signal_connect (dialog, "response",
-			  G_CALLBACK (gtk_widget_destroy), NULL);
+					  G_CALLBACK (gtk_widget_destroy), NULL);
  	g_signal_connect (dialog, "destroy",
-			  G_CALLBACK (multi_pass_dialog_destroy), NULL);
+					  G_CALLBACK (multi_pass_dialog_destroy), NULL);
 	g_signal_connect (dialog, "delete_event",
-			  G_CALLBACK (multi_pass_dialog_delete), NULL);
+					  G_CALLBACK (multi_pass_dialog_delete), NULL);
 
 
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), swin);
@@ -1054,8 +1097,8 @@ multi_pass_dialog_destroy (GtkWidget *dialog, gpointer data)
 /** \brief Set cell renderer function. */
 static void
 check_and_set_multi_cell_renderer (GtkTreeViewColumn *column,
-				   GtkCellRenderer   *renderer,
-				   gint               i)
+								   GtkCellRenderer   *renderer,
+								   gint               i)
 {
 
 	switch (i) {
@@ -1068,28 +1111,28 @@ check_and_set_multi_cell_renderer (GtkTreeViewColumn *column,
 	case MULTI_PASS_COL_MAX_EL:
 	case MULTI_PASS_COL_MAX_EL_AZ:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 degree_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 degree_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case MULTI_PASS_COL_AOS_TIME:
 	case MULTI_PASS_COL_TCA:
 	case MULTI_PASS_COL_LOS_TIME:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 time_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 time_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	case MULTI_PASS_COL_DURATION:
 		gtk_tree_view_column_set_cell_data_func (column,
-							 renderer,
-							 duration_cell_data_function,
-							 GUINT_TO_POINTER (i),
-							 NULL);
+												 renderer,
+												 duration_cell_data_function,
+												 GUINT_TO_POINTER (i),
+												 NULL);
 		break;
 
 	default:
@@ -1104,10 +1147,10 @@ check_and_set_multi_cell_renderer (GtkTreeViewColumn *column,
 /* duration; convert delta t in days to HH:MM:SS */
 static void
 duration_cell_data_function (GtkTreeViewColumn *col,
-			     GtkCellRenderer   *renderer,
-			     GtkTreeModel      *model,
-			     GtkTreeIter       *iter,
-			     gpointer           column)
+							 GtkCellRenderer   *renderer,
+							 GtkTreeModel      *model,
+							 GtkTreeIter       *iter,
+							 gpointer           column)
 {
 	gdouble    number;
 	gchar     *buff;
@@ -1121,8 +1164,8 @@ duration_cell_data_function (GtkTreeViewColumn *col,
 	
 	if (number == 0.0) {
 		g_object_set (renderer,
-			      "text", "- N/A -",
-			      NULL);
+					  "text", "- N/A -",
+					  NULL);
 	}
 	else {
 
@@ -1159,8 +1202,8 @@ duration_cell_data_function (GtkTreeViewColumn *col,
 		buff = g_strdup_printf ("%s%d%s%d%s%d", ch, h, cm, m, cs, s);
 
 		g_object_set (renderer,
-			      "text", buff,
-			      NULL);
+					  "text", buff,
+					  NULL);
 
 		g_free (buff);
 		g_free (ch);
@@ -1222,9 +1265,9 @@ button_press_cb (GtkWidget *treeview, GdkEventButton *event, gpointer data)
 
 				/* Get tree path for row that was clicked */
 				if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview),
-								   (gint) event->x,
-								   (gint) event->y,
-								   &path, NULL, NULL, NULL)) {
+												   (gint) event->x,
+												   (gint) event->y,
+												   &path, NULL, NULL, NULL)) {
 					gtk_tree_selection_unselect_all (selection);
 					gtk_tree_selection_select_path (selection, path);
 					gtk_tree_path_free (path);
@@ -1263,8 +1306,8 @@ view_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer data)
 		qth = (qth_t *) g_object_get_data (G_OBJECT (treeview), "qth");
 
 		gtk_tree_model_get (model, &iter,
-				    MULTI_PASS_COL_NUMBER, &rownum,
-				    -1);
+							MULTI_PASS_COL_NUMBER, &rownum,
+							-1);
 
 		/* get selected pass */
 		pass = copy_pass (PASS (g_slist_nth_data (passes, rownum)));
@@ -1275,8 +1318,8 @@ view_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer data)
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: There is no selection; skip popup."),
-			     __FILE__, __LINE__);
+					 _("%s:%d: There is no selection; skip popup."),
+					 __FILE__, __LINE__);
 	}
 
 }
