@@ -175,144 +175,184 @@ show_sat_info (GtkWidget *menuitem, gpointer data)
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 0, 1);
 	g_free (str);
 
+	/* operational status */
+	label = gtk_label_new (_("Operational Status:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
+
+	switch (sat->tle.status) {
+
+	case OP_STAT_OPERATIONAL:
+		label = gtk_label_new (_("Operational"));
+		break;
+
+	case OP_STAT_NONOP:
+		label = gtk_label_new (_("Non-operational"));
+		break;
+
+	case OP_STAT_PARTIAL:
+		label = gtk_label_new (_("Partially operational"));
+		break;
+
+	case OP_STAT_STDBY:
+		label = gtk_label_new (_("Backup/Standby"));
+		break;
+
+	case OP_STAT_SPARE:
+		label = gtk_label_new (_("Spare"));
+		break;
+
+	case OP_STAT_EXTENDED:
+		label = gtk_label_new (_("Extended Mission"));
+		break;
+
+	default:
+		label = gtk_label_new (_("Unknown"));
+		break;
+
+	}
+
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+
 	/* Catnum */
 	label = gtk_label_new (_("Catalogue number:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 2, 3);
 
 	str = g_strdup_printf ("%d", sat->tle.catnr);
 	label = gtk_label_new (str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 2, 3);
 	g_free (str);
 
 	/* international designator */
 	label = gtk_label_new (_("Internation designator:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 3, 4);
 
 	label = gtk_label_new (sat->tle.idesg);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 3, 4);
 
 	/* elset number */
 	label = gtk_label_new (_("Element set number:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 3, 4);
-
-	str = g_strdup_printf ("%d", sat->tle.elset);
-	label = gtk_label_new (str);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 3, 4);
-	g_free (str);
-
-	/* elset epoch */
-	label = gtk_label_new (_("Epoch time:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 4, 5);
 
-	str = epoch_to_str (sat);
+	str = g_strdup_printf ("%d", sat->tle.elset);
 	label = gtk_label_new (str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 4, 5);
 	g_free (str);
 
+	/* elset epoch */
+	label = gtk_label_new (_("Epoch time:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 5, 6);
+
+	str = epoch_to_str (sat);
+	label = gtk_label_new (str);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 5, 6);
+	g_free (str);
+
 	/* Revolution Number @ Epoch */
 	label = gtk_label_new (_("Orbit number @ epoch:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 5, 6);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 6, 7);
 
 	str = g_strdup_printf ("%d", sat->tle.revnum);
 	label = gtk_label_new (str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 5, 6);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 6, 7);
 	g_free (str);
 
 	/* ephermis type left out, since it is always 0 */
 
 	/* separator */
 	gtk_table_attach_defaults (GTK_TABLE (table),
-				   gtk_hseparator_new (),
-				   0, 4, 6, 7);
+							   gtk_hseparator_new (),
+							   0, 4, 7, 8);
 
 	/* Orbit inclination */
 	label = gtk_label_new (_("Inclination:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 7, 8);
-
-	str = g_strdup_printf ("%.4f\302\260", sat->tle.xincl/de2ra);
-	label = gtk_label_new (str);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 7, 8);
-	g_free (str);
-
-	/* RAAN */
-	label = gtk_label_new (_("RAAN:"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 8, 9);
 
-	str = g_strdup_printf ("%.4f\302\260", sat->tle.xnodeo/de2ra);
+	str = g_strdup_printf ("%.4f\302\260", sat->tle.xincl/de2ra);
 	label = gtk_label_new (str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 8, 9);
 	g_free (str);
 
-	/* Eccentricity */
-	label = gtk_label_new (_("Eccentricity:"));
+	/* RAAN */
+	label = gtk_label_new (_("RAAN:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 9, 10);
 
-	str = g_strdup_printf ("%.7f", sat->tle.eo);
+	str = g_strdup_printf ("%.4f\302\260", sat->tle.xnodeo/de2ra);
 	label = gtk_label_new (str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 9, 10);
 	g_free (str);
 
-	/* Argument of perigee */
-	label = gtk_label_new (_("Arg. of perigee:"));
+	/* Eccentricity */
+	label = gtk_label_new (_("Eccentricity:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 10, 11);
 
-	str = g_strdup_printf ("%.4f\302\260", sat->tle.omegao/de2ra);
+	str = g_strdup_printf ("%.7f", sat->tle.eo);
 	label = gtk_label_new (str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 10, 11);
 	g_free (str);
 
-	/* Mean Anomaly */
-	label = gtk_label_new (_("Mean anomaly:"));
+	/* Argument of perigee */
+	label = gtk_label_new (_("Arg. of perigee:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 11, 12);
 
-	str = g_strdup_printf ("%.4f\302\260", sat->tle.xmo/de2ra);
+	str = g_strdup_printf ("%.4f\302\260", sat->tle.omegao/de2ra);
 	label = gtk_label_new (str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 11, 12);
 	g_free (str);
 
-	/* Mean Motion */
-	label = gtk_label_new (_("Mean motion:"));
+	/* Mean Anomaly */
+	label = gtk_label_new (_("Mean anomaly:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 12, 13);
 
-	//str = g_strdup_printf ("%.4f [rev/day]", sat->tle.xno/(xmnpda*(twopi/xmnpda/xmnpda)));
-	str = g_strdup_printf ("%.8f [rev/day]", sat->meanmo);
+	str = g_strdup_printf ("%.4f\302\260", sat->tle.xmo/de2ra);
 	label = gtk_label_new (str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 12, 13);
 	g_free (str);
 
+	/* Mean Motion */
+	label = gtk_label_new (_("Mean motion:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 13, 14);
+
+	//str = g_strdup_printf ("%.4f [rev/day]", sat->tle.xno/(xmnpda*(twopi/xmnpda/xmnpda)));
+	str = g_strdup_printf ("%.8f [rev/day]", sat->meanmo);
+	label = gtk_label_new (str);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 13, 14);
+	g_free (str);
+
 	/* one half of the first time derivative of mean motion */
 	label = gtk_label_new (_("\302\275 d/dt (mean motion):"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 13, 14);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 14, 15);
 
 	str = g_strdup_printf ("%.5e [rev/day<sup>2</sup>]",
 			       sat->tle.xndt2o/(twopi/xmnpda/xmnpda));
 	label = gtk_label_new (NULL);
 	gtk_label_set_markup (GTK_LABEL (label), str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 13, 14);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 14, 15);
 	g_free (str);
 
 	/* one sixth of the second time derivative of mean motion */
@@ -320,26 +360,26 @@ show_sat_info (GtkWidget *menuitem, gpointer data)
 	gtk_label_set_markup (GTK_LABEL (label),
 				  _("1/6 d<sup>2</sup>/dt<sup>2</sup> (mean motion):"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 14, 15);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 15, 16);
 
 	str = g_strdup_printf ("%.5e [rev/day<sup>3</sup>]",
 			       sat->tle.xndd6o*xmnpda/(twopi/xmnpda/xmnpda));
 	label = gtk_label_new (NULL);
 	gtk_label_set_markup (GTK_LABEL (label), str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 14, 15);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 15, 16);
 	g_free (str);
 
 	/* B* drag term */
 	label = gtk_label_new (_("B* drag term:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 15, 16);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 16, 17);
 
 	str = g_strdup_printf ("%.5e [R<sub>E</sub><sup>-1</sup>]", sat->tle.bstar*ae);
 	label = gtk_label_new (NULL);
 	gtk_label_set_markup (GTK_LABEL (label), str);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 15, 16);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 16, 17);
 	g_free (str);
 
 	/* Orbit type */
@@ -393,9 +433,19 @@ epoch_to_str (sat_t *sat)
 	time_t     t;
 	guint      size;
 
-
+	/* http://celestrak.com/columns/v04n03/#FAQ02
+	   ... While talking about the epoch, this is perhaps a good place to answer
+	   the other time-related questions. First, how is the epoch time format
+	   interpreted? This question is best answered by using an example. An epoch
+	   of 98001.00000000 corresponds to 0000 UT on 1998 January 01st in other
+	   words, midnight between 1997 December 31 and 1998 January 01. An epoch of
+	   98000.00000000 would actually correspond to the beginning of 1997 December
+	   31st strange as that might seem. Note that the epoch day starts at UT
+	   midnight (not noon) and that all times are measured mean solar rather than
+	   sidereal time units (the answer to our third question).
+	*/
 	epd = g_date_new_dmy (1, 1, sat->tle.epoch_year);
-	g_date_add_days (epd, sat->tle.epoch_day);
+	g_date_add_days (epd, sat->tle.epoch_day-1);
 
 	/* convert date to struct tm */
 	g_date_to_struct_tm (epd, &tms);
