@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 
 /** \brief Edit ground station details.
@@ -110,24 +110,24 @@ sat_pref_qth_editor_run (GtkTreeView *treeview, gboolean new)
 
 	/* crate dialog and add contents */
 	dialog = gtk_dialog_new_with_buttons (_("Edit ground station data"),
-					      GTK_WINDOW (window),
-					      GTK_DIALOG_MODAL |
-					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CLEAR,
-					      GTK_RESPONSE_REJECT,
-					      GTK_STOCK_CANCEL,
-					      GTK_RESPONSE_CANCEL,
-					      GTK_STOCK_OK,
-					      GTK_RESPONSE_OK,
-					      NULL);
+										  GTK_WINDOW (window),
+										  GTK_DIALOG_MODAL |
+										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  GTK_STOCK_CLEAR,
+										  GTK_RESPONSE_REJECT,
+										  GTK_STOCK_CANCEL,
+										  GTK_RESPONSE_CANCEL,
+										  GTK_STOCK_OK,
+										  GTK_RESPONSE_OK,
+										  NULL);
 
 	/* disable OK button to begin with */
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-					   GTK_RESPONSE_OK,
-					   FALSE);
+									   GTK_RESPONSE_OK,
+									   FALSE);
 
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox),
-			   create_editor_widgets (treeview, new));
+					   create_editor_widgets (treeview, new));
 
 	/* this hacky-thing is to keep the dialog running in case the
 	   CLEAR button is plressed. OK and CANCEL will exit the loop
@@ -189,11 +189,11 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	gtk_entry_set_max_length (GTK_ENTRY (name), 25);
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, name,
-			      _("Enter a short name for this ground station, e.g. callsign.\n"\
-				"Allowed charachters: 0..9, a..z, A..Z, - and _"),
-			      _("The name will be used to identify the ground station when "\
-				"it is presented to the user. Maximum allowed length "\
-				"is 25 charachters."));
+						  _("Enter a short name for this ground station, e.g. callsign.\n"\
+							"Allowed charachters: 0..9, a..z, A..Z, - and _"),
+						  _("The name will be used to identify the ground station when "\
+							"it is presented to the user. Maximum allowed length "\
+							"is 25 charachters."));
 	gtk_table_attach_defaults (GTK_TABLE (table), name, 1, 4, 0, 1);
 
 	/* attach changed signal so that we can enable OK button when
@@ -210,10 +210,10 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	gtk_entry_set_max_length (GTK_ENTRY (desc), 256);
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, desc,
-			      _("Enter an optional description for this ground station."),
-			      _("The description can be used as additional "\
-				"information. It may be included when generating reports. "\
-				"The maximum length for the description is 256 characters."));
+						  _("Enter an optional description for this ground station."),
+						  _("The description can be used as additional "\
+							"information. It may be included when generating reports. "\
+							"The maximum length for the description is 256 characters."));
 	gtk_table_attach_defaults (GTK_TABLE (table), desc, 1, 4, 1, 2);
 
 	/* location */
@@ -225,15 +225,15 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	gtk_entry_set_max_length (GTK_ENTRY (location), 50);
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, location,
-			      _("Optional location of the ground station, fx. Copenhagen, Denmark."),
-			      NULL);
+						  _("Optional location of the ground station, fx. Copenhagen, Denmark."),
+						  NULL);
 	gtk_table_attach_defaults (GTK_TABLE (table), location, 1, 3, 2, 3);
 
 	locbut = gpredict_hstock_button (GTK_STOCK_INDEX, _("Select"),
-					 _("Select a predefined location from a list."));
+									 _("Select a predefined location from a list."));
 	g_signal_connect (locbut, "clicked",
-			  G_CALLBACK (select_location),
-			  GUINT_TO_POINTER (SELECTION_MODE_LOC));
+					  G_CALLBACK (select_location),
+					  GUINT_TO_POINTER (SELECTION_MODE_LOC));
 	gtk_table_attach_defaults (GTK_TABLE (table), locbut, 3, 4, 2, 3);
 	
 
@@ -242,13 +242,14 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 3, 4);
 
-	lat = gtk_spin_button_new_with_range (0.00, 90.00, 0.01);
-	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (lat), 0.01, 1.0);
+	lat = gtk_spin_button_new_with_range (0.00, 90.00, 0.0001);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (lat), 0.0001, 1.0);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (lat), TRUE);
+	gtk_spin_button_set_digits (GTK_SPIN_BUTTON (lat), 4);
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, lat,
-			      _("Select the latitude of the ground station in decimal degrees."),
-			      NULL);
+						  _("Select the latitude of the ground station in decimal degrees."),
+						  NULL);
 	gtk_table_attach_defaults (GTK_TABLE (table), lat, 1, 2, 3, 4);
 
 	ns = gtk_combo_box_new_text ();
@@ -263,12 +264,13 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 4, 5);
 
-	lon = gtk_spin_button_new_with_range (0.00, 180.00, 0.01);
-	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (lon), 0.01, 1.0);
+	lon = gtk_spin_button_new_with_range (0.00, 180.00, 0.0001);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (lon), 0.0001, 1.0);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (lon), TRUE);
+	gtk_spin_button_set_digits (GTK_SPIN_BUTTON (lon), 4);
 	gtk_tooltips_set_tip (tooltips, lon,
-			      _("Select the longitude of the ground station in decimal degrees."),
-			      NULL);
+						  _("Select the longitude of the ground station in decimal degrees."),
+						  NULL);
 	gtk_table_attach_defaults (GTK_TABLE (table), lon, 1, 2, 4, 5);
 
 	ew = gtk_combo_box_new_text ();
@@ -284,17 +286,17 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	   while doing automatic cross-updates
 	*/
 	latsigid = g_signal_connect (lat, "value-changed",
-				     G_CALLBACK (latlon_changed),
-				     NULL);
+								 G_CALLBACK (latlon_changed),
+								 NULL);
 	lonsigid = g_signal_connect (lon, "value-changed",
-				     G_CALLBACK (latlon_changed),
-				     NULL);
+								 G_CALLBACK (latlon_changed),
+								 NULL);
 	nssigid = g_signal_connect (ns, "changed",
-				    G_CALLBACK (latlon_changed),
-				    NULL);
+								G_CALLBACK (latlon_changed),
+								NULL);
 	ewsigid = g_signal_connect (ew, "changed",
-				    G_CALLBACK (latlon_changed),
-				    NULL);
+								G_CALLBACK (latlon_changed),
+								NULL);
 	
 	/* QRA locator */
 	label = gtk_label_new (_("Locator"));
@@ -305,12 +307,12 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	gtk_entry_set_max_length (GTK_ENTRY (qra), 6);
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, qra,
-			      _("Maidenhead locator grid."),
-			      NULL);
+						  _("Maidenhead locator grid."),
+						  NULL);
 	gtk_table_attach_defaults (GTK_TABLE (table), qra, 1, 2, 5, 6);
 	qrasigid = g_signal_connect (qra, "changed",
-				     G_CALLBACK (qra_changed),
-				     NULL);
+								 G_CALLBACK (qra_changed),
+								 NULL);
 
 	/* altitude */
 	label = gtk_label_new (_("Altitude"));
@@ -321,9 +323,9 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (alt), 1, 100);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (alt), TRUE);
 	gtk_tooltips_set_tip (tooltips, alt,
-			      _("Select the altitude of the ground station in meters or feet "\
-				"depending on your settings"),
-			      NULL);
+						  _("Select the altitude of the ground station in meters or feet "\
+							"depending on your settings"),
+						  NULL);
 	gtk_table_attach_defaults (GTK_TABLE (table), alt, 1, 2, 6, 7);
 
 	if (sat_cfg_get_bool (SAT_CFG_BOOL_USE_IMPERIAL)) {
@@ -344,15 +346,15 @@ create_editor_widgets (GtkTreeView *treeview, gboolean new)
 	gtk_entry_set_max_length (GTK_ENTRY (wx), 4);
 	tooltips = gtk_tooltips_new ();
 	gtk_tooltips_set_tip (tooltips, wx,
-			      _("Four letter code for weather station"),
-			      NULL);
+						  _("Four letter code for weather station"),
+						  NULL);
 	gtk_table_attach_defaults (GTK_TABLE (table), wx, 1, 3, 7, 8);
 
 	wxbut = gpredict_hstock_button (GTK_STOCK_INDEX, _("Select"),
-					_("Select a predefined weather station from a list."));
+									_("Select a predefined weather station from a list."));
 	g_signal_connect (wxbut, "clicked",
-			  G_CALLBACK (select_location),
-			  GUINT_TO_POINTER (SELECTION_MODE_WX));
+					  G_CALLBACK (select_location),
+					  GUINT_TO_POINTER (SELECTION_MODE_WX));
 	gtk_table_attach_defaults (GTK_TABLE (table), wxbut, 3, 4, 7, 8);
 	
 
@@ -389,14 +391,14 @@ update_widgets (GtkTreeView *treeview)
 
 		/* get values */
 		gtk_tree_model_get (model, &iter,
-				    QTH_LIST_COL_NAME, &qthname,
-				    QTH_LIST_COL_LOC,  &qthloc,
-				    QTH_LIST_COL_DESC, &qthdesc,
-				    QTH_LIST_COL_LAT, &qthlat,
-				    QTH_LIST_COL_LON, &qthlon,
-				    QTH_LIST_COL_ALT, &qthalt,
-				    QTH_LIST_COL_WX, &qthwx,
-				    -1);
+							QTH_LIST_COL_NAME, &qthname,
+							QTH_LIST_COL_LOC,  &qthloc,
+							QTH_LIST_COL_DESC, &qthdesc,
+							QTH_LIST_COL_LAT, &qthlat,
+							QTH_LIST_COL_LON, &qthlon,
+							QTH_LIST_COL_ALT, &qthalt,
+							QTH_LIST_COL_WX, &qthwx,
+							-1);
 
 		/* update widgets and free memory afterwards */
 		if (qthname) {
@@ -435,19 +437,19 @@ update_widgets (GtkTreeView *treeview)
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (alt), qthalt);
 
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s:%d: Loaded %s for editing:\n"\
-			       "LAT:%.2f LON:%.2f ALT:%d"),
-			     __FILE__, __LINE__,
-			     (qthname != NULL) ? qthname : "???",
-			     qthlat, qthlon, qthalt);
+					 _("%s:%d: Loaded %s for editing:\n"\
+					   "LAT:%.4f LON:%.4f ALT:%d"),
+					 __FILE__, __LINE__,
+					 (qthname != NULL) ? qthname : "???",
+					 qthlat, qthlon, qthalt);
 
 		g_free (qthname);
 
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_BUG,
-			     _("%s:%d: No ground station selected!"),
-			     __FILE__, __LINE__);
+					 _("%s:%d: No ground station selected!"),
+					 __FILE__, __LINE__);
 	}
 }
 
@@ -528,9 +530,9 @@ apply_changes         (GtkTreeView *treeview, gboolean new)
 		else {
 			/* no selection; internal error */
 			sat_log_log (SAT_LOG_LEVEL_BUG,
-				     _("%s:%d: Oooops, gpredict encountered an internal error "\
-				       "(no selection in qth list)"),
-				     __FILE__, __LINE__);
+						 _("%s:%d: Oooops, gpredict encountered an internal error "\
+						   "(no selection in qth list)"),
+						 __FILE__, __LINE__);
 
 			return FALSE;
 		}
@@ -538,19 +540,19 @@ apply_changes         (GtkTreeView *treeview, gboolean new)
 
 	/* update values */
 	gtk_list_store_set (liststore, &iter,
-			    QTH_LIST_COL_NAME, qthname,
-			    QTH_LIST_COL_LOC, qthloc,
-			    QTH_LIST_COL_DESC, qthdesc,
-			    QTH_LIST_COL_LAT, qthlat,
-			    QTH_LIST_COL_LON, qthlon,
-			    QTH_LIST_COL_ALT, qthalt,
-			    QTH_LIST_COL_WX, qthwx,
-			    -1);
+						QTH_LIST_COL_NAME, qthname,
+						QTH_LIST_COL_LOC, qthloc,
+						QTH_LIST_COL_DESC, qthdesc,
+						QTH_LIST_COL_LAT, qthlat,
+						QTH_LIST_COL_LON, qthlon,
+						QTH_LIST_COL_ALT, qthalt,
+						QTH_LIST_COL_WX, qthwx,
+						-1);
 
 	qthqra  = gtk_entry_get_text (GTK_ENTRY (qra));
 	gtk_list_store_set (liststore, &iter,
-			    QTH_LIST_COL_QRA, qthqra,
-			    -1);
+						QTH_LIST_COL_QRA, qthqra,
+						-1);
 
 	return TRUE;
 }
@@ -572,31 +574,31 @@ name_changed          (GtkWidget *widget, gpointer data)
 
 
 	/* step 1: ensure that only valid characters are entered
-	           (stolen from xlog, tnx pg4i)
+	   (stolen from xlog, tnx pg4i)
 	*/
 	entry = gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1);
 	if ((len = g_utf8_strlen (entry, -1)) > 0)
-	{
-		end = entry + g_utf8_strlen (entry, -1);
-		for (j = entry; j < end; ++j)
 		{
-			switch (*j)
-			{
-				case '0' ... '9':
-				case 'a' ... 'z':
-				case 'A' ... 'Z':
-				case '-':
-				case '_':
-					break;
-				default:
-					gdk_beep ();
-					pos = gtk_editable_get_position (GTK_EDITABLE (widget));
-					gtk_editable_delete_text (GTK_EDITABLE (widget),
-								  pos, pos+1);
-					break;
-			}
+			end = entry + g_utf8_strlen (entry, -1);
+			for (j = entry; j < end; ++j)
+				{
+					switch (*j)
+						{
+						case '0' ... '9':
+						case 'a' ... 'z':
+						case 'A' ... 'Z':
+						case '-':
+						case '_':
+							break;
+						default:
+							gdk_beep ();
+							pos = gtk_editable_get_position (GTK_EDITABLE (widget));
+							gtk_editable_delete_text (GTK_EDITABLE (widget),
+													  pos, pos+1);
+							break;
+						}
+				}
 		}
-	}
 
 
 	/* step 2: if name seems all right, enable OK button */
@@ -604,13 +606,13 @@ name_changed          (GtkWidget *widget, gpointer data)
 
 	if (g_utf8_strlen (text, -1) > 0) {
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-						   GTK_RESPONSE_OK,
-						   TRUE);
+										   GTK_RESPONSE_OK,
+										   TRUE);
 	}
 	else {
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-						   GTK_RESPONSE_OK,
-						   FALSE);
+										   GTK_RESPONSE_OK,
+										   FALSE);
 	}
 }
 
@@ -669,13 +671,13 @@ select_location       (GtkWidget *widget, gpointer data)
 			gtk_entry_set_text (GTK_ENTRY (location), qthloc);
 			gtk_entry_set_text (GTK_ENTRY (wx), qthwx);
 
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (lat), fabs (qthlat));
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON (lat), (gdouble) fabs (qthlat));
 			if (qthlat < 0.00)
 				gtk_combo_box_set_active (GTK_COMBO_BOX (ns), 1);
 			else
 				gtk_combo_box_set_active (GTK_COMBO_BOX (ns), 0);
 
-			gtk_spin_button_set_value (GTK_SPIN_BUTTON (lon), fabs (qthlon));
+			gtk_spin_button_set_value (GTK_SPIN_BUTTON (lon), (gdouble) fabs (qthlon));
 			if (qthlon < 0.00)
 				gtk_combo_box_set_active (GTK_COMBO_BOX (ew), 1);
 			else
@@ -739,11 +741,11 @@ latlon_changed        (GtkWidget *widget, gpointer data)
 	if (retcode == RIG_OK) {
 		/* debug message */
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s:%s: %.2f %.2f => %s"),
-			     __FILE__, __FUNCTION__,
-			     gtk_spin_button_get_value (GTK_SPIN_BUTTON (lon)),
-			     gtk_spin_button_get_value (GTK_SPIN_BUTTON (lat)),
-			     locator);
+					 _("%s:%s: %.2f %.2f => %s"),
+					 __FILE__, __FUNCTION__,
+					 gtk_spin_button_get_value (GTK_SPIN_BUTTON (lon)),
+					 gtk_spin_button_get_value (GTK_SPIN_BUTTON (lat)),
+					 locator);
 
 		g_signal_handler_block (qra, qrasigid);
 
@@ -754,8 +756,8 @@ latlon_changed        (GtkWidget *widget, gpointer data)
 	else {
 		/* send an error message and don't update */
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Error converting lon/lat to locator"),
-			     __FILE__, __LINE__);
+					 _("%s:%d: Error converting lon/lat to locator"),
+					 __FILE__, __LINE__);
 	}
 
 
@@ -782,10 +784,10 @@ qra_changed     (GtkEntry *entry, gpointer data)
 
 		/* debug message */
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s:%s: %s => %.2f %.2f"),
-			     __FILE__, __FUNCTION__,
-			     gtk_entry_get_text (GTK_ENTRY (qra)),
-			     lonf, latf);
+					 _("%s:%s: %s => %.2f %.2f"),
+					 __FILE__, __FUNCTION__,
+					 gtk_entry_get_text (GTK_ENTRY (qra)),
+					 lonf, latf);
 
 		/* block signal emissions for lat/lon widgets */
 		g_signal_handler_block (lat, latsigid);
@@ -824,9 +826,9 @@ qra_changed     (GtkEntry *entry, gpointer data)
 	else {
 		/* send an error message and don't update */
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Invalid locator: %s"),
-			     __FILE__, __LINE__,
-			     gtk_entry_get_text (GTK_ENTRY (qra)));
+					 _("%s:%d: Invalid locator: %s"),
+					 __FILE__, __LINE__,
+					 gtk_entry_get_text (GTK_ENTRY (qra)));
 	}
 
 }
