@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -57,44 +57,44 @@ static GtkWidget *qthlist; /* we need access to this from the ok and cancel func
 static GtkWidget    *create_qth_list       (void);
 static GtkTreeModel *create_and_fill_model (void);
 static guint         read_qth_file         (GtkListStore *liststore,
-					    gchar *filename);
+											gchar *filename);
 static GtkWidget    *create_buttons        (GtkTreeView *qthlist);
 static void          default_toggled       (GtkCellRendererToggle *cell,
-					    gchar                 *path_str,
-					    gpointer               data);
+											gchar                 *path_str,
+											gpointer               data);
 
 static gboolean      clear_default_flags      (GtkTreeModel *model,
-					       GtkTreePath *path,
-					       GtkTreeIter *iter,
-					       gpointer defqth);
+											   GtkTreePath *path,
+											   GtkTreeIter *iter,
+											   gpointer defqth);
 
 static void          float_cell_data_function (GtkTreeViewColumn *col,
-					       GtkCellRenderer   *renderer,
-					       GtkTreeModel      *model,
-					       GtkTreeIter       *iter,
-					       gpointer           column);
+											   GtkCellRenderer   *renderer,
+											   GtkTreeModel      *model,
+											   GtkTreeIter       *iter,
+											   gpointer           column);
 
 static void add_cb    (GtkWidget *button, gpointer data);
 static void edit_cb   (GtkWidget *button, gpointer data);
 static void delete_cb (GtkWidget *button, gpointer data);
 
 static gboolean check_and_set_default_qth (GtkTreeModel *model,
-					   GtkTreePath  *path,
-					   GtkTreeIter  *iter,
-					   gpointer      data);
+										   GtkTreePath  *path,
+										   GtkTreeIter  *iter,
+										   gpointer      data);
 
 static gboolean save_qth (GtkTreeModel *model,
-			  GtkTreePath  *path,
-			  GtkTreeIter  *iter,
-			  gpointer      data);
+						  GtkTreePath  *path,
+						  GtkTreeIter  *iter,
+						  gpointer      data);
 
 static void delete_location_files (void);
 
 
 static gboolean convert_qth_altitude (GtkTreeModel *model,
-				      GtkTreePath  *path,
-				      GtkTreeIter  *iter,
-				      gpointer      data);
+									  GtkTreePath  *path,
+									  GtkTreeIter  *iter,
+									  gpointer      data);
 
 
 /** \brief Create and initialise widgets for the locations prefs tab.
@@ -130,8 +130,8 @@ GtkWidget *sat_pref_qth_create ()
 
 	gtk_box_pack_start (GTK_BOX (vbox), swin, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox),
-			    create_buttons (GTK_TREE_VIEW (qthlist)),
-			    FALSE, FALSE, 0);
+						create_buttons (GTK_TREE_VIEW (qthlist)),
+						FALSE, FALSE, 0);
 
 	return vbox;
 }
@@ -155,8 +155,8 @@ sat_pref_qth_ok     ()
 	delete_location_files ();
 
 	gtk_tree_model_foreach (gtk_tree_view_get_model(GTK_TREE_VIEW(qthlist)),
-				save_qth,
-				NULL);
+							save_qth,
+							NULL);
 }
 
 
@@ -180,55 +180,55 @@ create_qth_list ()
 	/* name column */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Name"), renderer,
-							   "text", QTH_LIST_COL_NAME,
-							   NULL);
+													   "text", QTH_LIST_COL_NAME,
+													   NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (qthlist), column, -1);
 
 	/* location column */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Location"), renderer,
-							   "text", QTH_LIST_COL_LOC,
-							   NULL);
+													   "text", QTH_LIST_COL_LOC,
+													   NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (qthlist), column, -1);
 
 	/* lat column */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Lat"), renderer,
-							   "text", QTH_LIST_COL_LAT,
-							   NULL);
+													   "text", QTH_LIST_COL_LAT,
+													   NULL);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_column_set_cell_data_func (column,
-						 renderer,
-						 float_cell_data_function,
-						 GUINT_TO_POINTER (QTH_LIST_COL_LAT),
-						 NULL);
+											 renderer,
+											 float_cell_data_function,
+											 GUINT_TO_POINTER (QTH_LIST_COL_LAT),
+											 NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (qthlist), column, -1);
 
 	/* lon column */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Lon"), renderer,
-							   "text", QTH_LIST_COL_LON,
-							   NULL);
+													   "text", QTH_LIST_COL_LON,
+													   NULL);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_column_set_cell_data_func (column,
-						 renderer,
-						 float_cell_data_function,
-						 GUINT_TO_POINTER (QTH_LIST_COL_LON),
-						 NULL);
+											 renderer,
+											 float_cell_data_function,
+											 GUINT_TO_POINTER (QTH_LIST_COL_LON),
+											 NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (qthlist), column, -1);
 
 	/* alt column */
 	renderer = gtk_cell_renderer_text_new ();
 	if (sat_cfg_get_bool (SAT_CFG_BOOL_USE_IMPERIAL)) {
 		column = gtk_tree_view_column_new_with_attributes (_("Alt (ft)"),
-								   renderer,
-								   "text", QTH_LIST_COL_ALT,
-								   NULL);
+														   renderer,
+														   "text", QTH_LIST_COL_ALT,
+														   NULL);
 	}
 	else {
 		column = gtk_tree_view_column_new_with_attributes (_("Alt (m)"), renderer,
-								   "text", QTH_LIST_COL_ALT,
-								   NULL);
+														   "text", QTH_LIST_COL_ALT,
+														   NULL);
 	}
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (qthlist), column, -1);
 	gtk_tree_view_column_set_alignment (column, 0.5);
@@ -236,27 +236,27 @@ create_qth_list ()
 	/* locator */
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("QRA"), renderer,
-							   "text", QTH_LIST_COL_QRA,
-							   NULL);
+													   "text", QTH_LIST_COL_QRA,
+													   NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (qthlist), column, -1);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 
 	/* weather station */
-/* 	renderer = gtk_cell_renderer_text_new (); */
-/* 	column = gtk_tree_view_column_new_with_attributes (_("WX"), renderer, */
-/* 							   "text", QTH_LIST_COL_WX, */
-/* 							   NULL); */
-/* 	gtk_tree_view_insert_column (GTK_TREE_VIEW (qthlist), column, -1); */
-/* 	gtk_tree_view_column_set_alignment (column, 0.5); */
+	/* 	renderer = gtk_cell_renderer_text_new (); */
+	/* 	column = gtk_tree_view_column_new_with_attributes (_("WX"), renderer, */
+	/* 							   "text", QTH_LIST_COL_WX, */
+	/* 							   NULL); */
+	/* 	gtk_tree_view_insert_column (GTK_TREE_VIEW (qthlist), column, -1); */
+	/* 	gtk_tree_view_column_set_alignment (column, 0.5); */
 
 	/* default */
 	renderer = gtk_cell_renderer_toggle_new ();
 	handler_id = g_signal_connect (renderer, "toggled",
-				       G_CALLBACK (default_toggled), model);
+								   G_CALLBACK (default_toggled), model);
 
 	column = gtk_tree_view_column_new_with_attributes (_("Default"), renderer,
-							   "active", QTH_LIST_COL_DEF,
-							   NULL);
+													   "active", QTH_LIST_COL_DEF,
+													   NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (qthlist), column);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 
@@ -285,22 +285,22 @@ create_and_fill_model ()
 
 	/* create a new list store */
 	liststore = gtk_list_store_new (QTH_LIST_COL_NUM,
-					G_TYPE_STRING,    // QTH name
-					G_TYPE_STRING,    // Location
-					G_TYPE_STRING,    // Description
-					G_TYPE_DOUBLE,    // Latitude
-					G_TYPE_DOUBLE,    // Longitude
-					G_TYPE_INT,       // Altitude
-					G_TYPE_STRING,    // QRA locator
-					G_TYPE_STRING,    // Weather station
-					G_TYPE_BOOLEAN    // Default
-					);
+									G_TYPE_STRING,    // QTH name
+									G_TYPE_STRING,    // Location
+									G_TYPE_STRING,    // Description
+									G_TYPE_DOUBLE,    // Latitude
+									G_TYPE_DOUBLE,    // Longitude
+									G_TYPE_INT,       // Altitude
+									G_TYPE_STRING,    // QRA locator
+									G_TYPE_STRING,    // Weather station
+									G_TYPE_BOOLEAN    // Default
+									);
 
 	/* scan for .qth files in the user config directory and
 	   add the contents of each .qth file to the list store
 	*/
 	dirname = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-			       ".gpredict2", NULL);
+						   ".gpredict2", NULL);
 	dir = g_dir_open (dirname, 0, &error);
 
 
@@ -311,20 +311,20 @@ create_and_fill_model ()
 			if (g_strrstr (filename, ".qth")) {
 
 				buff = g_strconcat (dirname, G_DIR_SEPARATOR_S,
-						    filename, NULL);
+									filename, NULL);
 
 				/* read qth file */
 				if (read_qth_file (liststore, buff)) {
 					/* send debug message */
 					sat_log_log (SAT_LOG_LEVEL_DEBUG,
-						     _("%s:%d: Read QTH data from %s."),
-						     __FILE__, __LINE__, filename);
+								 _("%s:%d: Read QTH data from %s."),
+								 __FILE__, __LINE__, filename);
 				}
 				else {
 					/* error reading the file */
 					sat_log_log (SAT_LOG_LEVEL_ERROR,
-						     _("%s:%d: Error reading %s (see prev msg)"),
-						     __FILE__, __LINE__, filename);
+								 _("%s:%d: Error reading %s (see prev msg)"),
+								 __FILE__, __LINE__, filename);
 				}
 
 				g_free (buff);
@@ -333,8 +333,8 @@ create_and_fill_model ()
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Failed to open user cfg dir (%s)"),
-			     __FILE__, __LINE__, error->message);
+					 _("%s:%d: Failed to open user cfg dir (%s)"),
+					 __FILE__, __LINE__, error->message);
 		g_clear_error (&error);
 	}
 
@@ -363,31 +363,26 @@ create_and_fill_model ()
  * writing the contents to the .qth file.
  */
 static guint
-read_qth_file         (GtkListStore *liststore, gchar *filename)
+read_qth_file (GtkListStore *liststore, gchar *filename)
 {
-	GtkTreeIter  item;       /* new item added to the list store */
-	qth_t       *qth=NULL;   /* qth data structure */
+	GtkTreeIter  item;		/* new item added to the list store */
+	qth_t       *qth;		/* qth data structure */
 	gchar       *defqth;
 	gboolean     is_default = FALSE;
 	gchar       *fname;
-	gint         dispalt;     /* displayed altitude */
+	gint         dispalt;	/* displayed altitude */
 
-
-	/* not available until 2.8 */
-	/*	qth = g_try_new (qth_t, 1); */
-
-	qth = (qth_t *) g_try_malloc (sizeof (qth_t));
-
-	if (qth == NULL) {
+	if ((qth = g_try_new0 (qth_t, 1)) == NULL) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Failed to allocate memory!\n"),
-			     __FILE__, __LINE__);
+					 _("%s:%d: Failed to allocate memory!\n"),
+					 __FILE__, __LINE__);
 
 		return FALSE;
 	}
 
 	/* read data from file */
 	if (!gtk_sat_data_read_qth (filename, qth)) {
+		g_free (qth);
 		return FALSE;
 	}
 
@@ -399,16 +394,16 @@ read_qth_file         (GtkListStore *liststore, gchar *filename)
 
 	if (retcode != RIG_OK) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Could not convert (%.2f,%.2f) to QRA."),
-			     __FILE__, __LINE__,
-			     qth->lat, qth->lon);
+					 _("%s:%d: Could not convert (%.2f,%.2f) to QRA."),
+					 __FILE__, __LINE__,
+					 qth->lat, qth->lon);
 		qth->qra[0] = '\0';
 	}
 	else {
 		qth->qra[6] = '\0';
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s:%d: QRA locator is %s"),
-			     __FILE__, __LINE__, qth->qra);
+					 _("%s:%d: QRA locator is %s"),
+					 __FILE__, __LINE__, qth->qra);
 	}
 
 	/* is this the default qth? */
@@ -418,8 +413,8 @@ read_qth_file         (GtkListStore *liststore, gchar *filename)
 		is_default = TRUE;
 
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s:%d: This appears to be the default QTH."),
-			     __FILE__, __LINE__);
+					 _("%s:%d: This appears to be the default QTH."),
+					 __FILE__, __LINE__);
 	}
 
 	g_free (defqth);
@@ -446,28 +441,26 @@ read_qth_file         (GtkListStore *liststore, gchar *filename)
 	   add the data to the list store */
 	gtk_list_store_append (liststore, &item);
 	gtk_list_store_set (liststore, &item,
-			    QTH_LIST_COL_NAME, qth->name,
-			    QTH_LIST_COL_LOC, qth->loc,
-			    QTH_LIST_COL_DESC, qth->desc,
-			    QTH_LIST_COL_LAT, qth->lat,
-			    QTH_LIST_COL_LON, qth->lon,
-			    QTH_LIST_COL_ALT, dispalt,
-			    QTH_LIST_COL_QRA, qth->qra,
-			    QTH_LIST_COL_WX, qth->wx,
-			    QTH_LIST_COL_DEF, is_default,
-			    -1);
+						QTH_LIST_COL_NAME, qth->name,
+						QTH_LIST_COL_LOC, qth->loc,
+						QTH_LIST_COL_DESC, qth->desc,
+						QTH_LIST_COL_LAT, qth->lat,
+						QTH_LIST_COL_LON, qth->lon,
+						QTH_LIST_COL_ALT, dispalt,
+						QTH_LIST_COL_QRA, qth->qra,
+						QTH_LIST_COL_WX, qth->wx,
+						QTH_LIST_COL_DEF, is_default,
+						-1);
 
 	g_free (fname);
 
 	/* we are finished with this qth, free it */
-	/*** FIXME Segmentation fault, but we should free some memory! */
-	//	gtk_sat_data_free_qth (qth);
+	gtk_sat_data_free_qth (qth);
 
 	return TRUE;
 }
 
 
-
 /** \brief Create buttons.
  *  \param qthlist The GtkTreeView widget containing the qth data.
  *  \return A button box containing the buttons.
@@ -483,20 +476,20 @@ create_buttons (GtkTreeView *qthlist)
 
 	/* add button */
 	addbutton = gpredict_hstock_button (GTK_STOCK_ADD,
-                                             _("Add New"),
-                                             _("Add a new ground station to the list"));
+										_("Add New"),
+										_("Add a new ground station to the list"));
 	g_signal_connect (addbutton, "clicked", G_CALLBACK (add_cb), qthlist);
 
 	/* edit button */
 	editbutton = gpredict_hstock_button (GTK_STOCK_EDIT,
-                                              _("Edit"),
-                                              _("Edit the currently selected ground station"));
+										 _("Edit"),
+										 _("Edit the currently selected ground station"));
 	g_signal_connect (editbutton, "clicked", G_CALLBACK (edit_cb), qthlist);
 
 	/* delete button; don't forget to delete file.... */
 	delbutton = gpredict_hstock_button (GTK_STOCK_DELETE,
-					    _("Delete"),
-					    _("Delete the selected ground station"));
+										_("Delete"),
+										_("Delete the selected ground station"));
 	g_signal_connect (delbutton, "clicked", G_CALLBACK (delete_cb), qthlist);
 
 	/* vertical button box */
@@ -560,14 +553,14 @@ delete_cb (GtkWidget *button, gpointer data)
 		GtkWidget *dialog;
 
 		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-						 GTK_DIALOG_MODAL |
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_OK,
-						 _("Can not delete ground station!\n\n"\
-						   "You need to have at least one ground\n"\
-						   "statiob set up, otherwise gpredict may\n"\
-						   "not work properly."));
+										 GTK_DIALOG_MODAL |
+										 GTK_DIALOG_DESTROY_WITH_PARENT,
+										 GTK_MESSAGE_ERROR,
+										 GTK_BUTTONS_OK,
+										 _("Can not delete ground station!\n\n"\
+										   "You need to have at least one ground\n"\
+										   "statiob set up, otherwise gpredict may\n"\
+										   "not work properly."));
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -583,9 +576,9 @@ delete_cb (GtkWidget *button, gpointer data)
 			gchar    *buff;
 
 			gtk_tree_model_get (selmod, &iter,
-					    QTH_LIST_COL_DEF, &neednewdef,
-					    QTH_LIST_COL_NAME, &buff,
-					    -1);
+								QTH_LIST_COL_DEF, &neednewdef,
+								QTH_LIST_COL_NAME, &buff,
+								-1);
 
 			g_free (buff);
 
@@ -601,15 +594,15 @@ delete_cb (GtkWidget *button, gpointer data)
 
 				if (gtk_tree_model_get_iter_first (model, &iter)) {
 					gtk_list_store_set (GTK_LIST_STORE (model),
-							    &iter,
-							    QTH_LIST_COL_DEF, TRUE,
-							    -1);
+										&iter,
+										QTH_LIST_COL_DEF, TRUE,
+										-1);
 				}
 				else {
 					/* huh? no more entries, this is a bug! */
 					sat_log_log (SAT_LOG_LEVEL_BUG,
-						     _("%s:%d: Empty ground station list!"),
-						     __FILE__, __LINE__);
+								 _("%s:%d: Empty ground station list!"),
+								 __FILE__, __LINE__);
 				}
 
 			}
@@ -633,8 +626,8 @@ delete_cb (GtkWidget *button, gpointer data)
  */
 static void
 default_toggled (GtkCellRendererToggle *cell,
-		 gchar                 *path_str,
-		 gpointer               data)
+				 gchar                 *path_str,
+				 gpointer               data)
 {
 	GtkTreeModel *model = (GtkTreeModel *)data;
 	GtkTreeIter   iter;
@@ -653,24 +646,24 @@ default_toggled (GtkCellRendererToggle *cell,
 	if (fixed) {
 		/* do nothing except sending a message */
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s:%d: Default QTH can not be cleared! "\
-			       "Select another QTH to change default."),
-			     __FILE__, __LINE__);
+					 _("%s:%d: Default QTH can not be cleared! "\
+					   "Select another QTH to change default."),
+					 __FILE__, __LINE__);
 	}
 	else {
 		/* make this qth new default */
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    QTH_LIST_COL_DEF, TRUE,
-				    -1);
+							QTH_LIST_COL_DEF, TRUE,
+							-1);
 
 		/* copy file name of new default QTH to a string buffer */
 		gtk_tree_model_get (model, &iter,
-				    QTH_LIST_COL_NAME, &defqth,
-				    -1);
+							QTH_LIST_COL_NAME, &defqth,
+							-1);
 
 		sat_log_log (SAT_LOG_LEVEL_MSG,
-			     _("%s:%d: New default QTH is %s.qth."),
-			     __FILE__, __LINE__, defqth);
+					 _("%s:%d: New default QTH is %s.qth."),
+					 __FILE__, __LINE__, defqth);
 
 		/* clear the default flag for the other qth */
 		gtk_tree_model_foreach  (model, clear_default_flags, defqth);
@@ -704,19 +697,19 @@ clear_default_flags (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
 
 
 	gtk_tree_model_get (model, iter,
-			    QTH_LIST_COL_NAME, &thisqth,
-			    -1);
+						QTH_LIST_COL_NAME, &thisqth,
+						-1);
 
 	/* clear flag if this is not the new default QTH */
 	if (g_ascii_strcasecmp (thisqth, (gchar *) defqth)) {
 
 		gtk_list_store_set (GTK_LIST_STORE (model), iter,
-				    QTH_LIST_COL_DEF, FALSE,
-				    -1);
+							QTH_LIST_COL_DEF, FALSE,
+							-1);
 
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s:%d: Clearing default flag for %s."),
-			     __FILE__, __LINE__, thisqth);
+					 _("%s:%d: Clearing default flag for %s."),
+					 __FILE__, __LINE__, thisqth);
 
 	}
 				
@@ -737,10 +730,10 @@ clear_default_flags (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
 */
 static void
 float_cell_data_function (GtkTreeViewColumn *col,
-			  GtkCellRenderer   *renderer,
-			  GtkTreeModel      *model,
-			  GtkTreeIter       *iter,
-			  gpointer           column)
+						  GtkCellRenderer   *renderer,
+						  GtkTreeModel      *model,
+						  GtkTreeIter       *iter,
+						  gpointer           column)
 {
 	gdouble   number;
 	gchar   *buff;
@@ -774,15 +767,15 @@ float_cell_data_function (GtkTreeViewColumn *col,
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_BUG,
-				     _("%s:%d: Invalid column: %d"),
-				     __FILE__, __LINE__,
-				     coli);
+						 _("%s:%d: Invalid column: %d"),
+						 __FILE__, __LINE__,
+						 coli);
 			hmf = '?';
 		}
 	}
 
 	/* format the number */
-	buff = g_strdup_printf ("%.2f\302\260%c", number, hmf);
+	buff = g_strdup_printf ("%.4f\302\260%c", number, hmf);
 	g_object_set (renderer, "text", buff, NULL);
 	g_free (buff);
 }
@@ -792,18 +785,18 @@ float_cell_data_function (GtkTreeViewColumn *col,
 /** \brief Callback function to check each QTH for beeing the default */
 static gboolean
 check_and_set_default_qth (GtkTreeModel *model,
-			   GtkTreePath  *path,
-			   GtkTreeIter  *iter,
-			   gpointer      data)
+						   GtkTreePath  *path,
+						   GtkTreeIter  *iter,
+						   gpointer      data)
 {
 	gboolean  def     = FALSE;
 	gchar    *buff;
 	gchar    *filename;
 
 	gtk_tree_model_get (model, iter,
-			    QTH_LIST_COL_DEF, &def,
-			    QTH_LIST_COL_NAME, &buff,
-			    -1);
+						QTH_LIST_COL_DEF, &def,
+						QTH_LIST_COL_NAME, &buff,
+						-1);
 
 	if (def) {
 		/* this is a new default qth;
@@ -826,9 +819,9 @@ check_and_set_default_qth (GtkTreeModel *model,
 /** \brief save a row from the QTH list (called by the save function) */
 static gboolean
 save_qth (GtkTreeModel *model,
-	  GtkTreePath  *path,
-	  GtkTreeIter  *iter,
-	  gpointer      data)
+		  GtkTreePath  *path,
+		  GtkTreeIter  *iter,
+		  gpointer      data)
 {
 	qth_t     qth;
 	gboolean  def     = FALSE;
@@ -837,23 +830,23 @@ save_qth (GtkTreeModel *model,
 
 
 	gtk_tree_model_get (model, iter,
-			    QTH_LIST_COL_DEF, &def,
-			    QTH_LIST_COL_NAME, &qth.name,
-			    QTH_LIST_COL_LOC,  &qth.loc,
-			    QTH_LIST_COL_DESC, &qth.desc,
-			    QTH_LIST_COL_LAT, &qth.lat,
-			    QTH_LIST_COL_LON, &qth.lon,
-			    QTH_LIST_COL_ALT, &qth.alt,
-			    QTH_LIST_COL_WX, &qth.wx,
-			    -1);
+						QTH_LIST_COL_DEF, &def,
+						QTH_LIST_COL_NAME, &qth.name,
+						QTH_LIST_COL_LOC,  &qth.loc,
+						QTH_LIST_COL_DESC, &qth.desc,
+						QTH_LIST_COL_LAT, &qth.lat,
+						QTH_LIST_COL_LON, &qth.lon,
+						QTH_LIST_COL_ALT, &qth.alt,
+						QTH_LIST_COL_WX, &qth.wx,
+						-1);
 
 	filename = g_strconcat (g_get_home_dir (),
-				G_DIR_SEPARATOR_S,
-				".gpredict2",
-				G_DIR_SEPARATOR_S,
-				qth.name,
-				".qth",
-				NULL);
+							G_DIR_SEPARATOR_S,
+							".gpredict2",
+							G_DIR_SEPARATOR_S,
+							qth.name,
+							".qth",
+							NULL);
 	
 	/* check wehter we are using imperial or metric system;
 	   in case of imperial we have to convert altitude from
@@ -868,8 +861,8 @@ save_qth (GtkTreeModel *model,
 		/* saved ok, go on check whether qth is default */
 		if (def) {
 			sat_log_log (SAT_LOG_LEVEL_MSG,
-				     _("%s:%d: %s appears to be default QTH"),
-				     __FILE__, __LINE__, qth.name);
+						 _("%s:%d: %s appears to be default QTH"),
+						 __FILE__, __LINE__, qth.name);
 			
 			buff = g_path_get_basename (filename);
 			sat_cfg_set_str (SAT_CFG_STR_DEF_QTH, buff);
@@ -908,7 +901,7 @@ delete_location_files ()
 	   add the contents of each .qth file to the list store
 	*/
 	dirname = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-			       ".gpredict2", NULL);
+						   ".gpredict2", NULL);
 	dir = g_dir_open (dirname, 0, &error);
 
 
@@ -919,18 +912,18 @@ delete_location_files ()
 			if (g_strrstr (filename, ".qth")) {
 
 				buff = g_strconcat (dirname, G_DIR_SEPARATOR_S,
-						    filename, NULL);
+									filename, NULL);
 
 				/* remove file */
 				if (g_remove (buff)) {
 					sat_log_log (SAT_LOG_LEVEL_ERROR,
-						     _("%s:%d: Failed top remove %s"),
-						     __FILE__, __LINE__, filename);
+								 _("%s:%d: Failed top remove %s"),
+								 __FILE__, __LINE__, filename);
 				}
 				else {
 					sat_log_log (SAT_LOG_LEVEL_DEBUG,
-						     _("%s:%d: Removed %s"),
-						     __FILE__, __LINE__, filename);
+								 _("%s:%d: Removed %s"),
+								 __FILE__, __LINE__, filename);
 				}
 
 				g_free (buff);
@@ -939,8 +932,8 @@ delete_location_files ()
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Failed to open user cfg dir (%s)"),
-			     __FILE__, __LINE__, error->message);
+					 _("%s:%d: Failed to open user cfg dir (%s)"),
+					 __FILE__, __LINE__, error->message);
 		g_clear_error (&error);
 
 	}
@@ -966,8 +959,8 @@ sat_pref_qth_sys_changed (gboolean imperial)
 {
 
 	gtk_tree_model_foreach (gtk_tree_view_get_model(GTK_TREE_VIEW(qthlist)),
-				convert_qth_altitude,
-				GUINT_TO_POINTER(imperial));
+							convert_qth_altitude,
+							GUINT_TO_POINTER(imperial));
 }
 
 
@@ -978,9 +971,9 @@ sat_pref_qth_sys_changed (gboolean imperial)
  */
 static gboolean
 convert_qth_altitude (GtkTreeModel *model,
-		      GtkTreePath  *path,
-		      GtkTreeIter  *iter,
-		      gpointer      data)
+					  GtkTreePath  *path,
+					  GtkTreeIter  *iter,
+					  gpointer      data)
 {
 	gint alti;
 	GtkTreeViewColumn *column;
@@ -989,8 +982,8 @@ convert_qth_altitude (GtkTreeModel *model,
 
 	/* first, get the current altitude and other data */
 	gtk_tree_model_get (model, iter,
-			    QTH_LIST_COL_ALT, &alti,
-			    -1);
+						QTH_LIST_COL_ALT, &alti,
+						-1);
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW (qthlist), 3);
 
 	if (GPOINTER_TO_UINT(data)) {
@@ -1006,8 +999,8 @@ convert_qth_altitude (GtkTreeModel *model,
 
 	/* store new value */
 	gtk_list_store_set (GTK_LIST_STORE (model), iter,
-			    QTH_LIST_COL_ALT, alti,
-			    -1);
+						QTH_LIST_COL_ALT, alti,
+						-1);
 	/* update column title */
 	gtk_tree_view_column_set_title (column, title);
 	g_free (title);
